@@ -1,9 +1,30 @@
 /*****************************************************************
- * drkonki - The KDE Crash Handler
- * 
- * $Id: toplevel.cpp,v 1.26 2000/06/07 05:31:03 waba Exp $
+ * drkonqi - The KDE Crash Handler
+ *
+ * $Id: toplevel.cpp,v 1.34 2000/10/12 01:50:36 pfeiffer Exp $
  *
  * Copyright (C) 2000 Hans Petter Bieker <bieker@kde.org>
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ *
+ * 1. Redistributions of source code must retain the above copyright
+ *    notice, this list of conditions and the following disclaimer.
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
+ * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
+ * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
+ * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
+ * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
+ * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+ * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
+ * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+ * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
+ * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *****************************************************************/
 
 #include <qstring.h>
@@ -11,6 +32,8 @@
 #include <qhbox.h>
 
 #include <klocale.h>
+#include <kglobal.h>
+#include <kdebug.h>
 #include <kstddirs.h>
 #include <kbugreport.h>
 #include <kmessagebox.h>
@@ -25,16 +48,16 @@
 
 Toplevel :: Toplevel(const KrashConfig *krashconf, QWidget *parent, const char *name)
   : KDialogBase( Tabbed,
-		 krashconf->programName(),
+                 krashconf->programName(),
                  User2 | User1 | Close,
                  Close,
                  parent,
                  name,
                  true, // modal
                  true, // separator
-		 i18n("&Bug report"),
-		 i18n("&Debugger")
-		 ),
+                 i18n("&Bug report"),
+                 i18n("&Debugger")
+                 ),
     m_krashconf(krashconf), bugreport(0)
 {
   QHBox *page = addHBoxPage(i18n("General"));
@@ -42,14 +65,16 @@ Toplevel :: Toplevel(const KrashConfig *krashconf, QWidget *parent, const char *
 
   // picture of konqi
   QLabel *lab = new QLabel(page);
-  lab->setBackgroundColor(Qt::white);
-  lab->setFrameStyle(QFrame::Panel | QFrame::Raised);
+  lab->setFrameStyle(QFrame::Panel | QFrame::Sunken);
   QPixmap pix(locate("appdata", QString::fromLatin1("pics/konqi.png")));
   lab->setPixmap(pix);
+  lab->setFixedSize( lab->sizeHint() );
 
-  new QLabel( generateText(), page );
+  QLabel * info = new QLabel(generateText(), page);
+  info->setMinimumSize(info->sizeHint());
 
-  if (m_krashconf->showBacktrace()) {
+  if (m_krashconf->showBacktrace())
+  {
     page = addHBoxPage(i18n("Backtrace"));
     new KrashDebugger(m_krashconf, page);
   }
@@ -83,10 +108,10 @@ QString Toplevel :: generateText() const
   // check if the string is still empty. if so, display a default.
   if (str.isEmpty())
     str = i18n("<p><b>Application crashed</b></p>"
-	       "<p>The program %appname crashed.</p>");
+               "<p>The program %appname crashed.</p>");
 
   // scan the string for %appname etc
-  expandString(str);
+  m_krashconf->expandString(str);
 
   return str;
 }
@@ -101,17 +126,17 @@ void Toplevel :: slotUser1()
     i = KMessageBox::warningYesNoCancel
       (0,
        i18n("<p>Do you want to generate a "
-	    "backtrace? This will help the "
-	    "developers to figure out what went "
-	    "wrong.</p>\n"
-	    "<p>Unfortantly this will take some "
-	    "time on slow machines.</p>"
-	    "<p><b>Note: A backtrace is not a "
-	    "substitute for a proper description "
-	    "the bug and information on how to "
-	    "reproduce it. It is not possible "
-	    "to fix the bug without a proper "
-	    "description.</b></p>"),
+            "backtrace? This will help the "
+            "developers to figure out what went "
+            "wrong.</p>\n"
+            "<p>Unfortunately this will take some "
+            "time on slow machines.</p>"
+            "<p><b>Note: A backtrace is not a "
+            "substitute for a proper description "
+            "the bug and information on how to "
+            "reproduce it. It is not possible "
+            "to fix the bug without a proper "
+            "description.</b></p>"),
        i18n("Include Backtrace"));
 
     if (i == KMessageBox::Cancel) return;
@@ -125,7 +150,7 @@ void Toplevel :: slotUser1()
     BackTrace *backtrace = new BackTrace(m_krashconf, this);
     connect(backtrace, SIGNAL(someError()), SLOT(slotBacktraceSomeError()));
     connect(backtrace, SIGNAL(done(const QString &)),
-	    SLOT(slotBacktraceDone(const QString &)));
+            SLOT(slotBacktraceDone(const QString &)));
 
     backtrace->start();
 
@@ -142,14 +167,10 @@ void Toplevel :: slotUser1()
 void Toplevel :: slotUser2()
 {
   QString str = m_krashconf->debugger();
-  expandString(str);
-
-  // FIXME: Replace by KRun??
-  KProcess proc;
-  QStringList list = QStringList::split(' ', str);
-  for ( QStringList::Iterator it = list.begin(); it != list.end(); ++it )
-    proc << *it;
+  m_krashconf->expandString(str);
 
+  KShellProcess proc;
+  proc << str;
   proc.start(KProcess::DontCare);
 }
 
@@ -158,7 +179,7 @@ void Toplevel :: slotBacktraceDone(const QString &str)
   // Do not translate.. This will be included in the _MAIL_.
   QString buf = QString::fromLatin1
     ("\n\n\nHere is a backtrace generated by DrKonqi:\n") + str;
-  
+
   bugreport->setText(buf);
 
   QApplication::restoreOverrideCursor();
@@ -173,27 +194,10 @@ void Toplevel :: slotBacktraceSomeError()
   QApplication::restoreOverrideCursor();
 
   KMessageBox::sorry(0, i18n("It was not possible to generate a backtrace."),
-		     i18n("Backtrace not possible"));
+                     i18n("Backtrace not possible"));
 
   bugreport->exec();
   delete bugreport;
   bugreport = 0;
 }
 
-// replace some of the strings
-void Toplevel :: expandString(QString &str) const
-{
-  int pos = -1;
-  while ( (pos = str.findRev('%', pos)) != -1 ) {
-    if (str.mid(pos, 8) == QString::fromLatin1("%appname"))
-      str.replace(pos, 8, QString::fromLatin1(m_krashconf->appName()));
-    else if (str.mid(pos, 7) == QString::fromLatin1("%signum"))
-      str.replace(pos, 7, QString::number(m_krashconf->signalNumber()));
-    else if (str.mid(pos, 8) == QString::fromLatin1("%signame"))
-      str.replace(pos, 8, m_krashconf->signalName());
-    else if (str.mid(pos, 9) == QString::fromLatin1("%progname"))
-      str.replace(pos, 9, m_krashconf->programName());
-    else if (str.mid(pos, 4) == QString::fromLatin1("%pid"))
-      str.replace(pos, 4, QString::number(m_krashconf->pid()));
-  }
-}
