@@ -1,3 +1,23 @@
+/*
+  Copyright (c) 2000 Matthias Hoelzer-Kluepfel <hoelzer@kde.org>
+
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
+
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
+
+  You should have received a copy of the GNU General Public License
+  along with this program; if not, write to the Free Software
+  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+
+*/
+
+
 #include <string.h>
 #include <iostream.h>
 
@@ -24,12 +44,12 @@ void copyFile(QString infname, QString outfname)
       if (outf.open(IO_WriteOnly))
 	{
 	  outf.writeBlock(inf.readAll());
-	  
+	
 	  outf.close();
 	}
-      
+
       inf.close();
-    }  
+    }
 }
 
 
@@ -65,8 +85,8 @@ bool checkDesktopFile(const QString &templ, QString destDir)
   if (pos > 0)
     exec = exec.left(pos);
 
-  cout << "looking for " << exec << "\t\t";
-  
+  cout << "looking for " << exec.local8Bit() << "\t\t";
+
   // try to locate the binary
   QString pexec = KGlobal::dirs()->findExe(exec);
   if (pexec.isEmpty())
@@ -74,10 +94,10 @@ bool checkDesktopFile(const QString &templ, QString destDir)
       cout << "not found" << endl;
       return false;
     }
-  
-  cout << pexec << endl;
 
-  kdDebug() << "Writing " << destDir << "/./" << destName << endl;  
+  cout << pexec.local8Bit() << endl;
+
+  kdDebug() << "Writing " << destDir << "/./" << destName << endl;
 
   // create the directories
   destDir += "/";
@@ -121,7 +141,7 @@ void decorateDirs(QString destDir)
       destName = destDir+"/"+destName;
 
       if (!QFile::exists(destName))
-	{	  
+	{	
 	  kdDebug() << "Copy " << *it << " to " << destName << endl;
 	  copyFile(*it, destName);
 	}
