@@ -10,8 +10,15 @@
 #include <qtimer.h>
 
 #include <kcmodule.h>
+#include <config.h>
 
+#ifdef HAVE_LONG_LONG
+/* better to use long-long, because some 32bit-machines have more total 
+   memory (with swap) than just the 4GB which fits into a 32bit-long */
+typedef unsigned long long t_memsize;
+#else
 typedef unsigned long t_memsize;
+#endif
 
 class KMemoryWidget : public KCModule
 {
@@ -32,10 +39,6 @@ private:
 public slots:
   void update_Values();
 
-/*
-protected:
-  virtual void resizeEvent( QResizeEvent * );
-*/
 };
 
 
