@@ -44,7 +44,7 @@ public:
   void load();
   void defaults();
 
-  QString quickHelp();
+  QString quickHelp() const;
 
 private slots:
 
