@@ -37,8 +37,6 @@
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include <iostream.h>
-
 #include <sys/types.h>
 #include <unistd.h>
 #include <sys/stat.h>
@@ -106,18 +104,18 @@ MouseConfig::MouseConfig (QWidget * parent, const char *name)
 
     // SC/DC/AutoSelect/ChangeCursor
 
-    singleClick = new QCheckBox(i18n("Single &click activates/opens"), tab1);
-    connect(singleClick, SIGNAL(clicked()), SLOT(changed()));
+    doubleClick = new QCheckBox(i18n("Use double-click to activate or open"), tab1);
+    connect(doubleClick, SIGNAL(clicked()), SLOT(changed()));
     lay->addSpacing(15);
-    lay->addWidget(singleClick);
+    lay->addWidget(doubleClick);
 
-    wtstr = i18n("Checking this option allows you to select and activate"
+    wtstr = i18n("The default behavior in KDE is to select and activate"
          " icons with a single click of the left button on your pointing"
          " device. This behavior is consistent with what you would expect"
          " when you click links in most web browsers. If you would prefer"
          " to select with a single click, and activate with a double click,"
-         " uncheck this option.");
-    QWhatsThis::add( singleClick, wtstr );
+         " check this option.");
+    QWhatsThis::add( doubleClick, wtstr );
 
     cbAutoSelect = new QCheckBox(i18n("&Automatically select icons"), tab1);
     lay->addWidget(cbAutoSelect);
@@ -164,7 +162,7 @@ MouseConfig::MouseConfig (QWidget * parent, const char *name)
     lay->addWidget(cbCursor,Qt::AlignLeft);
     connect(cbCursor, SIGNAL(clicked()), this, SLOT(changed()));
 
-    connect( singleClick, SIGNAL( clicked() ), this, SLOT( slotClick() ) );
+    connect( doubleClick, SIGNAL( clicked() ), this, SLOT( slotClick() ) );
     connect( cbAutoSelect, SIGNAL( clicked() ), this, SLOT( slotClick() ) );
 
     wtstr = i18n("When this option is checked, the shape of the mouse pointer"
@@ -348,7 +346,7 @@ void MouseConfig::load()
   dragStartTime->setValue(settings->dragStartTime);
   dragStartDist->setValue(settings->dragStartDist);
 
-  singleClick->setChecked(settings->singleClick);
+  doubleClick->setChecked(!settings->singleClick);
 
   cbAutoSelect->setChecked( settings->autoSelectDelay >= 0 );
   if ( settings->autoSelectDelay < 0 )
@@ -370,7 +368,7 @@ void MouseConfig::save()
   settings->doubleClickInterval = doubleClickInterval->value();
   settings->dragStartTime = dragStartTime->value();
   settings->dragStartDist = dragStartDist->value();
-  settings->singleClick = singleClick->isChecked();
+  settings->singleClick = !doubleClick->isChecked();
   settings->autoSelectDelay = cbAutoSelect->isChecked()?slAutoSelect->value():-1;
   settings->visualActivate = cbVisualActivate->isChecked();
   settings->changeCursor = cbCursor->isChecked();
@@ -398,7 +396,7 @@ void MouseConfig::defaults()
     doubleClickInterval->setValue(400);
     dragStartTime->setValue(500);
     dragStartDist->setValue(4);
-    singleClick->setChecked( KDE_DEFAULT_SINGLECLICK );
+    doubleClick->setChecked( !KDE_DEFAULT_SINGLECLICK );
     cbAutoSelect->setChecked( KDE_DEFAULT_AUTOSELECTDELAY != -1 );
     slAutoSelect->setValue( KDE_DEFAULT_AUTOSELECTDELAY == -1 ? 50 : KDE_DEFAULT_AUTOSELECTDELAY );
     cbCursor->setChecked( KDE_DEFAULT_CHANGECURSOR );
@@ -419,9 +417,9 @@ QString MouseConfig::quickHelp() const
 void MouseConfig::slotClick()
 {
   // Autoselect has a meaning only in single-click mode
-  cbAutoSelect->setEnabled(singleClick->isChecked());
+  cbAutoSelect->setEnabled(!doubleClick->isChecked());
   // Delay has a meaning only for autoselect
-  bool bDelay = cbAutoSelect->isChecked() && singleClick->isChecked();
+  bool bDelay = cbAutoSelect->isChecked() && !doubleClick->isChecked();
   slAutoSelect->setEnabled( bDelay );
   lDelay->setEnabled( bDelay );
 }
@@ -445,6 +443,7 @@ void MouseSettings::load(KConfig *config)
 
   handedEnabled = true;
 
+  // ## keep this in sync with KGlobalSettings::mouseSettings
   switch (num_buttons)
     {
     case 1:
@@ -601,7 +600,7 @@ void MouseSettings::apply()
   else if (!!font)
     KIO::NetAccess::copy(font, installedFont);
 
-  system(QString("mkfontdir " + overrideDir).ascii());
+  system(QFile::encodeName("mkfontdir " + overrideDir));
 }
 
 void MouseSettings::save(KConfig *config)
@@ -616,7 +615,7 @@ void MouseSettings::save(KConfig *config)
 
   config->setGroup(QString::fromLatin1("KDE"));
   config->writeEntry("DoubleClickInterval", doubleClickInterval, true, true);
-  config->writeEntry("StartDragIime", dragStartTime, true, true);
+  config->writeEntry("StartDragTime", dragStartTime, true, true);
   config->writeEntry("StartDragDist", dragStartDist, true, true);
   config->writeEntry(QString::fromLatin1("SingleClick"), singleClick, true, true);
   config->writeEntry( "AutoSelectDelay", autoSelectDelay, true, true );
