@@ -91,11 +91,17 @@ KPopupMenu *ModuleMenu::getGroupMenu(const QStringList &groups)
     parGroup.append(groups[i]);
   KPopupMenu *parent = getGroupMenu(parGroup);
 
+  KServiceGroup::Ptr group = KServiceGroup::group(KCGlobal::baseGroup()+path);
+  if (!group)
+  {
+     kdWarning() << KCGlobal::baseGroup()+path << " not found!\n";
+     return this;
+  }
+
   // create new menu
   KPopupMenu *menu = new KPopupMenu(parent);
   connect(menu, SIGNAL(activated(int)), this, SLOT(moduleSelected(int)));
 
-  KServiceGroup::Ptr group = KServiceGroup::group(KCGlobal::baseGroup()+path);
   parent->insertItem(KGlobal::iconLoader()->loadIcon(group->icon(), KIcon::Desktop, KIcon::SizeSmall)
                                          , group->caption(), menu);
 
