@@ -25,11 +25,11 @@
 #include <qdir.h>
 #include <qimage.h>
 #include <qfileinfo.h>
+#include <qpushbutton.h>
 
 #include <kcolorbtn.h>
 #include <kurl.h>
-#include <kiconloader.h>
-#include <kicondialog.h>
+#include <kfiledialog.h>
 #include <kcmodule.h>
 
 
@@ -37,6 +37,7 @@
 
 class QLabel;
 class QRadioButton;
+class QLineEdit;
 class KLineEdit;
 
 
@@ -47,35 +48,49 @@ class KDMAppearanceWidget : public KCModule
 public:
 	KDMAppearanceWidget(QWidget *parent, const char *name=0);
 
-        void load();
-        void save();
+	void load();
+	void save();
 	void defaults();
-        QString quickHelp() const;
+	QString quickHelp() const;
+
+	void loadLanguageList(KLanguageCombo *combo, const QStringList &first);
+	void loadCountryList(KLanguageCombo *combo);
+	void loadLangs(QString country);
 
 	bool eventFilter(QObject *, QEvent *);
 
 protected:
 	void iconLoaderDragEnterEvent(QDragEnterEvent *event);
 	void iconLoaderDropEvent(QDropEvent *event);
-	void setLogo(QString logo);
+	bool setLogo(QString logo);
 
 private slots:
-	void slotRadioClicked(int id);
-        void slotLogoPixChanged(QString);
-        void changed();
-        void loadLocaleList(KLanguageCombo *combo, const QString &sub, const QStringList &first);
+	void slotAreaRadioClicked(int id);
+	void slotPosRadioClicked(int id);
+	void slotLogoButtonClicked();
+	void changed();
+	void changedCountry(int i);
  
 private:
-	enum { KdmLogo=0, KdmClock=1 };
+	enum { KdmNone, KdmClock, KdmLogo };
 	QLabel      *logoLabel;
-        KIconButton *logobutton;
-        KLineEdit    *greetstr_lined;
+	QPushButton *logobutton;
+	KLineEdit    *greetstr_lined;
 	QString      logopath;
-	QRadioButton *logoRadio;
+	QRadioButton *noneRadio;
 	QRadioButton *clockRadio;
+	QRadioButton *logoRadio;
+	QRadioButton *posCenterRadio;
+	QRadioButton *posSpecifyRadio;
+	QLabel	     *xLineLabel;
+	QLineEdit    *xLineEdit;
+	QLabel	     *yLineLabel;
+	QLineEdit    *yLineEdit;
 	QComboBox    *guicombo;
-        KLanguageCombo *langcombo;
-        KLanguageCombo *countrycombo;
+	QComboBox    *echocombo;
+	KLanguageCombo *langcombo;
+	KLanguageCombo *countrycombo;
+	QStringList  langs;
 
 };
 
