@@ -21,6 +21,7 @@
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#include <qlayout.h>
 
 #include <klocale.h>
 #include <kglobal.h>
@@ -35,7 +36,9 @@
 KeyModule::KeyModule(QWidget *parent, const char *name)
   : KCModule(parent, name)
 {
+  QVBoxLayout *layout = new QVBoxLayout(this);
   tab = new QTabWidget(this);
+  layout->addWidget(tab);
 
   global = new KKeyModule(this, true);
   tab->addTab(global, i18n("&Global shortcuts"));
@@ -44,9 +47,6 @@ KeyModule::KeyModule(QWidget *parent, const char *name)
   standard = new KKeyModule(this, false);
   tab->addTab(standard, i18n("&Application shortcuts"));
   connect(standard, SIGNAL(changed(bool)), this, SLOT(moduleChanged(bool)));
-
-  setMinimumSize(global->sizeHint().width(),
-		 global->sizeHint().height()+30);
 }
 
 
@@ -82,14 +82,29 @@ void KeyModule::resizeEvent(QResizeEvent *)
   tab->setGeometry(0,0,width(),height());
 }
 
+QString KeyModule::quickHelp() const
+{
+  return i18n("<h1>Key Bindings</h1> Using key bindings you can configure certain actions to be"
+    " triggered when you press a key or a combination of keys, e.g. CTRL-C is normally bound to"
+    " 'Copy'. KDE allows you to store more than one 'scheme' of key bindings, so you might want"
+    " to experiment a little setting up your own scheme while you can still change back to the"
+    " KDE defaults.<p> In the tab 'Global shortcuts' you can configure non-application specific"
+    " bindings like how to switch desktops or maximize a window. In the tab 'Application shortcuts'"
+    " you'll find bindings typically used in applications, such as copy and paste.");
+}
+
 
 extern "C"
 {
-  KCModule *create_keys(QWidget *parent, const char *name) 
-  { 
+  KCModule *create_keys(QWidget *parent, const char *name)
+  {
     KGlobal::locale()->insertCatalogue("kcmkeys");
+    KGlobal::locale()->insertCatalogue("kwin");
+    KGlobal::locale()->insertCatalogue("kdesktop");
+    KGlobal::locale()->insertCatalogue("kicker");
     return new KeyModule(parent, name);
   }
 }
 
 
+#include "main.moc"
