@@ -1,5 +1,5 @@
 /*
-    $Id: knotify.cpp,v 1.34.2.1 2000/10/26 11:55:23 bero Exp $
+    $Id: knotify.cpp,v 1.43 2001/02/05 06:42:23 waba Exp $
 
     Copyright (C) 2000 Carsten Pfeiffer <pfeiffer@kde.org>
 
@@ -33,6 +33,7 @@
 #include <kapp.h>
 #include <kaudioplayer.h>
 #include <kcursor.h>
+#include <kdebug.h>
 #include <kdialog.h>
 #include <kfiledialog.h>
 #include <kglobal.h>
@@ -42,8 +43,8 @@
 #include <kmessagebox.h>
 #include <knotifyclient.h>
 #include <kstddirs.h>
+#include <kurlcompletion.h>
 #include <kurlrequester.h>
-#include <kdebug.h>
 
 #include "knotify.h"
 #include "knotify.moc"
@@ -53,7 +54,9 @@ static const int COL_FILENAME = 1;
 KNotifyWidget::KNotifyWidget(QWidget *parent, const char *name):
     KCModule(parent, name)
 {
+    updating = true;
     currentItem = 0L;
+    setButtons( Help | Apply );
 
     QVBoxLayout *lay = new QVBoxLayout( this, KDialog::marginHint(),
 					KDialog::spacingHint() );
@@ -71,30 +74,14 @@ KNotifyWidget::KNotifyWidget(QWidget *parent, const char *name):
     hbox->setSpacing( KDialog::spacingHint() );
     QLabel *l = new QLabel( i18n("&Filename: "), hbox );
     requester = new KURLRequester( hbox );
-    requester->setEnabled( false );
     l->setBuddy( requester );
-
-    // find the first "sound"-resource that contains files
-    QStringList soundDirs = KGlobal::dirs()->resourceDirs( "sound" );
-    if ( !soundDirs.isEmpty() ) {
-	KURL soundURL;
-	QDir dir;
-	dir.setFilter( QDir::Files | QDir::Readable );
-	QStringList::Iterator it = soundDirs.begin();
-	while ( it != soundDirs.end() ) {
-	    dir = *it;
-	    if ( dir.isReadable() && dir.count() > 2 ) {
-		soundURL.setPath( *it );
-		requester->fileDialog()->setURL( soundURL );
-		break;
-	    }
-	    ++it;
-	}
-    }
+    connect( requester, SIGNAL( openFileDialog( KURLRequester * )),
+	     SLOT( slotRequesterClicked( KURLRequester * )));
 
     playButton = new QPushButton(  hbox );
     playButton->setFixedSize( requester->button()->size() );
     playButton->setPixmap( UserIcon("play") );
+    QToolTip::add( playButton, i18n("Play the given sound") );
     playButton->hide();
 
     connect( playButton, SIGNAL( clicked() ), SLOT( playSound() ));
@@ -103,11 +90,23 @@ KNotifyWidget::KNotifyWidget(QWidget *parent, const char *name):
     connect( view, SIGNAL( currentChanged( QListViewItem * )),
 	     SLOT( slotItemActivated( QListViewItem * )));
 
+
+    hbox = new QHBox( box );
+    hbox->setSpacing( KDialog::spacingHint() );
+    cbExternal = new QCheckBox( i18n("Use e&xternal player: "), hbox );
+    reqExternal = new KURLRequester( hbox );
+    reqExternal->completionObject()->setMode( KURLCompletion::ExeCompletion );
+    connect( cbExternal, SIGNAL( toggled( bool )),
+	     SLOT( externalClicked( bool )));
+    connect( reqExternal, SIGNAL( textChanged( const QString& )),
+	     SLOT( changed() ));
+
     m_events = new Events();
     qApp->processEvents(); // let's show up
 
     // reading can take some time
-    QTimer::singleShot( 0, this, SLOT( loadAll() ));
+    QTimer::singleShot( 0, this, SLOT( load() ));
+    updating = false;
 };
 
 KNotifyWidget::~KNotifyWidget()
@@ -121,6 +120,8 @@ KNotifyWidget::~KNotifyWidget()
  */
 void KNotifyWidget::updateView()
 {
+    bool save_updating = updating;
+    updating = true;
     view->clear();
     QListViewItem *appItem = 0L;
     KNListViewItem *eItem  = 0L;
@@ -145,9 +146,11 @@ void KNotifyWidget::updateView()
 
 	++it;
     }
+    updating = save_updating;
 }
 
 
+// FIXME: this doesn't work, it's a Reset, not a Defaults.
 void KNotifyWidget::defaults()
 {
     if (KMessageBox::warningContinueCancel(this,
@@ -156,12 +159,13 @@ void KNotifyWidget::defaults()
         != KMessageBox::Continue)
         return;
 
-    loadAll();
+    load();
 }
 
 void KNotifyWidget::changed()
 {
-    emit KCModule::changed(true);
+    if (!updating)
+       emit KCModule::changed(true);
 }
 
 /**
@@ -170,6 +174,8 @@ void KNotifyWidget::changed()
  */
 void KNotifyWidget::slotFileChanged( const QString& text )
 {
+    playButton->setEnabled( !text.isEmpty() );
+
     if ( !currentItem )
 	return;
 
@@ -183,7 +189,7 @@ void KNotifyWidget::slotFileChanged( const QString& text )
 
     if ( itemText && *itemText != text ) {
 	*itemText = text;
-	emit changed();
+	changed();
     }
 
     currentItem->setText( COL_FILENAME, text );
@@ -194,38 +200,67 @@ void KNotifyWidget::playSound()
     KAudioPlayer::play( requester->url() );
 }
 
-void KNotifyWidget::loadAll()
+void KNotifyWidget::load()
 {
+    bool save_updating = updating;
+    updating = true;
+
     setEnabled( false );
     setCursor( KCursor::waitCursor() );
+    currentItem = 0L;
+
+    KConfig *kc = new KConfig( "knotifyrc", true, false );
+    kc->setGroup( "Misc" );
+    cbExternal->setChecked( kc->readBoolEntry( "Use external player", false ));
+    reqExternal->setURL( kc->readEntry( "External player" ));
+    reqExternal->setEnabled( cbExternal->isChecked() );
+    delete kc;
+
+    requester->clear();
+    requester->setEnabled( false );
+    playButton->hide();
+
+    view->clear();
     m_events->load();
     updateView();
     setEnabled( true );
     unsetCursor();
+
+    updating = save_updating;
 }
 
 void KNotifyWidget::save()
 {
+    // see kdelibs/arts/knotify/knotify.cpp
+    KConfig *kc = new KConfig( "knotifyrc", false, false );
+    kc->setGroup( "Misc" );
+    kc->writeEntry( "External player", reqExternal->url() );
+    kc->writeEntry( "Use external player", cbExternal->isChecked() );
+    kc->sync();
+    delete kc;
+	
     m_events->save();
     if ( !kapp->dcopClient()->isAttached() )
 	kapp->dcopClient()->attach();
     kapp->dcopClient()->send("knotify", "", "reconfigure()", "");
+
+    emit KCModule::changed( false );
 }
 
 void KNotifyWidget::slotItemActivated( QListViewItem *i )
 {
     bool enableButton = false;
-    KNCheckListItem *item = dynamic_cast<KNCheckListItem *>( i );
-    if ( item ) {
-	currentItem = item;
-	const KNEvent *event = item->event;
+    currentItem = dynamic_cast<KNCheckListItem *>( i );
+    if ( currentItem ) {
+	const KNEvent *event = currentItem->event;
 
-	if ( item->eventType() == KNotifyClient::Sound ) {
+	if ( currentItem->eventType() == KNotifyClient::Sound ) {
 	    requester->setURL( event->soundfile );
 	    enableButton = true;
 	    playButton->show();
+	    playButton->setEnabled( !event->soundfile.isEmpty() );
 	}
-	else if ( item->eventType() == KNotifyClient::Logfile ) {
+	else if ( currentItem->eventType() == KNotifyClient::Logfile ) {
 	    requester->setURL( event->logfile );
 	    enableButton = true;
 	    playButton->hide();
@@ -236,7 +271,6 @@ void KNotifyWidget::slotItemActivated( QListViewItem *i )
 	}
     }
     else {
-	currentItem = 0L;
 	requester->lineEdit()->clear();
 	playButton->hide();
     }
@@ -244,6 +278,13 @@ void KNotifyWidget::slotItemActivated( QListViewItem *i )
     requester->setEnabled( enableButton );
 }
 
+void KNotifyWidget::externalClicked( bool on )
+{
+    if ( on )
+	reqExternal->setFocus();
+    reqExternal->setEnabled( on );
+    changed();
+}
 
 QString KNotifyWidget::quickHelp() const
 {
@@ -254,7 +295,7 @@ QString KNotifyWidget::quickHelp() const
 		"<ul><li>As the application was originally designed."
 		"<li>With a beep or other noise."
 		"<li>Via a popup dialog box with additional information."
-		"<li>By recording the the event in a logfile without "
+		"<li>By recording the event in a logfile without "
 		"any additional visual or auditory alert."
 		"</ul>");
 }
@@ -277,6 +318,31 @@ const KAboutData *KNotifyWidget::aboutData() const
     return ab;
 }
 
+void KNotifyWidget::slotRequesterClicked( KURLRequester *requester )
+{
+    static bool init = true;
+    if ( !init )
+	return;
+    
+    // find the first "sound"-resource that contains files
+    QStringList soundDirs = KGlobal::dirs()->resourceDirs( "sound" );
+    if ( !soundDirs.isEmpty() ) {
+	KURL soundURL;
+	QDir dir;
+	dir.setFilter( QDir::Files | QDir::Readable );
+	QStringList::Iterator it = soundDirs.begin();
+	while ( it != soundDirs.end() ) {
+	    dir = *it;
+	    if ( dir.isReadable() && dir.count() > 2 ) {
+		soundURL.setPath( *it );
+		requester->fileDialog()->setURL( soundURL );
+		break;
+	    }
+	    ++it;
+	}
+    }
+}
+
 
 ///////////////////////////////////////////////////////////////////
 
@@ -331,7 +397,7 @@ void KNListViewItem::itemChanged( KNCheckListItem *item )
     else
 	event->presentation &= ~item->eventType();
 
-    emit changed();
+    changed();
 }
 
 
