@@ -27,12 +27,15 @@
 #include <kmessagebox.h>
 #include <kstddirs.h>
 #include <kipc.h>
+#include <ktrader.h>
 #include <qcheckbox.h>
 #include <qcombobox.h>
 #include <qlabel.h>
 #include <qlayout.h>
 #include <qlineedit.h>
 #include <qwhatsthis.h>
+#include <qtl.h>
+#include <qlistview.h>
 #include <assert.h>
 
 #include "rootopts.h"
@@ -40,18 +43,44 @@
 #include <konq_defaults.h> // include default values directly from libkonq
 
 
+extern int konq_screen_number;
+
+
 //-----------------------------------------------------------------------------
 
-static const char * s_choices[4] = { "", "WindowListMenu", "DesktopMenu", "AppMenu" };
+class PreviewItem : public QCheckListItem
+{
+public:
+    PreviewItem(KRootOptions *rootOpts, QListView *parent,
+                const KService::Ptr &plugin, bool on)
+        : QCheckListItem(parent, plugin->name(), CheckBox),
+          m_rootOpts(rootOpts)
+    {
+        m_pluginName = plugin->desktopEntryName();
+        setOn(on);
+    }
+    const QString &pluginName() const { return m_pluginName; }
+
+protected:
+    virtual void stateChange( bool ) { m_rootOpts->changed(); }
+
+private:
+    KRootOptions *m_rootOpts;
+    QString m_pluginName;
+};
+
+static const char * s_choices[6] = { "", "WindowListMenu", "DesktopMenu", "AppMenu", "CustomMenu1", "CustomMenu2" };
 
 KRootOptions::KRootOptions(KConfig *config, QWidget *parent, const char *name )
     : KCModule( parent, name ), g_pConfig(config)
 {
   QLabel * tmpLabel;
-#define RO_LASTROW 13   // 3 cb, 1 line, 3 combo, 1 line, 3 paths and 1 label + last row
+#define RO_LASTROW 15   // 3 cb, 1 listview, 1 line, 3 combo, 1 line, 4 paths and 1 label + last row
 #define RO_LASTCOL 2
   int row = 0;
   QGridLayout *lay = new QGridLayout(this, RO_LASTROW+1, RO_LASTCOL+1, 10);
+  QString strMouseButton1, strMouseButton3, strButtonTxt1, strButtonTxt3;
+  bool leftHandedMouse;
 
   lay->setRowStretch(RO_LASTROW,10); // last line grows
 
@@ -59,8 +88,15 @@ KRootOptions::KRootOptions(KConfig *config, QWidget *parent, const char *name )
   lay->setColStretch(1,0);
   lay->setColStretch(2,10);
 
+  /*
+   * The text on this form depends on the mouse setting, which can be right
+   * or left handed.  The outer button functionality is actually swapped
+   *
+   */
+  leftHandedMouse = ( KGlobalSettings::mouseSettings().handed == KGlobalSettings::KMouseSettings::LeftHanded);
+
   VertAlignBox = new QCheckBox(i18n("Align Icons &Vertically on Desktop"), this);
-  lay->addMultiCellWidget(VertAlignBox, row, row, 0, 1);
+  lay->addMultiCellWidget(VertAlignBox, row, row, 0, 0);
   connect(VertAlignBox, SIGNAL(clicked()), this, SLOT(changed()));
   QWhatsThis::add( VertAlignBox, i18n("Check this option if you want the icons"
                                       " on the desktop to be aligned vertically (in columns). If you leave this"
@@ -71,7 +107,7 @@ KRootOptions::KRootOptions(KConfig *config, QWidget *parent, const char *name )
 
   row++;
   showHiddenBox = new QCheckBox(i18n("Show &Hidden Files on Desktop"), this);
-  lay->addMultiCellWidget(showHiddenBox, row, row, 0, 1);
+  lay->addMultiCellWidget(showHiddenBox, row, row, 0, 0);
   connect(showHiddenBox, SIGNAL(clicked()), this, SLOT(changed()));
   QWhatsThis::add( showHiddenBox, i18n("If you check this option, any files"
                                        " in your desktop directory that begin with a period (.) will be shown."
@@ -85,13 +121,21 @@ KRootOptions::KRootOptions(KConfig *config, QWidget *parent, const char *name )
 
   row++;
   menuBarBox = new QCheckBox(i18n("Enable Desktop &Menu"), this);
-  lay->addMultiCellWidget(menuBarBox, row, row, 0, 1);
+  lay->addMultiCellWidget(menuBarBox, row, row, 0, 0);
   connect(menuBarBox, SIGNAL(clicked()), this, SLOT(changed()));
   QWhatsThis::add( menuBarBox, i18n("Check this option if you want the"
                                     " desktop popup menus to appear on the top of the screen in the style"
                                     " of Macintosh.  This setting is independent of the global top-level"
                                     " menu setting that applies to KDE applications.") );
 
+  row++;
+  lay->setRowStretch( row, 10 );
+  previewListView = new QListView( this );
+  previewListView->addColumn( i18n("Show Previews for:") );
+  lay->addMultiCellWidget( previewListView, row - 3, row, 1, RO_LASTCOL );
+  QWhatsThis::add(previewListView, i18n("Select for which types of files you want to"
+                                        " enable preview images"));
+
   row++;
   QFrame * hLine2 = new QFrame(this);
   hLine2->setFrameStyle(QFrame::Sunken|QFrame::HLine);
@@ -101,17 +145,30 @@ KRootOptions::KRootOptions(KConfig *config, QWidget *parent, const char *name )
   tmpLabel = new QLabel( i18n("Clicks on the desktop"), this );
   lay->addMultiCellWidget( tmpLabel, row, row, 0, RO_LASTCOL );
 
+  strMouseButton1 = i18n("Left Button");
+  strButtonTxt1 = i18n( "You can choose what happens when"
+   " you click the left button of your pointing device on the desktop:");
+
+  strMouseButton3 = i18n("Right Button");
+  strButtonTxt3 = i18n( "You can choose what happens when"
+   " you click the right button of your pointing device on the desktop:");
+
+  if ( leftHandedMouse )
+  {
+     qSwap(strMouseButton1, strMouseButton3);
+     qSwap(strButtonTxt1, strButtonTxt3);
+  }
+
   row++;
-  tmpLabel = new QLabel( i18n("&Left button"), this );
+  tmpLabel = new QLabel( strMouseButton1, this );
   lay->addWidget( tmpLabel, row, 0 );
   leftComboBox = new QComboBox( this );
   tmpLabel->setBuddy( leftComboBox );
   lay->addWidget( leftComboBox, row, 1 );
   fillMenuCombo( leftComboBox );
   connect(leftComboBox, SIGNAL(activated(int)), this, SLOT(changed()));
-  QString wtstr = i18n("You can choose what happens when"
-                       " you click the left button of your pointing device on the desktop:"
-                       " <ul><li><em>No action:</em> as you might guess, nothing happens!</li>"
+  QString wtstr = strButtonTxt1 +
+                  i18n(" <ul><li><em>No action:</em> as you might guess, nothing happens!</li>"
                        " <li><em>Window list menu:</em> a menu showing all windows on all"
                        " virtual desktops pops up. You can click on the desktop name to switch"
                        " to that desktop, or on a window name to shift focus to that window,"
@@ -128,7 +185,7 @@ KRootOptions::KRootOptions(KConfig *config, QWidget *parent, const char *name )
   QWhatsThis::add( leftComboBox, wtstr );
 
   row++;
-  tmpLabel = new QLabel( i18n("M&iddle button"), this );
+  tmpLabel = new QLabel( i18n("Middle button"), this );
   lay->addWidget( tmpLabel, row, 0 );
   middleComboBox = new QComboBox( this );
   tmpLabel->setBuddy( middleComboBox );
@@ -154,16 +211,15 @@ KRootOptions::KRootOptions(KConfig *config, QWidget *parent, const char *name )
   QWhatsThis::add( middleComboBox, wtstr );
 
   row++;
-  tmpLabel = new QLabel( i18n("&Right button"), this );
+  tmpLabel = new QLabel( strMouseButton3, this );
   lay->addWidget( tmpLabel, row, 0 );
   rightComboBox = new QComboBox( this );
   tmpLabel->setBuddy( rightComboBox );
   lay->addWidget( rightComboBox, row, 1 );
   fillMenuCombo( rightComboBox );
   connect(rightComboBox, SIGNAL(activated(int)), this, SLOT(changed()));
-  wtstr = i18n("You can choose what happens when"
-               " you click the right button of your pointing device on the desktop:"
-               " <ul><li><em>No action:</em> as you might guess, nothing happens!</li>"
+  wtstr = strButtonTxt3 +
+          i18n(" <ul><li><em>No action:</em> as you might guess, nothing happens!</li>"
                " <li><em>Window list menu:</em> a menu showing all windows on all"
                " virtual desktops pops up. You can click on the desktop name to switch"
                " to that desktop, or on a window name to shift focus to that window,"
@@ -227,6 +283,18 @@ KRootOptions::KRootOptions(KConfig *config, QWidget *parent, const char *name )
   QWhatsThis::add( tmpLabel, wtstr );
   QWhatsThis::add( leAutostart, wtstr );
 
+  row++;
+  tmpLabel = new QLabel(i18n("&Documents path:"), this);
+  lay->addWidget(tmpLabel, row, 0);
+  leDocument = new QLineEdit(this);
+  tmpLabel->setBuddy( leDocument );
+  lay->addMultiCellWidget(leDocument, row, row, 1, RO_LASTCOL);
+  connect(leDocument, SIGNAL(textChanged(const QString &)), this, SLOT(changed()));
+  wtstr = i18n("This directory will be used by default to "
+               "load or save documents to or from.");
+  QWhatsThis::add( tmpLabel, wtstr );
+  QWhatsThis::add( leDocument, wtstr );
+
   row++;
   // TODO (post message freeze) : the message below is true only for local dirs.
   tmpLabel = new QLabel(i18n("Note that changing a path automatically moves"
@@ -246,6 +314,8 @@ void KRootOptions::fillMenuCombo( QComboBox * combo )
   combo->insertItem( i18n("Window List Menu") );
   combo->insertItem( i18n("Desktop Menu") );
   combo->insertItem( i18n("Application Menu") );
+  combo->insertItem( i18n("Custom Menu 1") );
+  combo->insertItem( i18n("Custom Menu 2") );
 }
 
 void KRootOptions::load()
@@ -255,6 +325,11 @@ void KRootOptions::load()
     showHiddenBox->setChecked(bShowHidden);
     bool bVertAlign = g_pConfig->readNumEntry("VertAlign", DEFAULT_VERT_ALIGN);
     VertAlignBox->setChecked(bVertAlign);
+    KTrader::OfferList plugins = KTrader::self()->query("ThumbCreator");
+    previewListView->clear();
+    QStringList previews = g_pConfig->readListEntry("Preview");
+    for (KTrader::OfferList::ConstIterator it = plugins.begin(); it != plugins.end(); ++it)
+        new PreviewItem(this, previewListView, *it, previews.contains((*it)->desktopEntryName()));
     //
     g_pConfig->setGroup( "Menubar" );
     bool bMenuBar = g_pConfig->readBoolEntry("ShowMenubar", false);
@@ -263,15 +338,15 @@ void KRootOptions::load()
     g_pConfig->setGroup( "Mouse Buttons" );
     QString s;
     s = g_pConfig->readEntry( "Left", "" );
-    for ( int c = 0 ; c < 4 ; c ++ )
+    for ( int c = 0 ; c < 6 ; c ++ )
     if (s == s_choices[c])
       { leftComboBox->setCurrentItem( c ); break; }
     s = g_pConfig->readEntry( "Middle", "WindowListMenu" );
-    for ( int c = 0 ; c < 4 ; c ++ )
+    for ( int c = 0 ; c < 6 ; c ++ )
       if (s == s_choices[c])
       { middleComboBox->setCurrentItem( c ); break; }
     s = g_pConfig->readEntry( "Right", "DesktopMenu" );
-    for ( int c = 0 ; c < 4 ; c ++ )
+    for ( int c = 0 ; c < 6 ; c ++ )
       if (s == s_choices[c])
       { rightComboBox->setCurrentItem( c ); break; }
 
@@ -279,21 +354,25 @@ void KRootOptions::load()
     leDesktop->setText( KGlobalSettings::desktopPath() );
     leTrash->setText( KGlobalSettings::trashPath() );
     leAutostart->setText( KGlobalSettings::autostartPath() );
+    leDocument->setText( KGlobalSettings::documentPath() );
 }
 
 void KRootOptions::defaults()
 {
     showHiddenBox->setChecked(DEFAULT_SHOW_HIDDEN_ROOT_ICONS);
     VertAlignBox->setChecked(true);
-    menuBarBox->setChecked(true);
+    for (QListViewItem *item = previewListView->firstChild(); item; item = item->nextSibling())
+        static_cast<PreviewItem *>(item)->setOn(false);
+    menuBarBox->setChecked(false);
     leftComboBox->setCurrentItem( NOTHING );
     middleComboBox->setCurrentItem( WINDOWLISTMENU );
     rightComboBox->setCurrentItem( DESKTOPMENU );
 
     // Desktop Paths - keep defaults in sync with kglobalsettings.cpp
     leDesktop->setText( QDir::homeDirPath() + "/Desktop/" );
-    leTrash->setText( QDir::homeDirPath() + "/Desktop/Trash/" );
+    leTrash->setText( QDir::homeDirPath() + "/Desktop/" + i18n("Trash") + '/' );
     leAutostart->setText( KGlobal::dirs()->localkdedir() + "Autostart/" );
+    leDocument->setText( QDir::homeDirPath() );
 }
 
 void KRootOptions::save()
@@ -301,6 +380,13 @@ void KRootOptions::save()
     g_pConfig->setGroup( "Desktop Icons" );
     g_pConfig->writeEntry("ShowHidden", showHiddenBox->isChecked());
     g_pConfig->writeEntry("VertAlign",VertAlignBox->isChecked());
+    QStringList previews;
+    for ( PreviewItem *item = static_cast<PreviewItem *>( previewListView->firstChild() );
+          item;
+          item = static_cast<PreviewItem *>( item->nextSibling() ) )
+        if ( item->isOn() )
+            previews.append( item->pluginName() );
+    g_pConfig->writeEntry( "Preview", previews );
     g_pConfig->setGroup( "Menubar" );
     g_pConfig->writeEntry("ShowMenubar", menuBarBox->isChecked());
     g_pConfig->setGroup( "Mouse Buttons" );
@@ -330,6 +416,11 @@ void KRootOptions::save()
     KURL newAutostartURL;
     newAutostartURL.setPath(leAutostart->text());
 
+    KURL documentURL;
+    documentURL.setPath( KGlobalSettings::documentPath() );
+    KURL newDocumentURL;
+    newDocumentURL.setPath(leDocument->text());
+
     if ( !newDesktopURL.cmp( desktopURL, true ) )
     {
         // Test which other paths were inside this one (as it is by default)
@@ -352,7 +443,7 @@ void KRootOptions::save()
                 trashMoved = true;
             }
             // or it has been changed (->need to move it from here, unless moving the desktop does it)
-            else 
+            else
             {
                 KURL futureTrashURL;
                 futureTrashURL.setPath( leDesktop->text() + trashURL.fileName() );
@@ -416,6 +507,12 @@ void KRootOptions::save()
         }
     }
 
+    if ( !newDocumentURL.cmp( documentURL, true ) )
+    {
+        config->writeEntry( "Documents", leDocument->text(), true, true );
+        pathChanged = true;
+    }
+
     config->sync();
     g_pConfig->sync();
 
