@@ -25,25 +25,40 @@
 #ifndef __KLOCALESAMPLE_H__
 #define __KLOCALESAMPLE_H__
 
+#include <qimage.h>
 #include <qwidget.h>
 
 class QLabel;
+class QResizeEvent;
+
+class KLocaleAdvanced;
 
 class KLocaleSample : public QWidget
 {
+  Q_OBJECT
 public:
-  KLocaleSample(QWidget *parent=0, const char*name=0);
+  KLocaleSample(KLocaleAdvanced *_locale,
+		QWidget *parent=0, const char*name=0);
   ~KLocaleSample();
 
 public slots:
   void update();
 
+protected slots:
+  void slotUpdateTime();
+
+protected:
+  virtual void resizeEvent(QResizeEvent *);
+  void setBackground(const QPixmap&);
+
 private:
+  KLocaleAdvanced *locale;
   QLabel *numberSample, *labNumber;
   QLabel *moneySample, *labMoney;
   QLabel *timeSample, *labTime;
   QLabel *dateSample, *labDate;
   QLabel *dateShortSample, *labDateShort;
+  QImage bgImage;
 };
 
 #endif
