@@ -44,6 +44,7 @@
 #include <kipc.h>
 #include <klocale.h>
 #include <kio/job.h>
+#include <kio/netaccess.h>
 #include <kio/paste.h>
 #include <knewmenu.h>
 #include <konq_defaults.h>
@@ -62,10 +63,11 @@
 #include <kglobalaccel.h>
 #include <kwinmodule.h>
 #include <krun.h>
-#include <kdesktopfile.h>
+#include <ksimpleconfig.h>
 #include <kwin.h>
 #include <kstdaction.h>
 #include <kglobalsettings.h>
+#include <kpopupmenu.h>
 
 // root window hack
 #include <X11/X.h>
@@ -77,11 +79,16 @@
 #include "desktop.h"
 #include "krootwm.h"
 #include "bgmanager.h"
-#include "bgsettings.h" // Argh. Some X header conflict ?
+#include "bgsettings.h"
 
 // -----------------------------------------------------------------------------
 #define DEFAULT_DELETEACTION 1
 
+
+// for multihead - from main.cc
+extern int kdesktop_screen_number;
+
+
 KDesktop::KDesktop( bool x_root_hack, bool auto_start, bool wait_for_kded ) :
     KonqIconViewWidget( 0L, "desktop", WResizeNoErase | (x_root_hack ? (WStyle_Customize | WStyle_NoBorder) : 0), TRUE ),
     // those two WStyle_ break kdesktop when the root-hack isn't used (no Dnd)
@@ -166,8 +173,7 @@ KDesktop::KDesktop( bool x_root_hack, bool auto_start, bool wait_for_kded ) :
 
   connect(KSycoca::self(), SIGNAL(databaseChanged()), this, SLOT(slotDatabaseChanged()));
 
-  if (!m_bWaitForKded )
-     QTimer::singleShot(100, this, SLOT( slotStart()));
+  QTimer::singleShot(0, this, SLOT( slotStart()));
 
   m_dotDirectory = 0;
 
@@ -178,6 +184,7 @@ KDesktop::KDesktop( bool x_root_hack, bool auto_start, bool wait_for_kded ) :
           this, SLOT(slotSettingsChanged(int)));
   kapp->addKipcEventMask(KIPC::SettingsChanged);
 
+  kdDebug() << "KDesktop constructor -> workAreaChanged" << endl;
   workAreaChanged();
 }
 
@@ -202,8 +209,7 @@ KDesktop::slotStart()
   kdDebug() << "KDesktop::slotStart" << endl;
   if (!m_bInit) return;
 
-  if (  m_bWaitForKded )
-      kapp->dcopClient()->send( "ksplash", "", "upAndRunning(QString)", QString("kded"));
+  kapp->dcopClient()->send( "ksplash", "", "upAndRunning(QString)", QString("kdesktop"));
 
   // In case we started without database
   KImageIO::registerFormats();
@@ -239,6 +245,7 @@ KDesktop::slotStart()
 #include "kdesktopbindings.cpp"
   keys->connectItem("Execute command", this, SLOT(slotExecuteCommand()));
   keys->connectItem("Show taskmanager", this, SLOT(slotShowTaskManager()));
+  keys->connectItem("Show window list", this, SLOT(slotShowWindowList()));
 
   KAction *undo = KStdAction::undo( KonqUndoManager::self(), SLOT( undo() ), &m_actionCollection, "undo" );
   connect( KonqUndoManager::self(), SIGNAL( undoAvailable( bool ) ),
@@ -251,10 +258,11 @@ KDesktop::slotStart()
   KStdAction::copy( this, SLOT( slotCopy() ), &m_actionCollection, "copy" );
   KStdAction::paste( this, SLOT( slotPaste() ), &m_actionCollection, "paste" );
 
+  (void) new KAction( i18n( "&Rename" ), /*"editrename",*/ Key_F2, this, SLOT( renameSelectedItem() ), &m_actionCollection, "rename" );
   (void) new KAction( i18n( "&Move to Trash" ), "edittrash", Key_Delete, this, SLOT( slotTrash() ), &m_actionCollection, "trash" );
-  (void) new KAction( i18n( "&Delete" ), SHIFT+Key_Delete, this, SLOT( slotDelete() ), &m_actionCollection, "del" );
+  (void) new KAction( i18n( "&Delete" ), "editdelete", SHIFT+Key_Delete, this, SLOT( slotDelete() ), &m_actionCollection, "del" );
 
-  (void) new KAction( i18n( "&Shred" ), CTRL+SHIFT+Key_Delete, this, SLOT( slotShred() ), &m_actionCollection, "shred" );
+  (void) new KAction( i18n( "&Shred" ), "editshred", CTRL+SHIFT+Key_Delete, this, SLOT( slotShred() ), &m_actionCollection, "shred" );
 
   // Make the accels for all those actions available, through KAccel.
   m_accel = new KAccel( this );
@@ -285,11 +293,15 @@ KDesktop::slotStart()
             if ( (*it).right(1) != "~" && (*it).right(4) != ".bak" &&
                  ( (*it)[0] != '%' || (*it).right(1) != "%" ) &&
                  ( (*it)[0] != '#' || (*it).right(1) != "#" ) )
-                (void) new KRun( (*it).prepend( QString::fromLatin1( "file:" ) + dir.absPath() + '/' ), 0, true );
+            {
+                KURL url;
+                url.setPath( dir.absPath() + '/' + (*it) );
+                (void) new KRun( url, 0, true );
+            }
      }
    }
 
-  connect(kapp, SIGNAL(kdisplayFontChanged()), SLOT(slotConfigure()));
+  connect(kapp, SIGNAL(appearanceChanged()), SLOT(slotConfigure()));
 
 }
 
@@ -306,20 +318,37 @@ KDesktop::~KDesktop()
 
 void KDesktop::initConfig()
 {
-  KConfig * config = KGlobal::config();
-  config->setGroup( "Desktop Icons" );
-  m_bShowDot = config->readBoolEntry("ShowHidden", DEFAULT_SHOW_HIDDEN_ROOT_ICONS);
-  m_bVertAlign = config->readBoolEntry("VertAlign", DEFAULT_VERT_ALIGN);
-  if ( !m_bInit ) { // only when called while running - not on first startup
-    m_dirLister->setShowingDotFiles( m_bShowDot );
-    keys->readSettings();
-  }
-  m_tAlign = m_bVertAlign ? TopToBottom : LeftToRight;
-  setArrangement(m_tAlign);
+    KConfig * config = KGlobal::config();
+    config->setGroup( "Desktop Icons" );
+    m_bShowDot = config->readBoolEntry("ShowHidden", DEFAULT_SHOW_HIDDEN_ROOT_ICONS);
+    m_bVertAlign = config->readBoolEntry("VertAlign", DEFAULT_VERT_ALIGN);
+    QStringList oldPreview = m_preview;
+    m_preview = config->readListEntry( "Preview" );
 
-  KonqIconViewWidget::initConfig();
+    if ( !m_bInit ) { // only when called while running - not on first startup
+        m_dirLister->setShowingDotFiles( m_bShowDot );
+        keys->readSettings();
+    }
+    m_tAlign = m_bVertAlign ? TopToBottom : LeftToRight;
+    setArrangement(m_tAlign);
 
-  setAutoArrange( false );
+    KonqIconViewWidget::initConfig( m_bInit );
+
+    setAutoArrange( false );
+
+    if ( m_preview.count() )
+    {
+        for ( QStringList::ConstIterator it = oldPreview.begin(); it != oldPreview.end(); ++it)
+            if ( !m_preview.contains( *it ) ){
+                kdDebug() << "Disabling preview for " << *it << endl;
+                setIcons( iconSize(), (*it).latin1() /* revert no-longer wanted previews to icons */ );
+}        startImagePreview( m_preview, true );
+    }
+    else
+    {
+        stopImagePreview();
+        setIcons( iconSize(), "" /* stopImagePreview */ );
+    }
 }
 
 // -----------------------------------------------------------------------------
@@ -343,6 +372,12 @@ void KDesktop::popupExecuteCommand()
 
 // -----------------------------------------------------------------------------
 
+void KDesktop::slotShowWindowList()
+{
+     KWin::setActiveWindow( winId() );
+     KRootWm::getRootWm()->slotWindowList();
+}
+
 void KDesktop::slotShowTaskManager()
 {
 	kdDebug() << "Launching KSysGuard..." << endl;
@@ -403,7 +438,7 @@ QStringList KDesktop::selectedURLs()
 
 void KDesktop::slotConfigure()
 {
-   configure();
+    configure();
 }
 
 void KDesktop::configure()
@@ -447,6 +482,13 @@ KURL KDesktop::desktopURL()
 {
     // Support both paths and URLs
     QString desktopPath = KGlobalSettings::desktopPath();
+    QString dn = "Desktop";
+    if (kdesktop_screen_number != 0) {
+	QString dn = "Desktop";
+	dn += QString::number(kdesktop_screen_number);
+	desktopPath.replace(QRegExp("Desktop"), dn);
+    }
+
     KURL desktopURL;
     if (desktopPath[0] == '/')
         desktopURL.setPath(desktopPath);
@@ -458,7 +500,7 @@ KURL KDesktop::desktopURL()
 // -----------------------------------------------------------------------------
 void KDesktop::slotDatabaseChanged()
 {
-  kdDebug() << "KDesktop::slotDatabaseChanged" << endl;
+  //kdDebug() << "KDesktop::slotDatabaseChanged" << endl;
   if (m_bInit)
      slotStart();
   refreshMimeTypes();
@@ -598,6 +640,17 @@ void KDesktop::slotEnableAction( const char * name, bool enabled )
 
 // -----------------------------------------------------------------------------
 
+QString KDesktop::makeFriendlyText( const QString & text )
+{
+    if (text.right(7) == QString::fromLatin1(".kdelnk"))
+      return text.left(text.length() - 7);
+    else if (text.right(8) == QString::fromLatin1(".desktop"))
+      return text.left(text.length() - 8);
+    return text;
+}
+
+// -----------------------------------------------------------------------------
+
 void KDesktop::slotClear()
 {
     clear();
@@ -617,12 +670,7 @@ void KDesktop::slotNewItems( const KFileItemList & entries )
     fileIVI = new KFileIVI( this, static_cast<KonqFileItem *>(it.current()),
                             iconSize() );
     //kdDebug() << fileIVI->text() << endl;
-    QString text = fileIVI->text();
-    if (text.right(7) == QString::fromLatin1(".kdelnk"))
-      fileIVI->setText(text.left(text.length() - 7));
-    else if (text.right(8) == QString::fromLatin1(".desktop"))
-      fileIVI->setText(text.left(text.length() - 8));
-
+    fileIVI->setText( makeFriendlyText( fileIVI->text() ) );
     fileIVI->setRenameEnabled( false );
 
     if ( m_dotDirectory )
@@ -648,6 +696,7 @@ void KDesktop::slotNewItems( const KFileItemList & entries )
 
 // -----------------------------------------------------------------------------
 
+// see also KonqKfmIconView::slotRefreshItems
 void KDesktop::slotRefreshItems( const KFileItemList & entries )
 {
     kdDebug() << "KDesktop::slotRefreshItems" << endl;
@@ -662,6 +711,7 @@ void KDesktop::slotRefreshItems( const KFileItemList & entries )
             {
                 kdDebug() << "KDesktop::slotRefreshItems refreshing icon " << fileIVI->item()->url().url() << endl;
                 fileIVI->refreshIcon( true );
+                fileIVI->setText( makeFriendlyText( rit.current()->text() ) );
                 break;
             }
         }
@@ -679,6 +729,7 @@ void KDesktop::refreshIcons()
     {
         KFileIVI * fileIVI = static_cast<KFileIVI *>(it);
         fileIVI->refreshIcon( true );
+        fileIVI->setText( makeFriendlyText( fileIVI->item()->text() ) );
     }
 }
 
@@ -686,7 +737,7 @@ void KDesktop::refreshIcons()
 
 void KDesktop::slotDeleteItem( KFileItem * _fileitem )
 {
-    //kdDebug() << "KDesktop::slotDeleteItems" << endl;
+//    kdDebug() << "KDesktop::slotDeleteItems" << endl;
     // we need to find out the KFileIVI containing the fileitem
     QIconViewItem *it = firstItem();
     while ( it ) {
@@ -707,6 +758,15 @@ void KDesktop::slotDeleteItem( KFileItem * _fileitem )
           m_lastIcon->move( fileIVI->x(), fileIVI->y() );
           m_lastIcon = 0L;
         }
+
+        if ( m_dotDirectory )
+        {
+            QString group = m_iconPositionGroupPrefix;
+            group.append( fileIVI->item()->url().fileName() );
+            if ( m_dotDirectory->hasGroup( group ) )
+                m_dotDirectory->deleteGroup( group );
+        }
+
         delete fileIVI;
         break;
       }
@@ -720,7 +780,7 @@ void KDesktop::slotDeleteItem( KFileItem * _fileitem )
 void KDesktop::slotStarted()
 {
     kdDebug() << "KDesktop::slotStarted" << endl;
-    m_dotDirectory = new KDesktopFile( m_dotDirectoryPath, true );
+    m_dotDirectory = new KSimpleConfig( m_dotDirectoryPath, true );
     m_bNeedSave = false;
     m_bNeedRepaint = false;
 }
@@ -737,6 +797,14 @@ void KDesktop::slotCompleted()
       m_dotDirectory = 0;
     }
 
+    if ( m_preview.count() )
+        startImagePreview( m_preview, true );
+    else
+    {
+        stopImagePreview();
+        setIcons( iconSize(), "" /* stopImagePreview */ );
+    }
+
     kdDebug() << "KDesktop::slotCompleted " << m_bNeedSave << " " << m_bNeedRepaint << endl;
     if ( m_bNeedSave )
         slotSaveIconPositions();
@@ -767,7 +835,7 @@ void KDesktop::slotSaveDropPosition( QDropEvent *ev, const QValueList<QIconDragI
     m_lastIcon = 0L;
     if (m_bInit) return; // too early
     if (m_dotDirectory) return; // we are listing the dir...
-    m_dotDirectory = new KDesktopFile( m_dotDirectoryPath );
+    m_dotDirectory = new KSimpleConfig( m_dotDirectoryPath );
     if (ev->provides( "text/uri-list" ))
     {
         KURL::List lst;
@@ -791,19 +859,50 @@ void KDesktop::slotSaveDropPosition( QDropEvent *ev, const QValueList<QIconDragI
     m_dotDirectory = 0L;
 }
 
+
+void KDesktop::setVRoot()
+{
+    if (KWin::info(winId()).mappingState == NET::Withdrawn) {
+        QTimer::singleShot(100, this, SLOT(setVRoot()));
+        return;
+    }
+
+    unsigned long rw = RootWindowOfScreen(ScreenOfDisplay(qt_xdisplay(), qt_xscreen()));
+    unsigned long vroot_data[1] = { viewport()->winId() };
+    Atom vroot = XInternAtom(qt_xdisplay(), "__SWM_VROOT", False);
+
+    Window rootReturn, parentReturn, *children;
+    unsigned int numChildren;
+    Window top = winId();
+    while (1) {
+        /*int ret = */XQueryTree(qt_xdisplay(), top , &rootReturn, &parentReturn,
+                                 &children, &numChildren);
+        if (children)
+            XFree((char *)children);
+        if (parentReturn == rw) {
+            break;
+        } else
+            top = parentReturn;
+    }
+    XChangeProperty(qt_xdisplay(), top, vroot, XA_WINDOW, 32,
+                    PropModeReplace, (unsigned char *)vroot_data, 1);
+}
+
 // -----------------------------------------------------------------------------
 
 void KDesktop::showEvent( QShowEvent *e )
 {
-  //HACK to avoid QIconView calling arrangeItemsInGrid (Simon)
-  //EVEN MORE HACK: unfortunately, QScrollView has no concept of
-  //TopToBottom, therefore, it always adds LeftToRight.  So, if any of
-  //the icons have a setting, we'll use QScrollView.. but otherwise,
-  //we use the iconview
-  if (m_hasExistingPos)
-    QScrollView::showEvent( e );
-  else
-    KIconView::showEvent( e );
+    QTimer::singleShot(100, this, SLOT(setVRoot()));
+
+    //HACK to avoid QIconView calling arrangeItemsInGrid (Simon)
+    //EVEN MORE HACK: unfortunately, QScrollView has no concept of
+    //TopToBottom, therefore, it always adds LeftToRight.  So, if any of
+    //the icons have a setting, we'll use QScrollView.. but otherwise,
+    //we use the iconview
+    if (m_hasExistingPos)
+        QScrollView::showEvent( e );
+    else
+        KIconView::showEvent( e );
 }
 
 // -----------------------------------------------------------------------------
@@ -828,18 +927,21 @@ void KDesktop::viewportWheelEvent( QWheelEvent * e )
 
 void KDesktop::workAreaChanged()
 {
+    kdDebug() << "KDesktop::workAreaChanged() -> starting timer" << endl;
     updateWorkAreaTimer->stop();
     updateWorkAreaTimer->start( 100, TRUE );
 }
 
 void KDesktop::updateWorkArea()
 {
-
     QRect wr( kwinModule()->workArea( kwinModule()->currentDesktop() ) );
+    kdDebug() << "KDesktop::updateWorkArea wr: " << wr.x() << "," << wr.y()
+              << " " << wr.width() << "x" << wr.height() << endl;
     setMargins( wr.left(), wr.top(),
                 QApplication::desktop()->width() - wr.right() - 1,
                 QApplication::desktop()->height() - wr.bottom() - 1 );
     resizeContents( viewport()->width(), viewport()->height() );
+    kdDebug() << "resizeContents " << viewport()->width() << "x" << viewport()->height() << endl;
 
     for ( QIconViewItem *item = firstItem(); item; item = item->nextItem() ) {
         QRect r( item->rect() );
@@ -868,22 +970,42 @@ void KDesktop::contentsDropEvent(QDropEvent * e)
   }
 
   if (isColorDrag) {
+    KPopupMenu popup;
+    popup.insertItem(i18n("Set as primary background color"), 1);
+    popup.insertItem(i18n("Set as secondary background color"), 2);
+    int result = popup.exec(e->pos());
 
     QColor c;
     KColorDrag::decode(e, c);
-    bgMgr->setColor(c);
-
+    switch (result) {
+      case 1: bgMgr->setColor(c, true); break;
+      case 2: bgMgr->setColor(c, false); break;
+      default: break;
+    }
   } else if (isImageDrag) {
+    KPopupMenu popup;
+    popup.insertItem(i18n("Set as wallpaper"), 1);
+    int result = popup.exec(e->pos());
 
-    QImage i;
-    QImageDrag::decode(e, i);
-    KTempFile tmpFile;
-    tmpFile.setAutoDelete( true );
-    i.save(tmpFile.name(), "PNG");
-    bgMgr->setWallpaper(tmpFile.name(), KBackgroundSettings::Tiled);
+    if (result == 1)
+    {
+      QImage i;
+      QImageDrag::decode(e, i);
+      KTempFile tmpFile(KGlobal::dirs()->saveLocation("wallpaper"), ".png");
+      i.save(tmpFile.name(), "PNG");
+      kdDebug() << "KDesktop::contentsDropEvent " << tmpFile.name() << endl;
+      bgMgr->setWallpaper(tmpFile.name());
+    }
   }
 }
 
+void KDesktop::setWallpaper(const KURL &url)
+{
+    QString tmpFile;
+    KIO::NetAccess::download( url, tmpFile );
+    bgMgr->setWallpaper(tmpFile);
+}
+
 void KDesktop::languageChanged( const QString & lang )
 {
     kdDebug() << "KDesktop::languageChanged " << lang << endl;
@@ -941,9 +1063,10 @@ void KDesktop::languageChanged( const QString & lang )
 void KDesktop::logout()
 {
     if( !kapp->requestShutDown() )
-        KMessageBox::error( this, i18n("Could not logout properly.  The sesion manager cannot\n"
+        // this i18n string is also in kicker/applets/run/runapplet
+        KMessageBox::error( this, i18n("Could not logout properly.  The session manager cannot\n"
                                         "be contacted.  You can try to force a shutdown by pressing\n"
-                                        "the CTRL, SHIFT and BACKSPACE keys at the same time.  Note\n"
+                                        "the CTRL, ALT and BACKSPACE keys at the same time.  Note\n"
                                         "however that your current session will not be saved with a\n"
                                         "forced shutdown." ) );
 }
