@@ -14,16 +14,20 @@
 #include "kdmdesktop.h"
 #include "kdmdesktop.moc"
 
+#include <config.h>
 
 static const char *description = 
 	I18N_NOOP("Fancy desktop background for kdm");
 
-static const char *version = "v1.1";
+static const char *version = "v1.3";
 
 
 
 MyApplication::MyApplication()
-  : KApplication(), renderer(0, new KSimpleConfig(locate("config", "kdmrc")))
+  : KApplication(), 
+    renderer(0, new KSimpleConfig( 
+	KGlobal::dirs()->resourceDirs("config").last() + 
+	QString::fromLatin1("kdmrc") ))
 {
   connect(&renderer, SIGNAL(imageDone(int)), this, SLOT(renderDone()));
   renderer.start();
