@@ -26,6 +26,7 @@ class KBookmarkMenu;
 class KHelpMenu;
 class KActionCollection;
 class KActionMenu;
+class KWindowListMenu;
 
 enum {
   ITEM_HELP=100,
@@ -76,24 +77,24 @@ public slots:
   void slotToggleDesktopMenu();
   void slotUnclutterWindows();
   void slotCascadeWindows();
+  void slotWindowList();
   void slotHelp();
   void slotPaste();
   void slotLock();
   void slotLogout();
 
- private slots:
- void slotAppearanceChanged();
-    
 private:
   KDesktop* m_pDesktop;
 
-  // The three root menus :
-  QPopupMenu* windowListMenu;
+  // The five root menus :
+  KWindowListMenu* windowListMenu;
   QPopupMenu* desktopMenu;
   // the appMenu is (will be) provided by kicker
+  QPopupMenu* customMenu1;
+  QPopupMenu* customMenu2;
 
   // Configuration for the root menus :
-  typedef enum { NOTHING = 0, WINDOWLISTMENU, DESKTOPMENU, APPMENU } menuChoice;
+  typedef enum { NOTHING = 0, WINDOWLISTMENU, DESKTOPMENU, APPMENU, CUSTOMMENU1, CUSTOMMENU2 } menuChoice;
   menuChoice leftButtonChoice;
   menuChoice middleButtonChoice;
   menuChoice rightButtonChoice;
@@ -124,9 +125,7 @@ private:
 private slots:
 
   void slotMenuItemActivated(int);
-  void slotWindowItemActivated(int);
   void slotFileNewAboutToShow();
-  void generateWindowlist();
 };
 
 #endif
