@@ -21,6 +21,7 @@
 #include <qslider.h>
 #include <qwhatsthis.h>
 #include <qcstring.h>
+#include <qbitmap.h>
 
 #include <kdialog.h>
 #include <klocale.h>
@@ -42,6 +43,9 @@
 #include <kwin.h>
 #include <kdesu/stub.h>
 #include <kdesu/su.h>
+#include <kstddirs.h>
+
+#include <konq_faviconmgr.h>
 
 #include "minicli.moc"
 
@@ -59,6 +63,7 @@ Minicli::Minicli( QWidget *parent, const char *name)
     m_strCWD = QString::null;
     m_IconName = QString::null;
     m_FocusWidget = 0;
+    m_favIconMgr = new KonqFavIconMgr( this );
     loadGUI();
     KWin::setState( winId(), NET::StaysOnTop );
 }
@@ -111,7 +116,7 @@ void Minicli::loadGUI()
 	     SLOT( addToHistory( const QString& ) ) );
     label->setBuddy(m_runCombo);
     // Stop the combobox from growing and growing and...(DA)
-    m_runCombo->setFixedWidth( 0.85 * sizeHint().width() );
+    m_runCombo->setFixedWidth( int(0.85 * sizeHint().width()) );
 
     m_parseTimer = new QTimer(this);
     CHECK_PTR(m_parseTimer);
@@ -139,7 +144,7 @@ void Minicli::loadGUI()
     QPushButton *runButton = bbox->addButton(i18n("&Run"), false);
     CHECK_PTR(runButton);
     runButton->setDefault( true );
-    connect(runButton, SIGNAL(clicked()), this, SLOT(slotRunCmd()));
+    connect(runButton, SIGNAL(clicked()), this, SLOT(accept()));
 
     QPushButton *cancelButton = bbox->addButton(i18n("&Cancel"), false);
     CHECK_PTR(cancelButton);
@@ -201,8 +206,8 @@ bool Minicli::setCWD( const QString& )
 void Minicli::keyPressEvent(QKeyEvent *kev)
 {
     int a = ((QKeyEvent*)kev)->ascii();
-    // ^C, EOF, ESC
-    if (a == 3 || a == 4 || a == 27)
+    // EOF, ESC
+    if (a == 4 || a == 27)
     {
         kev->accept();
     	reject();
@@ -245,6 +250,7 @@ void Minicli::reset()
     m_runCombo->setCurrentItem( 0 );
     m_runCombo->clearEdit();
     m_runCombo->setFocus();
+    m_runCombo->reset();
     m_FocusWidget = 0;
 }
 
@@ -382,15 +388,13 @@ int Minicli::run_command()
                     kdDebug(1207) << "Executable name: " << exec << endl;
                     break;
                 }
+                case KURIFilterData::UNKNOWN:
                 case KURIFilterData::ERROR:
-                    MSGBOX_WRAPPER( KMessageBox::error( this, m_filterData->errorMsg() ); )
-                    m_runCombo->removeFromHistory( m_runCombo->currentText() );
-                    return 1;
                 default:
                     MSGBOX_WRAPPER(
-                    KMessageBox::sorry( this, i18n("<qt>The program name or command <b>%1</b>\n"
-                                                   "cannot be found.  Please correct the command\n"
-                                                   "or URL and try again</qt>").arg( cmd ) );
+                    KMessageBox::sorry( this, i18n("<qt>Could not run <b>%1</b>.<br/>"
+                                                   "The specified command or URL was "
+                                                   "not found!</qt>").arg( cmd ));
                     )
                     m_runCombo->removeFromHistory( m_runCombo->currentText() );
                     return 1;
@@ -403,8 +407,8 @@ int Minicli::run_command()
         else
         {
             MSGBOX_WRAPPER(
-            KMessageBox::sorry( this, i18n("<qt>Could not run <b>%1</b>.\nPlease correct"
-                                        " the command or URL and try again.</qt>").arg( cmd ) );
+            KMessageBox::sorry( this, i18n("<qt>Could not run <b>%1</b>.<br/>"
+                                            "The specified command does not exist!</qt>").arg( cmd ) );
             )
             m_runCombo->removeFromHistory( m_runCombo->currentText() );
             return 1; // Let the user try again...
@@ -442,18 +446,12 @@ void Minicli::slotAdvanced()
         mpAdvButton->setText(i18n("&Options >>"));
         if( m_FocusWidget && m_FocusWidget->parent() != mpAdvanced )
             m_FocusWidget->setFocus();
-    	mpAdvanced->setMaximumSize(0, 0);
+        mpAdvanced->setMaximumSize(0, 0);
         mpAdvanced->setEnabled( false );
         mpAdvanced->adjustSize();
     }
 }
 
-void Minicli::slotRunCmd()
-{
-    QKeyEvent ev( QEvent::KeyPress, Qt::Key_Enter, 13, Qt::NoButton );
-    QApplication::sendEvent( m_runCombo, &ev );
-}
-
 void Minicli::slotParseTimer()
 {
     // Change the icon according to the command type.
@@ -479,10 +477,32 @@ void Minicli::slotParseTimer()
         kdDebug(1207) << "Filtered command: " << m_filterData->uri().url() << endl;
         kdDebug(1207) << "Command line options:" << m_filterData->argsAndOptions() << endl;
         m_IconName = m_filterData->iconName();
-        if( m_IconName.isEmpty() )
+        if( m_IconName.isEmpty() || m_IconName == "unknown" )
             m_IconName = QString::fromLatin1("go");
 	}
-    m_runIcon->setPixmap( DesktopIcon( m_IconName ) );
+    QPixmap icon = DesktopIcon( m_IconName );
+    if ( m_IconName == "www" )
+    {
+        // Not using KIconEffect::overlay as that requires the same size
+        // for the icon and the overlay, also the overlay definately doesn't
+        // have a more that one-bit alpha channel here
+        QPixmap overlay( locate ( "icon", m_favIconMgr->iconForURL( m_filterData->uri().url() ) + ".png" ) );
+        if ( !overlay.isNull() )
+        {
+            int x = icon.width() - overlay.width(),
+                y = icon.height() - overlay.height();
+            if ( icon.mask() )
+            {
+                QBitmap mask = *icon.mask();
+                bitBlt( &mask, x, y, overlay.mask(),
+                        0, 0, overlay.width(), overlay.height(),
+                        overlay.mask() ? OrROP : SetROP );
+                icon.setMask(mask);
+            }
+            bitBlt( &icon, x, y, &overlay );
+        }
+    }
+    m_runIcon->setPixmap( icon );
 }
 
 
