@@ -32,6 +32,8 @@ class QCheckBox;
 class MinicliAdvanced;
 class KPasswordEdit;
 
+class KonqFavIconMgr;
+
 class Minicli : public QDialog
 {
     Q_OBJECT
@@ -56,7 +58,6 @@ protected:
 
 private slots:
     void slotCmdChanged( const QString& );
-    void slotRunCmd();
     void slotParseTimer();
     void slotAdvanced();
     int run_command();
@@ -73,6 +74,7 @@ private:
     MinicliAdvanced *mpAdvanced;
     KHistoryCombo* m_runCombo;
     KURIFilterData* m_filterData;
+    KonqFavIconMgr *m_favIconMgr;
     QWidget* m_FocusWidget;
 };
 
