@@ -1,10 +1,10 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: secure.cpp,v 1.3 2000/03/09 20:19:10 jansen Exp $
+ * $Id: secure.cpp,v 1.5 2000/06/06 14:29:57 coolo Exp $
  *
  * This file is part of the KDE project, module kdesu.
  * Copyright (C) 1999,2000 Geert Jansen <g.t.jansen@stud.tue.nl>
- * 
+ *
  * secure.cpp: Peer credentials for a UNIX socket.
  */
 
@@ -28,14 +28,14 @@
  * Under Linux, Socket_security is supported.
  */
 
-#if defined(SO_PEERCRED) 
+#if defined(SO_PEERCRED)
 
 SocketSecurity::SocketSecurity(int sockfd)
 {
     ksize_t len = sizeof(struct ucred);
     if (getsockopt(sockfd, SOL_SOCKET, SO_PEERCRED, &cred, &len) < 0) {
-	kDebugPError("getsockopt(SO_PEERCRED)");
-	return; 
+	kdError() << "getsockopt(SO_PEERCRED) " << perror << endl;
+	return;
     }
 
     ok = true;
@@ -50,12 +50,12 @@ SocketSecurity::SocketSecurity(int sockfd)
 
 SocketSecurity::SocketSecurity(int sockfd)
 {
-    kDebugWarning("Using void socket security. Please add support for your");
-    kDebugWarning("platform to kdesu/kdesud/secure.cpp");
+    kdWarning() << "Using void socket security. Please add support for your" << endl;
+    kdWarning() << "platform to kdesu/kdesud/secure.cpp" << endl;
 
     // This passes the test made in handler.cpp
     cred.uid = getuid();
     ok = true;
 }
 
-#endif 
+#endif
