@@ -1,9 +1,9 @@
     /*
 
-    $Id: kdm-config.h,v 1.18 2000/07/30 15:04:45 faure Exp $
+    $Id: kdm-config.h,v 1.27 2001/02/15 22:52:37 ossi Exp $
 
-    Copyright (C) 1997, 1998 Steffen Hansen
-                             stefh@mip.ou.dk
+    Copyright (C) 1997, 1998 Steffen Hansen <hansen@kde.org>
+    Copyright (C) 2000 Oswald Buddenhagen <ossi@kde.org>
 
 
     This program is free software; you can redistribute it and/or modify
@@ -25,19 +25,7 @@
 #ifndef KDM_CONFIG_H_
 #define KDM_CONFIG_H_
 
-#ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif
-
-#ifndef QT_CLEAN_NAMESPACE
-#define QT_CLEAN_NAMESPACE /* to avoid INT32 conflict between <qglobal.h>
-                              and <X/Xmd.h>. */ 
-#endif
-
-/* xdm stuff, should always defined */
-#define UNIXCONN          
-#define TCPCONN           
-#define GREET_USER_STATIC 
 
 #ifdef XDMBINDIR
 # define BINDIR XDMBINDIR
@@ -46,86 +34,61 @@
 #define DEF_XDM_CONFIG XDMDIR##"/xdm-config"
 #define DEF_AUTH_DIR XDMDIR##"/authdir"
 
-/* If this isn't defined, we crash boxes with S3 cards.  
- * See genauth.c  
- */ 
-#define FRAGILE_DEV_MEM 1
-
 /* Authorization stuff */
-/* How do we check for HASXDMAUTH? Use Imake ?? */
 #if defined(HAVE_KRB5_KRB5_H)
+/*# define K5AUTH*/
 #endif
 #if defined(HAVE_RPC_RPC_H) && defined(HAVE_RPC_KEY_PROT_H)
-# define SECURE_RPC 1
+/*# define SECURE_RPC*/
 #endif
 
-/* Too many systems have trouble with secure rpc,
-   so its disabled for now:
-*/
-#undef SECURE_RPC
-
 #ifdef HAVE_PATHS_H
-#include <paths.h>
-#endif
-
-#ifdef HAVE_PAM
-# define USE_PAM 1
-#else
-# ifdef HAVE_SHADOW
-#  define USESHADOW 1
-# endif
-#endif
-
-#ifdef HAVE_SYSLOG_H
- #define USE_SYSLOG
+# include <paths.h>
 #endif
 
 #ifndef _PATH_VARRUN
-#define _PATH_VARRUN "/var/run/"
+# define _PATH_VARRUN "/var/run/"
 #endif
 
 #ifndef _PATH_MEM
-#define _PATH_MEM "/dev/mem"
-#endif
-
-#ifdef sun
-#define SVR4 1
-#endif
-
-#ifdef __cplusplus
-extern "C" {
-#endif
-  /* int XdmcpAllocARRAY8(); */
-int Debug( char*, ...);
-int LogError( char*, ...);
-int LogOutOfMem( char*, ...);
-#ifdef __cplusplus
-}
-#endif
-
-#ifdef SVR4
-#define NeedVarargsPrototypes  1
+# define _PATH_MEM "/dev/mem"
 #endif
 
 /*
  * These values define what is called by KDM on Shutdown or Reboot
  * respectively. Default is /sbin/halt and /sbin/reboot
  */
-#ifdef __NetBSD__
-#define SHUTDOWN_CMD	"/sbin/shutdown -h now"
-#define REBOOT_CMD	"/sbin/shutdown -r now"
+#ifdef CSRG_BASED
+# define SHUTDOWN_CMD	"/sbin/shutdown -h now"
+# define REBOOT_CMD	"/sbin/shutdown -r now"
 #endif
 
 #ifdef __SVR4
-#define SHUTDOWN_CMD	"/usr/sbin/halt"
-#define REBOOT_CMD	"/usr/sbin/reboot"
+# define SHUTDOWN_CMD	"/usr/sbin/halt"
+# define REBOOT_CMD	"/usr/sbin/reboot"
 #endif
 
 #ifndef SHUTDOWN_CMD
-#define	SHUTDOWN_CMD	"/sbin/halt"
+# define SHUTDOWN_CMD	"/sbin/halt"
 #endif
 #ifndef REBOOT_CMD
-#define REBOOT_CMD	"/sbin/reboot"
+# define REBOOT_CMD	"/sbin/reboot"
+#endif
+
+#ifdef HAVE_SETUSERCONTEXT
+# define HAS_SETUSERCONTEXT
+#endif
+
+#ifdef HAVE_PAM
+# define USE_PAM
+#else
+# ifdef HAVE_SHADOW
+#  define USESHADOW
+# endif
+#endif
+
+#ifdef HAVE_SYSLOG_H
+# define USE_SYSLOG
 #endif
 
 #endif /* KDM_CONFIG_H */
