@@ -1,16 +1,10 @@
-/* $XConsortium: xdmauth.c,v 1.12 94/04/17 20:03:50 gildea Exp $ */
-/* $Id: xdmauth.c,v 1.3 2000/04/21 20:16:54 waba Exp $ */
+/* $TOG: xdmauth.c /main/14 1998/02/09 13:56:44 kaleb $ */
+/* $Id: xdmauth.c,v 1.4.2.1 2001/03/15 17:35:06 ossi Exp $ */
 /*
 
-Copyright (c) 1988  X Consortium
+Copyright 1988, 1998  The Open Group
 
-Permission is hereby granted, free of charge, to any person obtaining
-a copy of this software and associated documentation files (the
-"Software"), to deal in the Software without restriction, including
-without limitation the rights to use, copy, modify, merge, publish,
-distribute, sublicense, and/or sell copies of the Software, and to
-permit persons to whom the Software is furnished to do so, subject to
-the following conditions:
+All Rights Reserved.
 
 The above copyright notice and this permission notice shall be included
 in all copies or substantial portions of the Software.
@@ -18,18 +12,18 @@ in all copies or substantial portions of the Software.
 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
-IN NO EVENT SHALL THE X CONSORTIUM BE LIABLE FOR ANY CLAIM, DAMAGES OR
+IN NO EVENT SHALL THE OPEN GROUP BE LIABLE FOR ANY CLAIM, DAMAGES OR
 OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 OTHER DEALINGS IN THE SOFTWARE.
 
-Except as contained in this notice, the name of the X Consortium shall
+Except as contained in this notice, the name of The Open Group shall
 not be used in advertising or otherwise to promote the sale, use or
 other dealings in this Software without prior written authorization
-from the X Consortium.
+from The Open Group.
 
 */
-
+/* $XFree86: xc/programs/xdm/xdmauth.c,v 1.3 2000/06/07 22:03:16 tsi Exp $ */
 /*
  * xdm - display manager daemon
  * Author:  Keith Packard, MIT X Consortium
@@ -40,12 +34,15 @@ from the X Consortium.
  */
 
 #include "dm.h"
+#include "dm_auth.h"
+#include "dm_error.h"
 
 #ifdef HASXDMAUTH
 
 static char	auth_name[256];
 static int	auth_name_len;
 
+void
 XdmPrintDataHex (s, a, l)
     char	    *s;
     char	    *a;
@@ -60,6 +57,7 @@ XdmPrintDataHex (s, a, l)
 }
 
 #ifdef notdef			/* not used */
+void
 XdmPrintKey (s, k)
     char	    *s;
     XdmAuthKeyRec   *k;
@@ -69,6 +67,7 @@ XdmPrintKey (s, k)
 #endif
 
 #ifdef XDMCP
+void
 XdmPrintArray8Hex (s, a)
     char	*s;
     ARRAY8Ptr	a;
@@ -77,6 +76,7 @@ XdmPrintArray8Hex (s, a)
 }
 #endif
 
+void
 XdmInitAuth (name_len, name)
     unsigned short  name_len;
     char	    *name;
@@ -152,6 +152,7 @@ XdmGetAuth (namelen, name)
 
 #ifdef XDMCP
 
+void
 XdmGetXdmcpAuth (pdpy,authorizationNameLen, authorizationName)
     struct protoDisplay	*pdpy;
     unsigned short	authorizationNameLen;
@@ -196,7 +197,7 @@ XdmGetXdmcpAuth (pdpy,authorizationNameLen, authorizationName)
     XdmPrintDataHex ("Accept packet auth", xdmcpauth->data, xdmcpauth->data_length);
     XdmPrintDataHex ("Auth file auth", fileauth->data, fileauth->data_length);
     /* encrypt the session key for its trip back to the server */
-    XdmcpWrap (xdmcpauth->data, &pdpy->key, xdmcpauth->data, 8);
+    XdmcpWrap (xdmcpauth->data, (unsigned char *)&pdpy->key, xdmcpauth->data, 8);
     pdpy->fileAuthorization = fileauth;
     pdpy->xdmcpAuthorization = xdmcpauth;
 }
@@ -205,7 +206,7 @@ XdmGetXdmcpAuth (pdpy,authorizationNameLen, authorizationName)
 		 'a' <= c && c <= 'f' ? c - 'a' + 10 : \
 		 'A' <= c && c <= 'F' ? c - 'A' + 10 : -1)
 
-static
+static int
 HexToBinary (key)
     char    *key;
 {
@@ -236,6 +237,7 @@ HexToBinary (key)
  * routine accepts either plain ascii strings for keys, or hex-encoded numbers
  */
 
+int
 XdmGetKey (pdpy, displayID)
     struct protoDisplay	*pdpy;
     ARRAY8Ptr		displayID;
@@ -244,7 +246,7 @@ XdmGetKey (pdpy, displayID)
     char    line[1024], id[1024], key[1024];
     int	    keylen;
 
-    Debug ("Lookup key for %*.*s\n", displayID->length, displayID->length, displayID->data);
+    Debug ("Lookup key for %.*s\n", displayID->length, displayID->data);
     keys = fopen (keyFile, "r");
     if (!keys)
 	return FALSE;
@@ -277,6 +279,7 @@ XdmGetKey (pdpy, displayID)
 }
 
 /*ARGSUSED*/
+int
 XdmCheckAuthentication (pdpy, displayID, authenticationName, authenticationData)
     struct protoDisplay	*pdpy;
     ARRAY8Ptr		displayID, authenticationName, authenticationData;
@@ -287,14 +290,14 @@ XdmCheckAuthentication (pdpy, displayID, authenticationName, authenticationData)
 	return FALSE;
     if (authenticationData->length != 8)
 	return FALSE;
-    XdmcpUnwrap (authenticationData->data, &pdpy->key,
+    XdmcpUnwrap (authenticationData->data, (unsigned char *)&pdpy->key,
 		  authenticationData->data, 8);
     XdmPrintArray8Hex ("Request packet auth", authenticationData);
     if (!XdmcpCopyARRAY8(authenticationData, &pdpy->authenticationData))
 	return FALSE;
     incoming = (XdmAuthKeyPtr) authenticationData->data;
     XdmcpIncrementKey (incoming);
-    XdmcpWrap (authenticationData->data, &pdpy->key,
+    XdmcpWrap (authenticationData->data, (unsigned char *)&pdpy->key,
 		  authenticationData->data, 8);
     return TRUE;
 }
