@@ -54,13 +54,13 @@ void createHelpWindow(const QCString &appId)
   str << "Container0_SplitterSizes=30,70" << endl;
   str << "RootItem=Container0" << endl;
   str << "View1_PassiveMode=true" << endl;
-  str << "View1_ServiceName=KHelpcenter" << endl;
+  str << "View1_ServiceName=khelpcenter" << endl;
   str << "View1_ServiceType=Browser/View" << endl;
   str << "View1_URL=file:/" << endl;
   str << "View1_PassiveMode=true" << endl;
   str << "View1_LinkedView=true" << endl;
   str << "View2_PassiveMode=false" << endl;
-  str << "View2_ServiceName=KonqHTMLView" << endl;
+  str << "View2_ServiceName=khtml" << endl;
   str << "View2_ServiceType=text/html" << endl;
   str << "View2_LinkedView=true" << endl;
 
@@ -72,8 +72,6 @@ void createHelpWindow(const QCString &appId)
     url = "help:/khelpcenter/main.html";
 
   KURL _url(url);
-  _url.setProtocol("help");
-
   str << "View2_URL=" << _url.url() << endl;
 
   f.close();
@@ -105,8 +103,8 @@ static KCmdLineOptions options[] =
 int main(int argc, char *argv[])
 {
   KAboutData aboutData( "khelpcenter", I18N_NOOP("KDE HelpCenter"),
-			HELPCENTER_VERSION, I18N_NOOP("The KDE Help Center"), KAboutData::License_GPL,
-			"(c) 1999-2000, Matthias Elter");
+                        HELPCENTER_VERSION, I18N_NOOP("The KDE Help Center"), KAboutData::License_GPL,
+                        "(c) 1999-2000, Matthias Elter");
   aboutData.addAuthor("Matthias Elter",0, "me@kde.org");
 
   KCmdLineArgs::init( argc, argv, &aboutData );
@@ -129,17 +127,17 @@ int main(int argc, char *argv[])
   for (it = apps.begin(); it != apps.end(); ++it)
     if ((*it).left(9) == "konqueror")
       {
-	createHelpWindow(*it);
-	return 0;
+        createHelpWindow(*it);
+        return 0;
       }
 
   // run a new konqueror instance
   app.dcopClient()->setNotifications( true );
   QObject::connect( app.dcopClient(), SIGNAL( applicationRegistered( const QCString& ) ),
-		    &listener, SLOT( slotAppRegistered( const QCString & ) ) );
+                    &listener, SLOT( slotAppRegistered( const QCString & ) ) );
   if (app.startServiceByDesktopName("konqueror", QString::fromLatin1("--silent"), &error))
     {
-      warning("Could not launch browser:\n%s\n", error.local8Bit().data());
+      qWarning("Could not launch browser:\n%s\n", error.local8Bit().data());
       return 1;
     }
 
