@@ -27,6 +27,8 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <qdrawutil.h>
 #include <qtooltip.h>
 #include <qlineedit.h>
+#include <qtoolbutton.h>
+#include <qpopupmenu.h>
 
 #include <kconfig.h>
 #include <kwin.h>
@@ -34,11 +36,12 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <kapp.h>
 #include <kglobal.h>
 #include <klocale.h>
+#include <kdebug.h>
 #include <kprocess.h>
 #include <kwin.h>
-#include <kpopupmenu.h>
 #include <kprocess.h>
 #include <kstddirs.h>
+#include <kiconloader.h>
 #include <dcopclient.h>
 #include <netwm.h>
 
@@ -49,6 +52,9 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #undef FocusOut
 #endif
 
+const int knDesktopPreviewSize = 12;
+const int knBtnSpacing = 1;
+
 extern "C"
 {
     KPanelApplet* init(QWidget *parent, const QString& configFile)
@@ -92,7 +98,7 @@ void KMiniPagerButton::paintEvent(QPaintEvent *)
 	QPixmap pm( width() - 2, height() - 2 );
 	if (pm.isNull()) return;
 	QPainter pp( &pm, this  );
-	
+
 	pp.fillRect( pm.rect(), bg );
 	pp.setPen(fg);
 	pp.drawText(0, 0, width(), height(), AlignCenter, QString::number( deskNum ) );
@@ -123,7 +129,7 @@ void KMiniPagerButton::paintEvent(QPaintEvent *)
     }
 
     p.setPen( fg );
-	
+
     if ( pager()->mode() == KMiniPager::Number ) {
 	p.drawText(0, 0, width(), height(), AlignCenter, QString::number( deskNum ) );
     } else if ( pager()->mode() == KMiniPager::Name ) {
@@ -174,10 +180,8 @@ void KMiniPagerButton::slotClicked()
 
 void KMiniPagerButton::slotToggled( bool b )
 {
-
-    if ( !b && lineedit ) {
+    if ( !b && lineedit )
 	lineedit->hide();
-    }
 }
 
 
@@ -192,32 +196,71 @@ bool KMiniPagerButton::eventFilter( QObject *o, QEvent * e)
     return QButton::eventFilter( o, e );
 }
 
+DesktopPreviewButton::DesktopPreviewButton(QWidget *pParent, ArrowType type)
+    : QToolButton(pParent)
+{
+    m_ArrowType = type;
+    setAutoRaise(true);
+    setToggleButton(true);
+}
+
+void DesktopPreviewButton::mousePressEvent( QMouseEvent * e)
+{
+    if ( e->button() != RightButton )
+        QToolButton::mousePressEvent( e );
+    else
+        emit showMenu( e->globalPos() );
+}
+
+void DesktopPreviewButton::drawButtonLabel(QPainter * pPainter)
+{
+    int nX = 0, nY = 0;
+    if (m_ArrowType == DownArrow)
+    {
+        nY = height() - 6;
+        nX = (width() - 4) / 2 + 1;
+    }
+    else if (m_ArrowType == UpArrow)
+    {
+        nY = 6;
+        nX = (width() - 4) / 2 + 1;
+    }
+    else if (m_ArrowType == RightArrow)
+    {
+        nX = width() - 6;
+        nY = (height() - 4) / 2 + 1;
+    }
+    else // left arrow
+    {
+        nX = 6;
+        nY = (height() - 4) / 2 + 1;
+    }
+
+    if ((isDown() || isOn()) && style().guiStyle() == Qt::WindowsStyle)
+    {
+        nX++; nY++;
+    }
+
+
+    QColorGroup colgrp = QColorGroup( colorGroup().text(),
+                                      backgroundColor(),
+                                      white, black, black,
+                                      black, white );
+    qDrawArrow( pPainter, m_ArrowType, Qt::WindowsStyle, false,
+                nX, nY,
+                0, 0,
+                colgrp, false);
+}
 
 KMiniPager::KMiniPager(const QString& configFile, Type type, int actions,
 		       QWidget *parent, const char *name)
-    : KPanelApplet(configFile, type, actions, parent, name)
+    : KPanelApplet(configFile, type, actions, parent, name),
+      layout(0), m(Preview),
+      m_pBtnDesktopPreview(0), m_pDesktopPreviewFrame(0),
+      m_pBoxLayout(0), m_pPagerProcess(0)
 {
-    kwin_module = new KWinModule(this);
-    active = kwin_module->activeWindow();
-    curDesk = kwin_module->currentDesktop();
-    if (curDesk == 0) // kwin not yet launched
-	curDesk = 1;
-    layout = 0;
-    m = Preview;
-
     windows.setAutoDelete( TRUE );
 
-    allocateButtons();
-    connect(kwin_module, SIGNAL(currentDesktopChanged(int)), SLOT(slotSetDesktop(int)));
-    connect(kwin_module, SIGNAL(numberOfDesktopsChanged(int)),
-	    SLOT(slotSetDesktopCount(int)));
-    connect(kwin_module, SIGNAL(activeWindowChanged(WId)), SLOT(slotActiveWindowChanged(WId)));
-    connect( kwin_module, SIGNAL( windowAdded(WId) ), this, SLOT( slotWindowAdded(WId) ) );
-    connect( kwin_module, SIGNAL( windowRemoved(WId) ), this, SLOT( slotWindowRemoved(WId) ) );
-    connect( kwin_module, SIGNAL( windowChanged(WId,unsigned int) ), this, SLOT( slotWindowChanged(WId,unsigned int) ) );
-    connect( kwin_module, SIGNAL( stackingOrderChanged() ), this, SLOT( slotStackingOrderChanged() ) );
-    connect( kwin_module, SIGNAL( desktopNamesChanged() ), this, SLOT( slotDesktopNamesChanged() ) );
-
     KConfig *conf = config();
     conf->setGroup("minipager");
     QFont defFont("Helvetica", 10, QFont::Bold);
@@ -233,12 +276,47 @@ KMiniPager::KMiniPager(const QString& configFile, Type type, int actions,
     else
 	m = Preview;
 
+    bShowDesktopPreviewButton = conf->readBoolEntry("ShowPreviewBtn", false);
+
+    kwin_module = new KWinModule(this);
+    active = kwin_module->activeWindow();
+    curDesk = kwin_module->currentDesktop();
+    if (curDesk == 0) // kwin not yet launched
+        curDesk = 1;
+
+    allocateButtons();
+    m_pBtnDesktopPreview = new DesktopPreviewButton(this, UpArrow);
+    m_pBtnDesktopPreview->setFocusPolicy(NoFocus);
+    QToolTip::add(m_pBtnDesktopPreview, i18n("Desktop Preview"));
+
+    connect(m_pBtnDesktopPreview, SIGNAL(clicked()), SLOT(desktopPreview()) );
+    connect(m_pBtnDesktopPreview, SIGNAL(showMenu(const QPoint&)), SLOT(slotShowMenu(const QPoint&)));
+    if (!bShowDesktopPreviewButton)
+        m_pBtnDesktopPreview->hide();
+
+    connect(kwin_module, SIGNAL(currentDesktopChanged(int)), SLOT(slotSetDesktop(int)));
+    connect(kwin_module, SIGNAL(numberOfDesktopsChanged(int)),
+            SLOT(slotSetDesktopCount(int)));
+    connect(kwin_module, SIGNAL(activeWindowChanged(WId)), SLOT(slotActiveWindowChanged(WId)));
+    connect( kwin_module, SIGNAL( windowAdded(WId) ), this, SLOT( slotWindowAdded(WId) ) );
+    connect( kwin_module, SIGNAL( windowRemoved(WId) ), this, SLOT( slotWindowRemoved(WId) ) );
+    connect( kwin_module, SIGNAL( windowChanged(WId,unsigned int) ), this, SLOT( slotWindowChanged(WId,unsigned int) ) );
+    connect( kwin_module, SIGNAL( stackingOrderChanged() ), this, SLOT( slotStackingOrderChanged() ) );
+    connect( kwin_module, SIGNAL( desktopNamesChanged() ), this, SLOT( slotDesktopNamesChanged() ) );
+}
+
+KMiniPager::~KMiniPager()
+{
+    destroyDesktopPreview();
 }
 
 void KMiniPager::slotSetDesktop(int desktop)
 {
+    hideDesktopPreview();
+
     if ( curDesk == desktop )
 	return;
+
     if ( kwin_module->numberOfDesktops() > static_cast<int>(btnList.count()))
 	slotSetDesktopCount( kwin_module->numberOfDesktops() );
     btnList[curDesk-1]->setOn(false);
@@ -268,10 +346,11 @@ int KMiniPager::widthForHeight(int h) const
 	}
     }
 
-    if( h <= 32 )
-	return deskNum * bw;
-    else
-	return deskHalf * bw;
+    int nWd = ( h <= 32 ? deskNum * bw : deskHalf * bw);
+    if (bShowDesktopPreviewButton && orientation() == Horizontal)
+        nWd += knDesktopPreviewSize + knBtnSpacing;
+
+    return nWd;
 }
 
 int KMiniPager::heightForWidth(int w) const
@@ -289,10 +368,11 @@ int KMiniPager::heightForWidth(int w) const
 	small = true;
     }
 
-    if( small )
-	return deskNum * bh;
-    else
-	return deskHalf * bh;
+    int nHg = ( small ? deskNum * bh : deskHalf * bh);
+    if (bShowDesktopPreviewButton && orientation() != Horizontal)
+        nHg += knDesktopPreviewSize + knBtnSpacing;
+
+    return nHg;
 }
 
 void KMiniPager::resizeEvent(QResizeEvent*)
@@ -305,18 +385,63 @@ void KMiniPager::resizeEvent(QResizeEvent*)
     if ( !horiz && mode() == KMiniPager::Name )
 	small = TRUE;
 
-    delete layout;
+    if (m_pBoxLayout)
+    {
+        delete m_pBoxLayout;
+        m_pBoxLayout = 0;
+    }
+    else if (layout)
+    {
+        delete layout;
+        layout = 0;
+    }
 
-    if(horiz) {
-	if (small)
-	    layout = new QGridLayout(this, 1, deskNum);
-	else
-	    layout = new QGridLayout(this, 2, deskHalf);
-    } else  {
-	if (small)
-	    layout = new QGridLayout(this, deskNum, 1);
-	else
-	    layout = new QGridLayout(this, deskHalf, 2);
+    int nDX, nDY;
+    if(horiz)
+    {
+        if (small)
+	    nDX = 1, nDY = deskNum;
+        else
+	    nDX = 2, nDY = deskHalf;
+        if (bShowDesktopPreviewButton)
+            m_pBoxLayout = new QHBoxLayout(this);
+    }
+    else
+    {
+        if (small)
+	    nDX = deskNum, nDY = 1;
+        else
+	    nDX = deskHalf, nDY = 2;
+        if (bShowDesktopPreviewButton)
+            m_pBoxLayout = new QVBoxLayout(this);
+    }
+
+    if (m_pBoxLayout && m_pBtnDesktopPreview)
+    {
+        ArrowType at;
+
+        if (horiz)
+        {
+            at = (popupDirection() == Down ? DownArrow : UpArrow);
+            m_pBtnDesktopPreview->setMinimumSize(knDesktopPreviewSize, 1);
+            m_pBtnDesktopPreview->setMaximumSize(knDesktopPreviewSize, 1024);
+        }
+        else // o == Vertical
+        {
+            at = (popupDirection() == Right ? RightArrow : LeftArrow);
+            m_pBtnDesktopPreview->setMinimumSize(1, knDesktopPreviewSize);
+            m_pBtnDesktopPreview->setMaximumSize(1024, knDesktopPreviewSize);
+        }
+        m_pBtnDesktopPreview->setArrowType(at);
+
+        m_pBoxLayout->addWidget(m_pBtnDesktopPreview);
+        m_pBoxLayout->addSpacing(knBtnSpacing);
+
+        layout = new QGridLayout(m_pBoxLayout, nDX, nDY);
+    }
+    else
+    {
+        layout = new QGridLayout(this, nDX, nDY);
     }
 
     int c = 0;
@@ -349,6 +474,8 @@ void KMiniPager::resizeEvent(QResizeEvent*)
     }
 
     layout->activate();
+    if (m_pBoxLayout)
+        m_pBoxLayout->activate();
     updateGeometry();
 }
 
@@ -357,7 +484,7 @@ void KMiniPager::allocateButtons()
     int i;
     int deskNum = kwin_module->numberOfDesktops();
     int act = kwin_module->currentDesktop();
-    KMiniPagerButton *btn;
+		KMiniPagerButton *btn;
     for (i=1; i <= deskNum; ++i) {
 	btn = new KMiniPagerButton(i, this);
 	btn->setOn(i == act);
@@ -382,10 +509,20 @@ void KMiniPager::slotSetDesktopCount(int )
 	curDesk = 1;
     resizeEvent(0);
     updateLayout();
+
+    // create desktop preview here
+    static bool bFirst = true;
+    if (bFirst && bShowDesktopPreviewButton)
+    {
+        bFirst = false;
+        createDesktopPreview();
+    }
 }
 
 void KMiniPager::slotActiveWindowChanged( WId win )
 {
+    hideDesktopPreview();
+
     if ( m != Preview )
 	return;
     KWin::Info* inf1 = info( active );
@@ -400,6 +537,8 @@ void KMiniPager::slotActiveWindowChanged( WId win )
 
 void KMiniPager::slotWindowAdded( WId win)
 {
+    hideDesktopPreview();
+
     if ( m != Preview )
 	return;
     KWin::Info* inf = info( win );
@@ -407,8 +546,6 @@ void KMiniPager::slotWindowAdded( WId win)
 	if ( inf->onAllDesktops || inf->desktop == i )
 	    btnList[i-1]->update();
     }
-
-
 }
 
 void KMiniPager::slotWindowRemoved( WId win )
@@ -454,6 +591,8 @@ KWin::Info* KMiniPager::info( WId win )
 
 void KMiniPager::slotStackingOrderChanged()
 {
+	hideDesktopPreview();
+
     if ( m != Preview )
 	return;
     slotRefresh();
@@ -467,40 +606,64 @@ void KMiniPager::slotRefresh()
 
 void KMiniPager::slotShowMenu( const QPoint& pos )
 {
-    KPopupMenu* p = new KPopupMenu;
-    p->insertTitle( i18n("Display Desktops As") );
+    QPopupMenu* p = new QPopupMenu;
     p->setCheckable( TRUE );
     p->insertItem( i18n("Preview"), KMiniPager::Preview );
     p->insertItem( i18n("Number"), KMiniPager::Number );
     p->insertItem( i18n("Name"), KMiniPager::Name );
     p->insertSeparator();
-    p->insertItem( i18n("Configure..."), 99);
+    p->insertItem( i18n("Enable Desktop Preview"), 98);
+    p->insertSeparator();
+    p->insertItem( SmallIcon("configure"), i18n("&Preferences..."), 99);
     p->setItemChecked( m, TRUE  );
+    p->setItemChecked(98, bShowDesktopPreviewButton);
 
     int result = p->exec( pos );
     delete p;
     if ( result <= 0 || result == m )
-	return;
+        return;
+
     if (result == 99)
-      {
-	preferences();
-	return;
-      }
-    m = (KMiniPager::Mode)result;
-    KConfig *conf = config();
+    {
+        preferences();
+        return;
+    }
+    KConfig* conf = config();
     conf->setGroup("minipager");
-    if ( m == Number )
-	conf->writeEntry( "Mode", "Number" );
-    else if ( m == Name )
-	conf->writeEntry( "Mode", "Name" );
+
+    if(result == 98)
+    {
+        bShowDesktopPreviewButton = !bShowDesktopPreviewButton;
+        conf->writeEntry( "ShowPreviewBtn", bShowDesktopPreviewButton);
+        resizeEvent(0);
+        if (bShowDesktopPreviewButton)
+        {
+            m_pBtnDesktopPreview->show();
+            createDesktopPreview();
+        }
+        else
+        {
+            destroyDesktopPreview();
+            delete m_pDesktopPreviewFrame;
+            m_pDesktopPreviewFrame = 0L;
+            m_pBtnDesktopPreview->hide();
+        }
+    }
     else
-	conf->writeEntry( "Mode", "Preview" );
+    {
+        m = (KMiniPager::Mode)result;
+        if ( m == Number )
+            conf->writeEntry( "Mode", "Number" );
+        else if ( m == Name )
+            conf->writeEntry( "Mode", "Name" );
+        else
+            conf->writeEntry( "Mode", "Preview" );
+    }
 
     conf->sync();
-	
+
     slotRefresh();
     emit updateLayout();
-
 }
 
 void KMiniPager::slotDesktopNamesChanged()
@@ -520,8 +683,165 @@ void KMiniPager::slotDesktopNamesChanged()
 
 void KMiniPager::preferences()
 {
-  KProcess proc;
-  proc << locate("exe", "kcmshell");
-  proc << "LookNFeel/Desktop/virtualdesktops";
-  proc.start(KProcess::DontCare);
+  kapp->startServiceByDesktopName("virtualdesktops");
 }
+
+QDesktopPreviewFrame::QDesktopPreviewFrame(KMiniPager *pPager)
+    : QFrame(0, 0, WStyle_Customize | WStyle_NoBorder | WStyle_StaysOnTop | WStyle_Dialog)
+{
+    m_pPager = pPager;
+
+    // Set the wm flags to this window
+    KWin::setState( winId(), NET::StaysOnTop | NET::SkipTaskbar);
+}
+
+void QDesktopPreviewFrame::keyPressEvent(QKeyEvent *evt)
+{
+    if (isVisible())
+    {
+        m_pPager->hideDesktopPreview();
+    }
+    QFrame::keyPressEvent(evt);
+}
+
+void KMiniPager::hideDesktopPreview()
+{
+    if (m_pDesktopPreviewFrame && m_pDesktopPreviewFrame->isVisible())
+    {
+        m_pDesktopPreviewFrame->hide();
+        m_pBtnDesktopPreview->setOn(false);
+    }
+}
+
+void KMiniPager::desktopPreviewProcessExited(KProcess *p)
+{
+    kdDebug() << "KMiniPager::desktopPreviewProcessExited" << endl;
+    if (m_pPagerProcess == p)
+    {
+        delete m_pPagerProcess;
+        m_pPagerProcess = 0;
+
+        hideDesktopPreview();
+        delete m_pDesktopPreviewFrame;
+        m_pDesktopPreviewFrame = 0;
+    }
+}
+
+void KMiniPager::destroyDesktopPreview()
+{
+    if (m_pPagerProcess)
+        m_pPagerProcess->kill();
+}
+
+QSize KMiniPager::calculateDesktopPreviewFrameSize() const
+{
+    int w = QApplication::desktop()->width();
+    int h = QApplication::desktop()->height();
+
+    int nHg = 120; // two rows always
+    int nNumColumns = (kwin_module->numberOfDesktops() + 1) / 2;
+
+    // take into account an internal borders
+    int nWdCorr = 6 + (nNumColumns) * 2;
+    if (nNumColumns <= 3)
+        nWdCorr--;
+
+    int nWd = (60 * nNumColumns * w) / h + nWdCorr;
+    return QSize(nWd, nHg);
+}
+
+void KMiniPager::createDesktopPreview()
+{
+    // create desktop preview frame
+    if (!m_pDesktopPreviewFrame)
+    {
+        m_pDesktopPreviewFrame = new QDesktopPreviewFrame(this);
+        m_pDesktopPreviewFrame->setFrameStyle(QFrame::Panel| QFrame::Raised);
+        m_pDesktopPreviewFrame->hide();
+
+        m_pDesktopPreviewFrame->resize(calculateDesktopPreviewFrameSize());
+
+        QString strAppPath(locate("exe", "kpager"));
+        if (!strAppPath.isEmpty())
+        {
+            KProcess * process = new KProcess();
+            if (!process)
+                return;
+
+            // set executable
+            *process << strAppPath;
+
+            // set parameters
+            *process << "-parent";
+            *process << QString().setNum(m_pDesktopPreviewFrame->winId());
+
+            QObject::connect(process, SIGNAL(processExited(KProcess *)),
+                             this, SLOT(desktopPreviewProcessExited(KProcess *)));
+
+            // start process with a link to StdIn for oneway comm.
+            process->start(KProcess::NotifyOnExit);
+            m_pPagerProcess = process;
+        }
+    }
+}
+
+void KMiniPager::desktopPreview()
+{
+    createDesktopPreview();
+
+    if (m_pDesktopPreviewFrame)
+    {
+        if (!m_pDesktopPreviewFrame->isVisible())
+        {
+            // calculate correct frame position
+            int w = QApplication::desktop()->width();
+            int h = QApplication::desktop()->height();
+            QPoint btnPos(m_pBtnDesktopPreview->mapToGlobal(m_pBtnDesktopPreview->pos()));
+
+            QSize frmSz(calculateDesktopPreviewFrameSize());
+
+            int nX, nY;
+            if (orientation() == Horizontal)
+            {
+                nX = w - frmSz.width();
+                if (nX > btnPos.x())
+                    nX = btnPos.x();
+
+                if (popupDirection() == Down)
+                {
+                    nY = height() + 1;
+                }
+                else
+                {
+                    nY = h - height() - frmSz.height() - 2;
+                }
+            }
+            else // orientation == vertical
+            {
+                nY = h - frmSz.height();
+                if (nY > btnPos.y())
+                    nY = btnPos.y();
+
+                if (popupDirection() == Right)
+                {
+                    nX = width() + 1;
+                }
+                else
+                {
+                    nX = w - width() - frmSz.width() -1;
+                }
+            }
+
+            m_pDesktopPreviewFrame->setGeometry(nX, nY, frmSz.width(), frmSz.height());
+
+            m_pDesktopPreviewFrame->show();
+            m_pDesktopPreviewFrame->setFocus();
+            KWin::setActiveWindow(m_pDesktopPreviewFrame->winId());
+        }
+        else
+        {
+            m_pDesktopPreviewFrame->hide();
+        }
+    }
+}
+
