@@ -43,18 +43,20 @@ BaseContainer::BaseContainer(QWidget *parent)
 
 BaseContainer::~BaseContainer()
 {
-  delete _opMnu;
+    delete _opMnu;
 }
 
 QPoint BaseContainer::getPopupPosition(QPopupMenu *menu, QPoint eventpos)
 {
-  switch (_dir) {
-  case dDown: return(mapToGlobal(QPoint(eventpos.x(), height())));
-  case dUp: return(mapToGlobal(QPoint(eventpos.x(), 0 - menu->height())));
-  case dLeft: return(mapToGlobal(QPoint(0-menu->width(), eventpos.y())));
-  case dRight: return(mapToGlobal(QPoint(width(), eventpos.y())));
-  }
-  return eventpos;
+    QPoint gpos = mapToGlobal(eventpos);
+
+    switch (_dir) {
+        case dDown: return(QPoint(gpos.x(), topLevelWidget()->height() + topLevelWidget()->pos().y()));
+        case dUp: return(QPoint(gpos.x(), topLevelWidget()->pos().y() - menu->height()));
+        case dLeft: return(QPoint(topLevelWidget()->pos().x() - menu->width(), gpos.y()));
+        case dRight: return(QPoint(topLevelWidget()->width() + topLevelWidget()->pos().x(), gpos.y()));
+    }
+    return eventpos;
 }
 
 void BaseContainer::removeRequest()
