@@ -25,8 +25,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #define __containerarea_h__
 
 #include <qlist.h>
-
-#include <dcopobject.h>
+#include <qtimer.h>
 
 #include "global.h"
 #include "panner.h"
@@ -34,43 +33,47 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include "appletinfo.h"
 
 class ExternalAppletContainer;
+class KConfig;
+class DragIndicator;
 
-class ContainerArea : public Panner, DCOPObject
+class ContainerArea : public Panner
 {
     Q_OBJECT
-    K_DCOP
 
 public:
-    ContainerArea( Orientation orientation, QWidget* parent, const char* name = 0);
+    ContainerArea(Orientation orientation, bool mainArea, KConfig* config, QWidget* parent, const char* name = 0);
     ~ContainerArea();
-
-k_dcop:
-    int position();
-    int orientation();
-    int popupDirection();
-   void addApplet( const QString& desktopFile );
+    void init();
 
 public:
+    int position() const;
+    int orientation() const;
+    int popupDirection() const;
 
     void addKMenuButton();
     void addDesktopButton();
     void addWindowListButton();
     void addURLButton(const QString &url);
     void addBrowserButton(const QString &startDir);
+    void addServiceMenuButton(const QString &name, const QString& relPath);
     void addExeButton(const QString &filePath, const QString &icon,
 		      const QString &cmdLine, bool inTerm);
 
-    void addAppletContainer(const QString &desktopFile, bool internal);
+    void addApplet( const QString& desktopFile );
+    void addApplet(const QString &desktopFile, bool internal);
 
     void configure();
 
-    bool hasInstance(AppletInfo*);
+    bool hasInstance(AppletInfo*) const;
 
-    bool inMoveOperation() { return _movingAC; }
+    bool inMoveOperation() const { return _movingAC; }
 
 public slots:
     void startContainerMove(BaseContainer *a);
     void stopContainerMove(BaseContainer *a);
+    void setPosition(Position p);
+    void slotLayoutChildren();
+    void slotSaveContainerConfig();
 
 protected:
     void layoutChildren();
@@ -78,15 +81,19 @@ protected:
     BaseContainer* coversContainer(BaseContainer *a, bool strict);
 
     void updateContainerList();
-    int relativeContainerPos(BaseContainer* a);
-    int totalFreeSpace();
-    int minimumUsedSpace();
+    int relativeContainerPos(BaseContainer*) const;
+    int totalFreeSpace() const;
+    int minimumUsedSpace() const;
 
     void mouseMoveEvent(QMouseEvent *);
     void mouseReleaseEvent(QMouseEvent *);
 
-    void dragEnterEvent(QDragEnterEvent *ev);
-    void dropEvent(QDropEvent *ev);
+    void dragEnterEvent(QDragEnterEvent*);
+    void dragMoveEvent(QDragMoveEvent*);
+    void dragLeaveEvent(QDragLeaveEvent*);
+    void dropEvent(QDropEvent*);
+
+    virtual void resizeEvent(QResizeEvent *);
 
     void addContainer(BaseContainer* a);
     void removeContainer(BaseContainer *a);
@@ -95,30 +102,68 @@ protected:
     void setUniqueId(BaseContainer* a);
     void moveToFirstFreePosition(BaseContainer* a);
 
-    bool isStretch(BaseContainer* a);
+    bool isStretch(BaseContainer* a) const;
+    void disableStretch();
+    void restoreStretch();
 
     void saveContainerConfig(bool layoutOnly = false);
     void loadContainerConfig();
     void defaultContainerConfig();
 
     void moveContainerSwitch(BaseContainer* a, int distance);
-    void moveContainerPush(BaseContainer* a, int distanceRequest);
-    int moveContainerPushRec(QListIterator<BaseContainer> it, int distanceRequest);
+    int moveContainerPush(BaseContainer* a, int distance);
+
+    int moveContainerPushRecursive(QListIterator<BaseContainer> it, int distanceRequest);
+
+    QRect availableSpaceFollowing(BaseContainer*);
+    void moveDragIndicator(int pos);
+
+    void setBackgroundTheme();
+
+    void scrollTo(BaseContainer*);
+
+    KConfig* config() { return _config; }
 
 protected slots:
     void embeddedWindowDestroyed();
-    void slotSaveContainerConfig();
     void slotRemoveContainer(BaseContainer*);
-    void slotLayoutChildren();
     void slotAddExternal(ExternalAppletContainer*);
+    void autoScroll();
 
 private:
     QList<BaseContainer> _containers;
 
-    bool _block_relayout;
-    bool _movingAC;
-    BaseContainer *_moveAC;
-    QPoint _moveOffset;
+    bool	    _block_relayout;
+    bool	    _movingAC;
+    BaseContainer*  _moveAC;
+    QPoint	    _moveOffset;
+    Position	    _pos;
+    bool	    _mainArea;
+    KConfig*	    _config;
+    DragIndicator*  _dragIndicator;
+    BaseContainer*  _dragMoveAC;
+    QPoint	    _dragMoveOffset;
+    QTimer          _autoScrollTimer;
+};
+
+class DragIndicator : public QWidget
+{
+    Q_OBJECT
+
+public:
+    DragIndicator(QWidget* parent = 0, const char* name = 0)
+	: QWidget(parent, name) {;}
+    ~DragIndicator() {;}
+
+    QSize preferredSize() const { return _preferredSize; }
+    void setPreferredSize(const QSize& size) { _preferredSize = size; }
+
+protected:
+    void paintEvent(QPaintEvent*);
+    void mousePressEvent(QMouseEvent*);
+
+private:
+    QSize _preferredSize;
 };
 
 #endif
