@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- *	$Id: gopher.cc,v 1.16 2000/08/05 18:13:59 garbanzo Exp $
+ *	$Id: gopher.cc,v 1.19 2001/01/15 18:49:29 porten Exp $
  */
 
 #include <sys/types.h>
@@ -57,8 +57,6 @@
 
 #include "gopher.h"
 
-#include <iostream.h>
-
 
 using namespace KIO;
 
@@ -242,7 +240,7 @@ void GopherProtocol::listDir( const KURL &dest )
       break;
     }
     default: {
-      atom.m_str="application/ocet-stream";
+      atom.m_str="application/octet-stream";
       break;
     }
     }
@@ -298,7 +296,6 @@ void GopherProtocol::get(const KURL &usrc)
   path = usrc.path();
 
   if (path == "/aboutme.txt") {
-    gettingFile(usrc.url());
     mimeType("text/plain");
     array.setRawData(GopherProtocol::abouttext, strlen(GopherProtocol::abouttext));
     data(array);
@@ -360,7 +357,6 @@ bool GopherProtocol::readRawData(const QString &_url, const char *mimetype)
 {
   QByteArray array;
   char buf[1024];
-  gettingFile(_url);
   mimeType(mimetype);
   ssize_t read_ret=0;
   size_t total_size=0;
