@@ -24,10 +24,10 @@ void Url::splitString(QString q, char c, QStrList &list)
   while ( (pos = q.find(c)) >= 0)
     {
       item = q.left(pos);
-      list.append(item);
+      list.append(item.local8Bit());
       q.remove(0,pos+1);
     }
-  list.append(q);
+  list.append(q.local8Bit());
 }
 
 
@@ -40,6 +40,9 @@ void Url::parseLDAP()
 
   // parse the query  
   QString q = query();
+  // remove first ?
+  if (!q.isEmpty() && q.left(1) == "?")
+    q.remove(0,1);
 
   // split into a list
   QStrList url_items;
@@ -85,7 +88,7 @@ QStrList &Url::attributes()
     {
       QString item(it);
       item = decode_string(item);
-      _attr_decoded.append(item);
+      _attr_decoded.append(item.latin1());
     }
   
   return _attr_decoded;
