@@ -1,4 +1,7 @@
 /*  This file is part of the KDE project
+
+    $Id: kio_nfs.cpp,v 1.19 2001/01/16 08:20:45 garbanzo Exp $
+
     Copyright (C) 2000 Alexander Neundorf <neundorf@kde.org>
 
     This library is free software; you can redistribute it and/or
@@ -21,45 +24,44 @@
 #include <config.h>
 #endif
 
-#include <iostream.h>
-
-#include <pwd.h>
-#include <grp.h>
-#include <stdio.h>
+#include <sys/types.h>
 #include <sys/stat.h>
+#include <sys/utsname.h>
+
+#include <arpa/inet.h>
 
 // This is needed on Solaris so that rpc.h defines clnttcp_create etc.
 #ifndef PORTMAP
 #define PORTMAP
 #endif
-#include <rpc/rpc.h> // for clnt_call etc.
+#include <rpc/rpc.h> // for rpc calls
 
-#ifdef HAVE_STRING_H
-#include <string.h>
-#else
-#include <strings.h>
-#endif
-#include <sys/types.h>
-#include <unistd.h>
-#include <memory.h>
-#include <stdlib.h>
-
-#include <netdb.h>
-#include <arpa/inet.h>
 #include <errno.h>
+#include <grp.h>
+#include <memory.h>
+#include <netdb.h>
+#include <pwd.h>
+#include <stdlib.h>
+#include <strings.h>
+#include <stdio.h>
+#include <time.h>
+#include <unistd.h>
+
+#include <iostream.h>
+
+#include <qfile.h>
+#include <qdir.h>
+
+#include <kdebug.h>
+#include <kinstance.h>
+#include <klocale.h>
+
+#include <kio/global.h>
 
 #include "nfs_prot.h"
 #define fhandle _fhandle
 #include "mount.h"
-#include <time.h>
 #include "kio_nfs.h"
-#include <kinstance.h>
-#include <kdebug.h>
-#include <kio/global.h>
-#include <klocale.h>
-
-#include <qfile.h>
-#include <qdir.h>
 
 #define MAXHOSTLEN 256
 
@@ -73,12 +75,6 @@
 //this is taken from kdelibs/kdecore/fakes.cpp
 //#if !defined(HAVE_GETDOMAINNAME)
 
-#include <sys/utsname.h> 
-#include <netdb.h>
-#include <strings.h>
-#include <errno.h>
-#include <stdio.h>
-
 int x_getdomainname(char *name, size_t len)
 {
    struct utsname uts;
@@ -209,8 +205,8 @@ time_t NFSFileHandle::age() const
 ostream& operator<< (ostream& s, const NFSFileHandle& x)
 {
    for (int i =0; i<NFS_FHSIZE; i++)
-      s<<hex<<(unsigned int)x[i]<<" ";
-   s<<dec;
+      s<<iostream::hex<<(unsigned int)x[i]<<" ";
+   s<<iostream::dec;
    return s;
 }
 
@@ -262,7 +258,7 @@ void NFSProtocol::closeConnection()
    m_sock=-1;
    if (m_client==0) return;
    CLNT_DESTROY(m_client);
-   
+
    m_client=0;
 };
 
@@ -376,35 +372,32 @@ void NFSProtocol::openConnection()
       m_client = clntudp_create(&server_addr,MOUNTPROG, MOUNTVERS, pertry_timeout, &m_sock);
       if (m_client==0)
       {
-         clnt_pcreateerror("mount clntudp_create");
-         error( ERR_COULD_NOT_CONNECT, m_currentHost.latin1());
+         clnt_pcreateerror(const_cast<char *>("mount clntudp_create"));
+         error(ERR_COULD_NOT_CONNECT, m_currentHost.latin1());
          return;
       }
    }
    QCString hostName("localhost");
    char nameBuffer[1024];
-   if (gethostname(nameBuffer,1024)==0)
-   {
+   if (gethostname(nameBuffer, 1024)==0) {
       hostName=nameBuffer;
       // I have the same problem here as Stefan Westerfeld, that's why I use
       // the getdomainname() from fakes.cpp (renamed to x_getdomainname()), this one works
       // taken from kdelibs/arts/mcopy/mcoputils.cc
-      if (x_getdomainname(nameBuffer,1024)==0)
-      {
+      if (x_getdomainname(nameBuffer, 1024)==0) {
          /*
           * I don't know why, but on my linux machine, the domainname
           * always ends up being (none), which is certainly no valid
           * domainname
           */
-         if(strcmp(nameBuffer,"(none)") != 0)
-         {
+         if(strcmp(nameBuffer,"(none)") != 0) {
             hostName += ".";
             hostName += nameBuffer;
          }
       }
    };
-   kdDebug(7101)<<"hostname is -"<<hostName<<"-"<<endl;
-   m_client->cl_auth = authunix_create(hostName.data(),geteuid(),getegid(),0,0);
+   kdDebug(7101) << "hostname is -" << hostName << "-" << endl;
+   m_client->cl_auth = authunix_create(hostName.data(), geteuid(), getegid(), 0, 0);
    total_timeout.tv_sec = 20;
    total_timeout.tv_usec = 0;
 
@@ -414,31 +407,31 @@ void NFSProtocol::openConnection()
 
    int clnt_stat = clnt_call(m_client, MOUNTPROC_EXPORT,(xdrproc_t) xdr_void, NULL,
                          (xdrproc_t) xdr_exports, (char*)&exportlist,total_timeout);
-   if (!checkForError(clnt_stat,0,m_currentHost.latin1())) return;
+   if (!checkForError(clnt_stat, 0, m_currentHost.latin1())) return;
 
    fhstatus fhStatus;
-   for(; exportlist!=0;exportlist = exportlist->ex_next)
-   {
-      kdDebug(7101)<<"found export: "<<exportlist->ex_dir<<endl;
+   bool atLeastOnceSucceeded(FALSE);
+   for(; exportlist!=0;exportlist = exportlist->ex_next) {
+      kdDebug(7101) << "found export: " << exportlist->ex_dir << endl;
 
-      memset(&fhStatus,0,sizeof(fhStatus));
+      memset(&fhStatus, 0, sizeof(fhStatus));
       clnt_stat = clnt_call(m_client, MOUNTPROC_MNT,(xdrproc_t) xdr_dirpath, (char*)(&(exportlist->ex_dir)),
                             (xdrproc_t) xdr_fhstatus,(char*) &fhStatus,total_timeout);
-      if (fhStatus.fhs_status==0)
-      {
+      if (fhStatus.fhs_status==0) {
+         atLeastOnceSucceeded=TRUE;
          NFSFileHandle fh;
          fh=fhStatus.fhstatus_u.fhs_fhandle;
          m_handleCache.insert(QString("/")+KIO::encodeFileName(exportlist->ex_dir),fh);
          m_exportedDirs.append(KIO::encodeFileName(exportlist->ex_dir));
          //cerr<<"appending file -"<<KIO::encodeFileName(exportlist->ex_dir).latin1()<<"- with FH: -"<<fhStatus.fhstatus_u.fhs_fhandle<<"-"<<endl;
-      }
-      else
-      {
-         closeConnection();
-         error( ERR_COULD_NOT_AUTHENTICATE, m_currentHost.latin1());
-         return;
       };
    }
+   if (!atLeastOnceSucceeded)
+   {
+      closeConnection();
+      error( ERR_COULD_NOT_AUTHENTICATE, m_currentHost.latin1());
+      return;
+   };
    server_addr.sin_port = 0;
 
    //now create the client for the nfs daemon
@@ -758,7 +751,7 @@ void NFSProtocol::completeAbsoluteLinkUDSEntry(UDSEntry& entry, const QCString&
 	atom.m_uds = KIO::UDS_FILE_TYPE;
 	atom.m_long = buff.st_mode & S_IFMT; // extract file type
 	entry.append( atom );
-	
+
 	atom.m_uds = KIO::UDS_ACCESS;
 	atom.m_long = buff.st_mode & 07777; // extract permissions
 	entry.append( atom );
@@ -821,7 +814,7 @@ void NFSProtocol::completeBadLinkUDSEntry(UDSEntry& entry, fattr& attributes)
 {
    // It is a link pointing to nowhere
    completeUDSEntry(entry,attributes);
-   
+
    UDSAtom atom;
    atom.m_uds = KIO::UDS_FILE_TYPE;
    atom.m_long = S_IFMT - 1;
@@ -989,6 +982,7 @@ bool NFSProtocol::checkForError(int clientStat, int nfsStat, const QString& text
    if (clientStat!=RPC_SUCCESS)
    {
       kdDebug(7101)<<"rpc error: "<<clientStat<<endl;
+      //does this mapping make sense ?
       error(ERR_CONNECTION_BROKEN,i18n("A RPC error occured"));
       return FALSE;
    };
@@ -1350,7 +1344,7 @@ void NFSProtocol::rename( const KURL &src, const KURL &dest, bool _overwrite )
    stripTrailingSlash(srcPath);
    stripTrailingSlash(destPath);
    kdDebug(7101)<<"renaming -"<<srcPath<<"- to -"<<destPath<<"-"<<endl;
-      
+
    if (isRoot(srcPath) || isExportedDir(srcPath))
    {
       error(ERR_CANNOT_RENAME,srcPath);
@@ -1544,7 +1538,7 @@ void NFSProtocol::symlink( const QString &target, const KURL &dest, bool )
       error(ERR_ACCESS_DENIED,destPath);
       return;
    };
-   
+
    kdDebug(7101)<<"tach"<<endl;
    QCString tmpStr=target.latin1();
    symlinkargs symLinkArgs;
@@ -1560,7 +1554,7 @@ void NFSProtocol::symlink( const QString &target, const KURL &dest, bool )
    if (!checkForError(clnt_stat,nfsStat,destPath)) return;
 
    finished();
-      
+
 };
 
 bool NFSProtocol::isValidLink(const QString& parentDir, const QString& linkDest)
