@@ -2,7 +2,7 @@
 
    configdialog.h (part of Klipper - Cut & paste history for KDE)
 
-   $Id: configdialog.h,v 1.4 2000/07/05 22:01:06 faure Exp $
+   $Id: configdialog.h,v 1.9 2001/01/15 23:55:48 pfeiffer Exp $
 
    (C) 2000 by Carsten Pfeiffer <pfeiffer@kde.org>
 
@@ -19,12 +19,14 @@
 #include <qvgroupbox.h>
 
 #include <kdialogbase.h>
+#include <keditlistbox.h>
 #include <kkeydialog.h>
+#include <knuminput.h>
 
 #include "urlgrabber.h"
 
 class KGlobalAccel;
-class KEditableListView;
+class KListView;
 
 class GeneralWidget : public QVGroupBox
 {
@@ -37,7 +39,9 @@ public:
     ~GeneralWidget();
 
 private:
-    QCheckBox *cbMousePos, *cbSaveContents;
+    QCheckBox *cbMousePos, *cbSaveContents, *cbReplayAIH;
+    KIntNumInput *popupTimeout;
+    KEditListBox *editListBox;
 
 };
 
@@ -62,9 +66,10 @@ private slots:
     void slotAddAction();
     void slotDeleteAction();
     void slotRightPressed( QListViewItem *, const QPoint&, int col );
+    void slotItemChanged( QListViewItem *, const QPoint& , int );
 
 private:
-    KEditableListView *listView;
+    KListView *listView;
 
 };
 
@@ -100,12 +105,31 @@ public:
 	return generalWidget->cbMousePos->isChecked();
     }
 
+    bool replayActionInHistory() const {
+	return generalWidget->cbReplayAIH->isChecked();
+    }
+    int popupTimeout() const {
+	return generalWidget->popupTimeout->value();
+    }
+    QStringList noActionsFor() const {
+	return generalWidget->editListBox->items();
+    }
+
     void setKeepContents( bool enable ) {
 	generalWidget->cbSaveContents->setChecked( enable );
     }
     void setPopupAtMousePos( bool enable ) {
 	generalWidget->cbMousePos->setChecked( enable );
     }
+    void setReplayActionInHistory( bool enable ) {
+	generalWidget->cbReplayAIH->setChecked( enable );
+    }
+    void setPopupTimeout( int timeout ) {
+	generalWidget->popupTimeout->setValue( timeout );
+    }
+    void setNoActionsFor( const QStringList& items ) {
+	generalWidget->editListBox->insertStringList( items );
+    }
 
 private:
     GeneralWidget *generalWidget;
