@@ -22,6 +22,8 @@
 #include <stdlib.h>
 #include <sys/stat.h>
 
+#include <qfile.h>
+
 #include <kapp.h>
 #include <kstddirs.h>
 #include <kdebug.h>
@@ -40,7 +42,7 @@
 
 
 static const char *description =
-	I18N_NOOP("KFM Exec - Opens remote files, watches modifications, asks for upload");
+        I18N_NOOP("KFM Exec - Opens remote files, watches modifications, asks for upload");
 
 static const char *version = "v0.0.1";
 
@@ -67,71 +69,69 @@ KFMExec::KFMExec()
 
     expectedCounter = 0;
     command = args->arg(0);
-    kdDebug() << command.ascii() << endl;
+    kdDebug() << command << endl;
 
     for ( int i = 1; i < args->count(); i++ )
     {
         KURL url = args->url(i);
         // A local file, not an URL ?
-	// => It is not encoded and not shell escaped, too.
-	if ( url.isLocalFile() )
-	{
-	    QString tmp( shellQuote( url.path() ) );
-	    if ( !files.isEmpty() )
-		files += " ";
-	    files += "\"";
-	    files += tmp.local8Bit();
-	    files += "\"";
-	}
-	// It is an URL
-	else
+        // => It is not encoded and not shell escaped, too.
+        if ( url.isLocalFile() )
         {
-	    if ( url.isMalformed() )
-	    {
+            QString tmp( shellQuote( url.path() ) );
+            params.append(tmp);
+        }
+        // It is an URL
+        else
+        {
+            if ( url.isMalformed() )
+            {
                 KMessageBox::error( 0L, i18n( "The URL %1\nis malformed" ).arg( url.url() ) );
-	    }
-	    // We must fetch the file
-	    else
-	    {
+            }
+            // We must fetch the file
+            else
+            {
                 // Build the destination filename, in ~/.kde/share/apps/kfmexec/tmp/
                 // Unlike KDE-1.1, we put the filename at the end so that the extension is kept
                 // (Some programs rely on it)
-		QString tmp = locateLocal( "appdata", "tmp/" ) +
-		              QString("%1.%2.%3").arg(getpid()).arg(jobCounter++).arg(url.fileName());
-		if ( !files.isEmpty() )
-		    files += " ";
-		files += "\"";
-		files += tmp;
-		files += "\"";
-                kdDebug() << "files= " << files << endl;
-		fileList.append( tmp );
-		urlList.append( url );
+                QString tmp = locateLocal( "appdata", "tmp/" ) +
+                              QString("%1.%2.%3").arg(getpid()).arg(jobCounter++).arg(url.fileName());
+                params.append(tmp);
+                fileList.append( tmp );
+                urlList.append( url );
 
-		expectedCounter++;
-		KIO::Job *job = KIO::file_copy( url, tmp );
-		jobList->append( job );
+                expectedCounter++;
+                KIO::Job *job = KIO::file_copy( url, tmp );
+                jobList->append( job );
 
-		connect( job, SIGNAL( result( KIO::Job * ) ), SLOT( slotResult( KIO::Job * ) ) );
-	
-	    }
-	}
+                connect( job, SIGNAL( result( KIO::Job * ) ), SLOT( slotResult( KIO::Job * ) ) );
+
+            }
+        }
     }
     args->clear();
 
     counter = 0;
     if ( counter == expectedCounter )
-	slotResult( 0L );
+        slotResult( 0L );
 }
 
 void KFMExec::slotResult( KIO::Job * job )
 {
     if (job && job->error())
+    {
         job->showErrorDialog();
+        QStringList::Iterator it = params.find( static_cast<KIO::FileCopyJob*>(job)->destURL().path() );
+        if ( it != params.end() )
+           params.remove( it );
+        else
+           kdDebug() <<  static_cast<KIO::FileCopyJob*>(job)->destURL().path() << " not found in list" << endl;
+    }
 
     counter++;
 
     if ( counter < expectedCounter )
-	return;
+        return;
 
     // We know we can run the app now - but let's finish the job properly first.
     QTimer::singleShot( 0, this, SLOT( slotRunApp() ) );
@@ -141,6 +141,9 @@ void KFMExec::slotResult( KIO::Job * job )
 
 void KFMExec::slotRunApp()
 {
+    if ( params.isEmpty() )
+      exit(1);
+
     int pos;
     while ( ( pos = command.find( "%f" )) != -1 )
       command.replace( pos, 2, "" );
@@ -148,6 +151,17 @@ void KFMExec::slotRunApp()
       command.replace( pos, 2, "" );
 
     command.append( " " );
+    QString files;
+    QStringList::ConstIterator cmdit = params.begin();
+    for ( ; cmdit != params.end() ; ++cmdit ) 
+    {
+        if ( !files.isEmpty() )
+            files += " ";
+        files += "\"";
+        files += *cmdit;
+        files += "\"";
+    }
+    kdDebug() << "files= " << files << endl;
     command.append( files );
 
     // Store modification times
@@ -156,14 +170,14 @@ void KFMExec::slotRunApp()
     QStringList::ConstIterator it = fileList.begin();
     for ( ; it != fileList.end() ; ++it )
     {
-	struct stat buff;
-	stat( *it, &buff );
-	times[i++] = buff.st_mtime;
+        struct stat buff;
+        stat( QFile::encodeName(*it), &buff );
+        times[i++] = buff.st_mtime;
     }
 
     kdDebug() << "EXEC '" << command << "'" << endl;
 
-    system( command );
+    system( QFile::encodeName(command) );
 
     kdDebug() << "EXEC done" << endl;
 
@@ -173,30 +187,31 @@ void KFMExec::slotRunApp()
     it = fileList.begin();
     for ( ; it != fileList.end() ; ++it, ++urlIt )
     {
-	struct stat buff;
+        struct stat buff;
         QString src = *it;
         KURL dest = *urlIt;
-	if ( stat( src, &buff ) == 0 && times[i++] != buff.st_mtime )
-	{
-	    if ( KMessageBox::questionYesNo( 0L, i18n( "The file\n%1\nhas been modified.\nDo you want to save it?" ).arg(src) )
-                      == KMessageBox::Yes )
-	    {
-		kdDebug() << QString("src='%1'  dest='%2'").arg(src).arg(dest.url()).ascii() << endl;
+        if ( stat( QFile::encodeName(src), &buff ) == 0 && times[i++] != buff.st_mtime )
+        {
+            if ( KMessageBox::questionYesNo( 0L,
+                                             i18n( "The file\n%1\nhas been modified.\nDo you want to upload the changes?" ).arg(dest.prettyURL()),
+                                             i18n("File changed" ) ) == KMessageBox::Yes )
+            {
+                kdDebug() << QString("src='%1'  dest='%2'").arg(src).arg(dest.url()).ascii() << endl;
                 // Do it the synchronous way.
-		KIO::NetAccess::upload( src, dest );
-	    }
-	}
-	else
-	{
-	    unlink( src.local8Bit() );
-	}
+                if ( !KIO::NetAccess::upload( src, dest ) )
+                {
+                        KMessageBox::error( 0L, KIO::NetAccess::lastErrorString() );
+                }
+            }
+        }
+        else
+        {
+            unlink( src.local8Bit() );
+        }
     }
 
-    kdDebug() << "Finished, quitting." << endl;
-    kapp->quit();
-    kdDebug() << "Still here..." << endl;
+    //kapp->quit(); not efficient enough
     exit(0);
-    kdDebug() << "Not here..." << endl;
 }
 
 QString KFMExec::shellQuote( const QString & data )
@@ -205,32 +220,32 @@ QString KFMExec::shellQuote( const QString & data )
     int pos = 0;
     while ( ( pos = cmd.find( ";", pos )) != -1 )
     {
-	cmd.replace( pos, 1, "\\;" );
-	pos += 2;
+        cmd.replace( pos, 1, "\\;" );
+        pos += 2;
     }
     pos = 0;
     while ( ( pos = cmd.find( "\"", pos )) != -1 )
     {
-	cmd.replace( pos, 1, "\\\"" );
-	pos += 2;
+        cmd.replace( pos, 1, "\\\"" );
+        pos += 2;
     }
     pos = 0;
     while ( ( pos = cmd.find( "|", pos ) ) != -1 )
     {
-	cmd.replace( pos, 1, "\\|" );
-	pos += 2;
+        cmd.replace( pos, 1, "\\|" );
+        pos += 2;
     }
     pos = 0;
     while ( ( pos = cmd.find( "(", pos )) != -1 )
     {
-	cmd.replace( pos, 1, "\\(" );
-	pos += 2;
+        cmd.replace( pos, 1, "\\(" );
+        pos += 2;
     }
     pos = 0;
     while ( ( pos = cmd.find( ")", pos )) != -1 )
     {
-	cmd.replace( pos, 1, "\\)" );
-	pos += 2;
+        cmd.replace( pos, 1, "\\)" );
+        pos += 2;
     }
 
     return cmd;
@@ -254,7 +269,7 @@ int main( int argc, char **argv )
     if ( argc < 2 )
     {
         kdFatal() << i18n( "Syntax Error:\nkfmexec command [URLs ....]" ) << endl;
-	exit(1);
+        exit(1);
     }
 
     KFMExec exec;
