@@ -32,6 +32,7 @@
 #include <kuserprofile.h>
 #include <kaboutdata.h>
 #include <klocale.h>
+#include <kmessagebox.h>
 
 #include <qwidget.h>
 #include <qfile.h>
@@ -40,7 +41,8 @@
 
 KAboutData *KonqFactory::s_aboutData = 0;
 
-KParts::ReadOnlyPart *KonqViewFactory::create( QWidget *parentWidget, const char *widgetName, QObject * parent, const char *name )
+KParts::ReadOnlyPart *KonqViewFactory::create( QWidget *parentWidget, const char *widgetName,
+                                               QObject * parent, const char *name )
 {
   if ( !m_factory )
     return 0L;
@@ -70,15 +72,6 @@ KParts::ReadOnlyPart *KonqViewFactory::create( QWidget *parentWidget, const char
   return static_cast<KParts::ReadOnlyPart *>(obj);
 }
 
-KonqFactory::KonqFactory()
-{
-  KGlobal::dirs()->saveLocation("data", "kfm/bookmarks", true);
-}
-
-KonqFactory::~KonqFactory()
-{
-}
-
 KonqViewFactory KonqFactory::createView( const QString &serviceType,
                                          const QString &serviceName,
                                          KService::Ptr *serviceImpl,
@@ -114,7 +107,6 @@ KonqViewFactory KonqFactory::createView( const QString &serviceType,
   if ( !serviceName.isEmpty() )
   {
       KTrader::OfferList::Iterator it = offers.begin();
-      // Remove irrelevant entries (non parts)
       for ( ; it != offers.end() && !service ; ++it )
       {
           if ( (*it)->desktopEntryName() == serviceName )
@@ -131,6 +123,10 @@ KonqViewFactory KonqFactory::createView( const QString &serviceType,
   {
     kdDebug(1202) << "Trying to open lib for requested service " << service->desktopEntryName() << endl;
     factory = KLibLoader::self()->factory( QFile::encodeName(service->library()) );
+    if ( !factory )
+        KMessageBox::error(0,
+                           i18n("There was an error loading the module %1.\nThe diagnostics is:\n%2")
+                           .arg(service->name()).arg(KLibLoader::self()->lastErrorMessage()));
   }
 
   KTrader::OfferList::Iterator it = offers.begin();
@@ -145,6 +141,10 @@ KonqViewFactory KonqFactory::createView( const QString &serviceType,
       //kdDebug(1202) << "Trying to open lib for service " << service->name() << endl;
       // Try loading factory
       factory = KLibLoader::self()->factory( QFile::encodeName(service->library()) );
+      if ( !factory )
+        KMessageBox::error(0,
+                           i18n("There was an error loading the module %1.\nThe diagnostics is:\n%2")
+                           .arg(service->name()).arg(KLibLoader::self()->lastErrorMessage()));
       // If this works, we exit the loop.
     } else
       kdDebug(1202) << "Not allowed as default " << service->desktopEntryName() << endl;
@@ -155,7 +155,7 @@ KonqViewFactory KonqFactory::createView( const QString &serviceType,
 
   if ( !factory )
   {
-    kdDebug(1202) << "KonqFactory::createView : no factory" << endl;
+    kdWarning(1202) << "KonqFactory::createView : no factory" << endl;
     return KonqViewFactory();
   }
 
@@ -176,44 +176,18 @@ void KonqFactory::getOffers( const QString & serviceType,
                              KTrader::OfferList *partServiceOffers,
                              KTrader::OfferList *appServiceOffers )
 {
-    KTrader::OfferList offers = KTrader::self()->query( serviceType );
-
     if ( appServiceOffers )
     {
-        *appServiceOffers = offers;
-        KTrader::OfferList::Iterator it = appServiceOffers->begin();
-        while ( it != appServiceOffers->end() )
-        {
-            //kdDebug(1202) << (*it)->desktopEntryName() << endl;
-            // Remove pure services (no app), and also remove ourselves... :-}
-            if ( (*it)->type() != "Application"
-                 || (*it)->desktopEntryName() == "kfmclient" )
-            {
-                it = appServiceOffers->remove( it );
-                // it points to the next one now
-            }
-            else
-                ++it;
-        }
-    }
-
-    KTrader::OfferList::Iterator it = offers.begin();
-    // Remove irrelevant entries (non parts)
-    while ( it != offers.end() )
-    {
-        QStringList serviceTypes = (*it)->serviceTypes();
-        if ( !serviceTypes.contains( "KParts/ReadOnlyPart" ) && !serviceTypes.contains( "Browser/View" ) )
-        {
-            //kdDebug(1202) << "Service " << (*it)->name() << " not embeddable" << endl;
-            it = offers.remove( it );
-            // it points to the next one now
-            continue;
-        }
-        ++it;
+        *appServiceOffers = KTrader::self()->query( serviceType, "Application",
+"DesktopEntryName != 'kfmclient' and DesktopEntryName != 'kfmclient_dir' and DesktopEntryName != 'kfmclient_html'",
+                                                    QString::null );
     }
 
     if ( partServiceOffers )
-        (*partServiceOffers) = offers;
+    {
+        *partServiceOffers = KTrader::self()->query( serviceType, "KParts/ReadOnlyPart",
+                                                     QString::null, QString::null );
+    }
 }
 
 
@@ -226,7 +200,6 @@ const KAboutData *KonqFactory::aboutData()
                         I18N_NOOP("Web browser, file manager, ..."),
                         KAboutData::License_GPL,
                         "(c) 1999-2000, The Konqueror developers" );
-    s_aboutData->addAuthor( "Torben Weis", I18N_NOOP("kfm author"), "weis@kde.org" );
     s_aboutData->addAuthor( "David Faure", I18N_NOOP("developer (parts, I/O lib) and maintainer"), "faure@kde.org" );
     s_aboutData->addAuthor( "Simon Hausmann", I18N_NOOP("developer (framework, parts)"), "hausmann@kde.org" );
     s_aboutData->addAuthor( "Michael Reiher", I18N_NOOP("developer (framework)"), "michael.reiher@gmx.de" );
@@ -244,6 +217,11 @@ const KAboutData *KonqFactory::aboutData()
     s_aboutData->addAuthor( "Dima Rogozin", I18N_NOOP("developer (Java applet support)"), "dima@mercury.co.il" );
     s_aboutData->addAuthor( "Harri Porten", I18N_NOOP("developer (JavaScript)"), "porten@kde.org" );
     s_aboutData->addAuthor( "Stefan Schimanski", I18N_NOOP("developer (Netscape plugin support)"), "1Stein@gmx.de" );
+    s_aboutData->addAuthor( "George Staikos", I18N_NOOP("developer (SSL support)"), "staikos@kde.org" );
+    s_aboutData->addAuthor( "Dawit Alemayehu",I18N_NOOP("developer (I/O lib, Authentication support)"), "adawit@kde.org" );
+    s_aboutData->addAuthor( "Carsten Pfeiffer",I18N_NOOP("developer (framework)"), "pfeiffer@kde.org" );
+    s_aboutData->addAuthor( "Torsten Rahn", I18N_NOOP("graphics / icons"), "torsten@kde.org" );
+    s_aboutData->addAuthor( "Torben Weis", I18N_NOOP("kfm author"), "weis@kde.org" );
   }
   return s_aboutData;
 }
