@@ -36,10 +36,13 @@
 #include <kimageio.h>
 #include <kopenwith.h>
 
+#include <qwidgetlist.h>
+
 static KCmdLineOptions options[] =
 {
   { "silent", I18N_NOOP("Start without a default window."), 0 },
   { "profile <profile>",   I18N_NOOP("Profile to open."), 0 },
+  { "mimetype <mimetype>",   I18N_NOOP("Mimetype to use for this URL, (e.g. text/html or inode/directory)."), 0 },
   { "+[URL]",   I18N_NOOP("Location to open."), 0 },
   { 0, 0, 0}
 };
@@ -59,8 +62,6 @@ int main( int argc, char **argv )
   KGlobal::locale()->insertCatalogue("libkonq"); // needed for apps using libkonq
   KImageIO::registerFormats();
 
-  QString path = KGlobal::dirs()->saveLocation("data", "kfm/bookmarks", true);
-  KonqBookmarkManager bm ( path );
   KFileOpenWithHandler fowh;
 
   KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
@@ -85,7 +86,11 @@ int main( int argc, char **argv )
        QString url;
        if (args->count() == 1)
            url = QString::fromLocal8Bit(args->arg(0));
-       KonqMisc::createBrowserWindowFromProfile( profilePath, profile, url );
+       KParts::URLArgs urlargs;
+       if (args->isSet("mimetype"))
+           urlargs.serviceType = QString::fromLocal8Bit(args->getOption("mimetype"));
+       kdDebug() << "main() -> createBrowserWindowFromProfile servicetype=" << urlargs.serviceType << endl;
+       KonqMisc::createBrowserWindowFromProfile( profilePath, profile, url, urlargs );
      }
      else
      {
@@ -96,6 +101,7 @@ int main( int argc, char **argv )
                  KonqMainWindow *mainWindow = new KonqMainWindow;
                  mainWindow->show();
              }
+             kdDebug() << "main() -> no args" << endl;
          }
          else
          {
@@ -108,8 +114,14 @@ int main( int argc, char **argv )
                      urlToOpen = url;
                  else
                      urlToOpen = KURL( KonqMisc::konqFilteredURL(0L, args->arg(i)) ); // "konqueror slashdot.org"
-                 //KonqMisc::createSimpleWindow( urlToOpen );
-                 KonqMisc::createNewWindow( urlToOpen );
+
+                 KParts::URLArgs urlargs;
+                 if (args->isSet("mimetype"))
+                 {
+                     urlargs.serviceType = QString::fromLocal8Bit(args->getOption("mimetype"));
+                     kdDebug() << "main() : setting serviceType to " << urlargs.serviceType << endl;
+                 }
+                 KonqMisc::createNewWindow( urlToOpen, urlargs );
              }
          }
      }
@@ -118,5 +130,18 @@ int main( int argc, char **argv )
 
   app.exec();
 
+ //// Temporary code, waiting for Qt to do this properly
+
+  // Delete all toplevel widgets that have WDestructiveClose, so that we don't have
+  // any parts loaded when KLibLoader::cleanUp is called.
+  QWidgetList *list = QApplication::topLevelWidgets();
+  QWidgetListIt it(*list);
+  QWidget * w;
+  while( (w=it.current()) != 0 ) {
+     ++it;
+     if ( w->testWFlags( Qt::WDestructiveClose ) )
+          delete w;
+  }  
+
   return 0;
 }
