@@ -29,7 +29,7 @@
 #include <konq_openurlrequest.h>
 
 #include <kparts/mainwindow.h>
-#include <kbookmark.h>
+#include <kbookmarkmanager.h>
 #include <kcompletion.h>
 #include <kurlcompletion.h>
 #include <kglobalsettings.h>
@@ -38,7 +38,11 @@
 #include <kxmlguiclient.h>
 #include <ktrader.h>
 
+#include "konq_combo.h"
+
 class KAction;
+class KActionCollection;
+class KAccel;
 class KActionMenu;
 class KBookmarkMenu;
 class KHistoryCombo;
@@ -53,14 +57,18 @@ class KonqComboAction;
 class KonqFrame;
 class KonqFrameBase;
 class KonqFrameContainer;
-class KonqHistoryAction;
+class KToolBarPopupAction;
 class KonqLogoAction;
+class KonqViewModeAction;
 class KonqPart;
 class KonqViewManager;
 class OpenWithGUIClient;
 class ToggleViewGUIClient;
 class ViewModeGUIClient;
 class KonqMainWindowIface;
+class KonqDirPart;
+class KonqRun;
+class KURLRequester;
 struct HistoryEntry;
 
 namespace KParts {
@@ -70,6 +78,7 @@ namespace KParts {
  struct URLArgs;
 };
 
+
 class KonqMainWindow : public KParts::MainWindow,
 		       virtual public KBookmarkOwner
 {
@@ -88,7 +97,7 @@ public:
    */
   void openURL( KonqView * view, const KURL & url,
                 const QString &serviceType = QString::null,
-                const KonqOpenURLRequest & req = KonqOpenURLRequest(), bool trustedSource = true );
+                const KonqOpenURLRequest & req = KonqOpenURLRequest(), bool trustedSource = false );
 
   /**
    * Called by openURL when it knows the service type (either directly,
@@ -138,7 +147,7 @@ public:
   const MapViews & viewMap() const { return m_mapViews; }
 
   KonqView *currentView() const { return m_currentView; }
-  KParts::ReadOnlyPart *currentPart();
+  KParts::ReadOnlyPart *currentPart() const;
 
   // Only valid if there are one or two views
   KonqView * otherView( KonqView * view ) const;
@@ -150,21 +159,27 @@ public:
 
   /// Overloaded functions of KBookmarkOwner
   virtual void openBookmarkURL( const QString & _url );
-  virtual QString currentTitle() const { return m_title; }
+  virtual QString currentTitle() const;
   virtual QString currentURL() const;
 
   /**
    * Change URL displayed in the location bar
    */
   void setLocationBarURL( const QString &url );
+  /**
+   * Return URL displayed in the location bar - for KonqViewManager
+   */
+  QString locationBarURL() const;
+  void focusLocationBar();
 
   void enableAllActions( bool enable );
 
   void disableActionsNoView();
 
-  void updateToolBarActions();
+  void updateToolBarActions( bool pendingActions = false );
   void updateOpenWithActions();
   void updateViewModeActions();
+  void updateViewActions();
 
   bool fullScreenMode() const { return m_bFullScreen; }
 
@@ -173,12 +188,16 @@ public:
    */
   KToggleAction * linkViewAction() { return m_paLinkView; }
 
+  void enableAction( const char * name, bool enabled );
+
   /**
    * The default settings "allow HTML" - the one used when creating a new view
    * Might not match the current view !
    */
   bool isHTMLAllowed() const { return m_bHTMLAllowed; }
 
+  bool saveViewPropertiesLocally() const { return m_bSaveViewPropertiesLocally; }
+
   static QList<KonqMainWindow> *mainWindowList() { return s_lstViews; }
 
   // public for konq_guiclients
@@ -187,6 +206,9 @@ public:
   // for the view manager
   void currentProfileChanged();
 
+  // adds url to all combos of all mainwindows of this instance
+  static void addToCombos( const QString& url, const QCString& objId );
+
 signals:
   void viewAdded( KonqView *view );
   void viewRemoved( KonqView *view );
@@ -226,7 +248,7 @@ public slots:
   void slotViewModeToggle( bool toggle );
   void slotShowHTML();
   void slotLockView();
-  void slotUnlockViews();
+  void slotUnlockView();
   void slotLinkView();
   void slotReload();
   void slotStop();
@@ -242,15 +264,10 @@ public slots:
   void slotGoTemplates();
   void slotGoAutostart();
 
-  void slotConfigureFileManager();
-  void slotConfigureFileTypes();
-  void slotConfigureBrowser();
-  void slotConfigureEBrowsing();
-  void slotConfigureCookies();
-  void slotConfigureProxies();
-  void slotConfigureCrypto();
+  void slotConfigure();
   void slotConfigureKeys();
   void slotConfigureToolbars();
+  void slotNewToolbarConfig();
 
   void slotUndoAvailable( bool avail );
 
@@ -265,9 +282,10 @@ public slots:
   // public for KonqViewManager
   void slotPartActivated( KParts::Part *part );
 
+  virtual void setIcon( const QPixmap& );
+
 protected slots:
   void slotViewCompleted( KonqView * view );
-  void slotEnableAction( const char * name, bool enabled );
 
   void slotURLEntered( const QString &text );
 
@@ -282,7 +300,6 @@ protected slots:
   void slotSaveViewProfile();
   void slotSaveViewPropertiesLocally();
   void slotRemoveLocalProperties();
-  void slotSaveOptions();
 
   void slotOpenEmbedded();
   void slotOpenEmbeddedDoIt();
@@ -295,8 +312,6 @@ protected slots:
 
   void slotOpenWith();
 
-  //void slotAbout();
-
   void slotGoMenuAboutToShow();
   void slotUpAboutToShow();
   void slotBackAboutToShow();
@@ -318,22 +333,29 @@ protected slots:
   void slotComboPaste();
   void slotComboDelete();
   void slotClipboardDataChanged();
+  void slotCheckComboSelection();
 
   void slotShowMenuBar();
   void slotShowToolBar();
+  void slotShowExtraToolBar();
   void slotShowLocationBar();
   void slotShowBookmarkBar();
 
   void slotActionStatusText( const QString &text );
   void slotClearStatusText();
 
+  void slotFindOpen( KonqDirPart * dirPart );
+  void slotFindClosed( KonqDirPart * dirPart );
+
+  void slotIconsChanged();
+
 protected:
   QString detectNameFilter( QString & url );
 
   void toggleBar( const char *name );
   KToolBar * toolBarByName( const char *name );
 
-  bool eventFilter(QObject*obj,QEvent *ev);
+  virtual bool eventFilter(QObject*obj,QEvent *ev);
 
   void fillHistoryPopup( QPopupMenu *menu, const QList<HistoryEntry> &history );
 
@@ -342,12 +364,19 @@ protected:
 
   void applyKonqMainWindowSettings();
 
+    void saveToolBarServicesMap();
+
   void viewsChanged();
 
   void updateLocalPropsActions();
 
   virtual void closeEvent( QCloseEvent * );
 
+  bool askForTarget(const QString& text, KURL& url);
+
+private slots:
+  void slotRequesterClicked( KURLRequester * );
+
 private:
   /**
    * takes care of hiding the bookmarkbar and calling setChecked( false ) on the
@@ -382,9 +411,9 @@ private:
 
   KActionMenu *m_pamBookmarks;
 
-  KonqHistoryAction *m_paUp;
-  KonqHistoryAction *m_paBack;
-  KonqHistoryAction *m_paForward;
+  KToolBarPopupAction *m_paUp;
+  KToolBarPopupAction *m_paBack;
+  KToolBarPopupAction *m_paForward;
   KAction *m_paHome;
 
   KonqBidiHistoryAction *m_paHistory;
@@ -403,7 +432,7 @@ private:
   KActionMenu *m_pamLoadViewProfile;
 
   KAction *m_paLockView;
-  KAction *m_paUnlockAll;
+  KAction *m_paUnlockView;
   KToggleAction *m_paLinkView;
   KAction *m_paReload;
   KAction *m_paUndo;
@@ -411,6 +440,7 @@ private:
   KAction *m_paCopy;
   KAction *m_paPaste;
   KAction *m_paStop;
+  KAction *m_paRename;
 
   KAction *m_paTrash;
   KAction *m_paDelete;
@@ -424,11 +454,13 @@ private:
   KonqComboAction *m_paURLCombo;
   KBookmarkBar *m_paBookmarkBar;
 
+  KAction * m_paFindFiles;
   KToggleAction *m_ptaUseHTML;
 
   KToggleAction *m_paShowMenuBar;
   KToggleAction *m_paShowStatusBar;
   KToggleAction *m_paShowToolBar;
+  KToggleAction *m_paShowExtraToolBar;
   KToggleAction *m_paShowLocationBar;
   KToggleAction *m_paShowBookmarkBar;
 
@@ -456,13 +488,18 @@ private:
   KonqView *m_currentView;
 
   KBookmarkMenu* m_pBookmarkMenu;
+  KActionCollection*  m_bookmarksActionCollection;
 
   KonqViewManager *m_pViewManager;
 
+  KonqRun *m_initialKonqRun;
+
   QString m_title;
 
-  QGuardedPtr<KHistoryCombo> m_combo;
+  QGuardedPtr<KonqCombo> m_combo;
+  static KConfig *s_comboConfig;
   KURLCompletion *m_pURLCompletion;
+  // just a reference to KonqHistoryManager's completionObject
   static KCompletion *s_pCompletion;
 
   ToggleViewGUIClient *m_toggleViewGUIClient;
@@ -478,21 +515,22 @@ private:
 
   QList<KAction> m_openWithActions;
   KActionMenu *m_viewModeMenu;
+  QList<KAction> m_toolBarViewModeActions; // basically holds two KonqViewActions, one of
+                                           // iconview and one for listview
   QList<KAction> m_viewModeActions;
+  QMap<QString,KService::Ptr> m_viewModeToolBarServices; // similar to m_toolBarViewModeActions
+  // it holds a map library name (libkonqiconview/libkonqlistview) ==> service (service for
+  // iconview, multicolumnview, treeview, etc .)
 
   KonqMainWindowIface * m_dcopObject;
 
-  bool m_qComboHack; // FIXME, remove when QComboBox is ready
-
   static QStringList *s_plstAnimatedLogo;
 
   static QList<KonqMainWindow> *s_lstViews;
 
-  typedef QMap<QCString,QCString> ActionSlotMap;
-  static ActionSlotMap *s_actionSlotMap;
-
   QString m_currentDir; // stores current dir for relative URLs whenever applicable
 
+    KAccel *m_accel;
 };
 
 #endif
