@@ -24,6 +24,9 @@
 #include <kmessagebox.h>
 #include <kurifilter.h>
 #include <klocale.h>
+#include <kstddirs.h>
+#include <kglobal.h>
+#include <kprotocolinfo.h>
 #include <qdir.h>
 
 /**********************************************
@@ -60,11 +63,14 @@ KonqMainWindow * KonqMisc::createSimpleWindow( const KURL & _url, const QString
 
 KonqMainWindow * KonqMisc::createNewWindow( const KURL &url, const KParts::URLArgs &args )
 {
+  kdDebug() << "KonqMisc::createNewWindow url=" << url.url() << endl;
   abortFullScreenMode();
 
-  // For HTTP, use the web browsing profile, otherwise use filemanager profile
-  // TODO: maybe add a list of protocols in the profile...
-  QString profileName = url.protocol().startsWith("http") ? "webbrowsing" : "filemanagement";
+  // For HTTP or html files, use the web browsing profile, otherwise use filemanager profile
+  QString profileName = (!(KProtocolInfo::supportsListing(url.protocol())) ||
+                        url.path().right(5) == ".html" ||
+			url.path().right(4) == ".htm" )
+          ? "webbrowsing" : "filemanagement";
 
   QString profile = locate( "data", QString::fromLatin1("konqueror/profiles/") + profileName );
   return createBrowserWindowFromProfile( profile, profileName, url, args );
@@ -84,9 +90,11 @@ KonqMainWindow * KonqMisc::createBrowserWindowFromProfile( const QString &path,
   }
   else
   {
-      mainWindow = new KonqMainWindow( QString::null, false );
+      mainWindow = new KonqMainWindow( KURL(), false );
       //FIXME: obey args (like passing post-data (to KRun), etc.)
-      mainWindow->viewManager()->loadViewProfile( path, filename, url );
+      KonqOpenURLRequest req;
+      req.args = args;
+      mainWindow->viewManager()->loadViewProfile( path, filename, url, req );
   }
   mainWindow->setInitialFrameName( args.frameName );
   mainWindow->show();
@@ -95,36 +103,24 @@ KonqMainWindow * KonqMisc::createBrowserWindowFromProfile( const QString &path,
 
 QString KonqMisc::konqFilteredURL( QWidget* parent, const QString& _url, const QString& _path )
 {
-  KURIFilterData data = _url;
-
-  if( !_path.isEmpty() )
-    data.setAbsolutePath(_path);
-
-  if( KURIFilter::self()->filterURI( data ) )
+  if ( !_url.startsWith( "about:" ) ) // Don't filter "about:" URLs
   {
-    if( data.uriType() == KURIFilterData::ERROR )
+    KURIFilterData data = _url;
+
+    if( !_path.isEmpty() )
+      data.setAbsolutePath(_path);
+
+    if( KURIFilter::self()->filterURI( data ) )
     {
-      // HACK: To get around message freeze!!  The if
-      // statement should be removed after 2.0 freeze
-      // is lifted...
-      if( !data.errorMsg().isEmpty() )
-	 KMessageBox::sorry( parent, i18n( data.errorMsg().utf8() ) );
-      return QString::null;
+      if( data.uriType() == KURIFilterData::ERROR && !data.errorMsg().isEmpty() )
+        KMessageBox::sorry( parent, i18n( data.errorMsg().utf8() ) );
+      else
+        return data.uri().url();
     }
-    else
-      return data.uri().url();
   }
+  else
+      if ( _url == "about:" ) // We can't use "about:" as it is, KURL doesn't parse it.
+          return "about:konqueror";
   return _url;  // return the original url if it cannot be filtered.
 }
 
-/**********************************************
- *
- * KonqBookmarkManager
- *
- **********************************************/
-
-void KonqBookmarkManager::editBookmarks( const KURL & _url )
-{
-  KonqMisc::createSimpleWindow( _url );
-}
-
