@@ -20,8 +20,11 @@
 #ifndef __kfm_run_h__
 #define __kfm_run_h__
 
-#include "krun.h"
+#include <krun.h>
+#include <qguardedptr.h>
+#include <kservice.h>
 #include <sys/types.h>
+#include <konq_openurlrequest.h>
 
 class KonqMainWindow;
 class KonqView;
@@ -35,8 +38,8 @@ public:
    * optionnal child view.
    */
   KonqRun( KonqMainWindow* mainWindow, KonqView *childView,
-           const KURL &url, mode_t _mode = 0,
-           bool _is_local_file = false, bool _auto_delete = true );
+                 const KURL &url, const KonqOpenURLRequest & req = KonqOpenURLRequest(),
+           bool trustedSource = false );
 
   virtual ~KonqRun();
 
@@ -47,6 +50,13 @@ public:
 
   KonqView *childView() const { return m_pView; }
 
+  const QString & typedURL() const { return m_req.typedURL; }
+
+  static bool allowExecution( const QString &serviceType, const KURL &url );
+  static bool isExecutable( const QString &serviceType );
+  static bool askSave( const KURL & url, KService::Ptr offer );
+  static void save( const KURL & url );
+
 protected:
   /**
    * Called if the mimetype has been detected. The function checks wether the document
@@ -54,7 +64,7 @@ protected:
    * finish the job.
    */
   virtual void foundMimeType( const QString & _type );
-  
+
   virtual void scanFile();
 
 protected slots:
@@ -62,9 +72,11 @@ protected slots:
   void slotKonqMimetype(KIO::Job *job, const QString &type);
 
 protected:
-  KonqMainWindow* m_pMainWindow;
-  KonqView* m_pView;
+  QGuardedPtr<KonqMainWindow> m_pMainWindow;
+  QGuardedPtr<KonqView> m_pView;
   bool m_bFoundMimeType;
+  KonqOpenURLRequest m_req;
+  bool m_bTrustedSource;
 };
 
 #endif
