@@ -33,6 +33,7 @@
 #include <qfileinfo.h>
 #include <qapplication.h>
 
+#include <kaccelgen.h>
 #include <kaction.h>
 #include <kconfig.h>
 #include <kstddirs.h>
@@ -54,6 +55,7 @@ KonqViewManager::KonqViewManager( KonqMainWindow *mainWindow )
 
   m_pamProfiles = 0L;
   m_bProfileListDirty = true;
+  m_bLoadingProfile = false;
 }
 
 KonqViewManager::~KonqViewManager()
@@ -62,20 +64,40 @@ KonqViewManager::~KonqViewManager()
 }
 
 KonqView* KonqViewManager::splitView ( Qt::Orientation orientation,
-                                       QString serviceType,
-                                       const QString &serviceName )
+                                       const QString &serviceType,
+                                       const QString &serviceName,
+                                       bool newOneFirst)
 {
   kdDebug(1202) << "KonqViewManager::splitView(ServiceType)" << endl;
 
   KonqFrame* viewFrame = 0L;
-  if( m_pMainContainer && m_pMainWindow->currentView() )
-    viewFrame = m_pMainWindow->currentView()->frame();
+  if( m_pMainContainer )
+  {
+    if ( m_pMainWindow->currentView() )
+      viewFrame = m_pMainWindow->currentView()->frame();
+    else
+    {
+      kdWarning(1202) << "splitView called, but no current view!" << endl;
+      return 0L; // if we go on, we'll hit the assert in split()
+    }
+  }
+
+  KonqFrameContainer *newContainer;
+  KonqView* childView = split( viewFrame, orientation, serviceType, serviceName, &newContainer );
+
+  if ( newOneFirst )
+  {
+      newContainer->moveToLast( viewFrame->widget() );
+      newContainer->swapChildren();
+  }
 
-  KonqView* childView = split( viewFrame, orientation, serviceType, serviceName );
   return childView;
 }
 
-KonqView* KonqViewManager::splitWindow( Qt::Orientation orientation )
+KonqView* KonqViewManager::splitWindow( Qt::Orientation orientation,
+                                        const QString &serviceType,
+                                        const QString &serviceName,
+                                        bool newOneFirst )
 {
   kdDebug(1202) << "KonqViewManager::splitWindow(default)" << endl;
 
@@ -87,9 +109,21 @@ KonqView* KonqViewManager::splitWindow( Qt::Orientation orientation )
   {
     splitFrame = m_pMainContainer->firstChild();
     locationBarURL = m_pMainWindow->currentView()->locationBarURL();
+    if ( !splitFrame )
+    {
+      kdWarning(1202) << "splitFrame called, but no view in m_pMainContainer!" << endl;
+      return 0L; // if we go on, we'll hit the assert in split()
+    }
   }
 
-  KonqView* childView = split( splitFrame, orientation );
+  KonqFrameContainer *newContainer;
+  KonqView* childView = split( splitFrame, orientation, serviceType, serviceName, &newContainer );
+
+  if ( newOneFirst )
+  {
+      newContainer->moveToLast( splitFrame->widget() );
+      newContainer->swapChildren();
+  }
 
   if( childView )
     childView->openURL( url, locationBarURL );
@@ -196,7 +230,7 @@ KonqView* KonqViewManager::split (KonqFrameBase* splitFrame,
 
 void KonqViewManager::removeView( KonqView *view )
 {
-  kdDebug(1202) << "---------------- removeView" << view << endl;
+  kdDebug(1202) << "---------------- removeView " << view << endl;
   if ( activePart() == view->part() )
   {
     KonqView *nextView = chooseNextView( view );
@@ -223,6 +257,7 @@ void KonqViewManager::removeView( KonqView *view )
     return;
   }
 
+  kdDebug(1202) << "KonqViewManager::removeView reparenting other frame " << otherFrame << " widget=" << otherFrame->widget() << endl;
   QPoint pos = otherFrame->widget()->pos();
 
   otherFrame->reparentFrame( m_pMainWindow, pos );
@@ -233,16 +268,21 @@ void KonqViewManager::removeView( KonqView *view )
   m_pMainWindow->removeChildView( view );
 
   parentContainer->removeChildFrame( view->frame() );
-  //kdDebug(1202) << "Deleting view frame" << view->frame() << endl;
+
+  // We did so ourselves for passive views - doesn't really matter, but saves a call to slotPassiveModePartDeleted
+  if ( view->isPassiveMode() && view->part() )
+      disconnect( view->part(), SIGNAL( destroyed() ), this, SLOT( slotPassiveModePartDeleted() ) );
+
+  kdDebug(1202) << "Deleting view frame " << view->frame() << endl;
   delete view->frame();
   // This deletes the widgets inside, including the part's widget, so tell the child view
   view->partDeleted();
-  //kdDebug(1202) << "Deleting view " << view << endl;
+  kdDebug(1202) << "Deleting view " << view << endl;
   delete view;
 
   grandParentContainer->removeChildFrame( parentContainer );
-  //kdDebug(1202) << "Deleting parentContainer " << parentContainer
-  //              << ". Its parent is " << parentContainer->parent() << endl;
+  kdDebug(1202) << "Deleting parentContainer " << parentContainer
+                << ". Its parent is " << parentContainer->parent() << endl;
   delete parentContainer;
 
   otherFrame->reparentFrame( grandParentContainer, pos, true/*showIt*/ );
@@ -250,7 +290,7 @@ void KonqViewManager::removeView( KonqView *view )
   if( moveOtherChild )
     grandParentContainer->moveToFirst( otherFrame->widget() );
 
-  //kdDebug(1202) << "------------- removeView done " << view << endl;
+  kdDebug(1202) << "------------- removeView done " << view << endl;
 #ifndef NDEBUG
   printFullHierarchy( m_pMainContainer );
 #endif
@@ -269,23 +309,22 @@ void KonqViewManager::removePart( KParts::Part * part )
   KonqView * view = m_pMainWindow->childView( static_cast<KParts::ReadOnlyPart *>(part) );
   if ( view ) // the child view still exists, so we are in case 1
   {
-      //kdDebug(1202) << "Found a child view" << endl;
+      kdDebug(1202) << "Found a child view" << endl;
       view->partDeleted(); // tell the child view that the part auto-deletes itself
       if (m_pMainWindow->viewCount() == 1)
       {
         kdDebug(1202) << "Deleting last view -> closing the window" << endl;
         setActivePart( 0L, true );
         m_pMainWindow->removeChildView( view );
-        delete view->frame();
-        // This deletes the widgets inside, including the part's widget, so tell the child view
-        view->partDeleted();
+        kdDebug(1202) << "Deleting frame " << view << endl;
+        delete view->frame(); // This deletes the widgets inside, including the part's widget
         kdDebug(1202) << "Deleting view " << view << endl;
         delete view;
         kdDebug(1202) << "Deleting m_pMainContainer " << m_pMainContainer << endl;
         delete m_pMainContainer;
         m_pMainContainer = 0L;
-        kdDebug(1202) << "Deleting m_pMainWindow " << m_pMainWindow << endl;
-        delete m_pMainWindow;
+        kdDebug(1202) << "Closing m_pMainWindow " << m_pMainWindow << endl;
+        m_pMainWindow->close(); // will delete it
         return;
       }
       else // normal case
@@ -297,9 +336,25 @@ void KonqViewManager::removePart( KParts::Part * part )
   //kdDebug(1202) << "KonqViewManager::removePart ( " << part << " ) done" << endl;
 }
 
+void KonqViewManager::slotPassiveModePartDeleted()
+{
+  // Passive mode parts aren't registered to the part manager,
+  // so we have to handle suicidal ones ourselves
+  KParts::ReadOnlyPart * part = const_cast<KParts::ReadOnlyPart *>( static_cast<const KParts::ReadOnlyPart *>( sender() ) );
+  disconnect( part, SIGNAL( destroyed() ), this, SLOT( slotPassiveModePartDeleted() ) );
+  kdDebug(1202) << "KonqViewManager::slotPassiveModePartDeleted part=" << part << endl;
+  KonqView * view = m_pMainWindow->childView( part );
+  kdDebug(1202) << "view=" << view << endl;
+  if ( view ) // the child view still exists, so the part suicided
+  {
+      view->partDeleted(); // tell the child view that the part deleted itself
+      removeView( view );
+  }
+}
+
 void KonqViewManager::viewCountChanged()
 {
-  bool bShowActiveViewIndicator = ( m_pMainWindow->activeViewsCount() > 1 );
+  bool bShowActiveViewIndicator = ( m_pMainWindow->/*activeViewsCount*/viewCount() > 1 );
   bool bShowLinkedViewIndicator = ( m_pMainWindow->viewCount() > 1 );
 
   KonqMainWindow::MapViews mapViews = m_pMainWindow->viewMap();
@@ -337,7 +392,7 @@ void KonqViewManager::clear()
 
 KonqView *KonqViewManager::chooseNextView( KonqView *view )
 {
-  kdDebug(1202) << "KonqViewManager(" << this << ")::chooseNextView(" << view << ")" << endl;
+  //kdDebug(1202) << "KonqViewManager(" << this << ")::chooseNextView(" << view << ")" << endl;
   KonqMainWindow::MapViews mapViews = m_pMainWindow->viewMap();
 
   KonqMainWindow::MapViews::Iterator it = mapViews.begin();
@@ -357,9 +412,10 @@ KonqView *KonqViewManager::chooseNextView( KonqView *view )
 
   KonqMainWindow::MapViews::Iterator startIt = it;
 
-  // kdDebug(1202) << "KonqViewManager::chooseNextView: count=" << mapViews.count() << endl;
+  //kdDebug(1202) << "KonqViewManager::chooseNextView: count=" << mapViews.count() << endl;
   while ( true )
   {
+    //kdDebug(1202) << "*KonqViewManager::chooseNextView going next" << endl;
     if ( ++it == end ) // move to next
       it = mapViews.begin(); // rewind on end
 
@@ -369,9 +425,10 @@ KonqView *KonqViewManager::chooseNextView( KonqView *view )
     KonqView *nextView = it.data();
     if ( nextView && !nextView->isPassiveMode() )
       return nextView;
+    //kdDebug(1202) << "KonqViewManager::chooseNextView nextView=" << nextView << " passive=" << nextView->isPassiveMode() << endl;
   }
 
-  kdDebug(1202) << "KonqViewManager::chooseNextView: returning 0L" << endl;
+  //kdDebug(1202) << "KonqViewManager::chooseNextView: returning 0L" << endl;
   return 0L; // no next view found
 }
 
@@ -434,6 +491,11 @@ KonqView *KonqViewManager::setupView( KonqFrameContainer *parentContainer,
   // Don't register passive views to the part manager
   if ( !v->isPassiveMode() ) // note that KonqView's constructor could set this to true even if passiveMode is false
     addPart( v->part(), false );
+  else
+  {
+    // Passive views aren't registered, but we still want to detect the suicidal ones
+    connect( v->part(), SIGNAL( destroyed() ), this, SLOT( slotPassiveModePartDeleted() ) );
+  }
 
   kdDebug(1202) << "KonqViewManager::setupView done" << endl;
   return v;
@@ -463,8 +525,10 @@ void KonqViewManager::saveViewProfile( KConfig & cfg, bool saveURLs, bool saveWi
 {
   kdDebug(1202) << "KonqViewManager::saveViewProfile" << endl;
   if( m_pMainContainer && m_pMainContainer->firstChild() ) {
-    cfg.writeEntry( "RootItem", m_pMainContainer->firstChild()->frameType() + QString::number(0) );
-    QString prefix = m_pMainContainer->firstChild()->frameType() + QString::number(0);
+    cfg.writeEntry( "RootItem", QString::fromLatin1( m_pMainContainer->firstChild()->frameType() )
+                    + QString::number(0) );
+    QString prefix = QString::fromLatin1( m_pMainContainer->firstChild()->frameType() )
+                     + QString::number(0);
     prefix.append( '_' );
     m_pMainContainer->firstChild()->saveConfig( &cfg, prefix, saveURLs, 0, 1 );
   }
@@ -478,15 +542,17 @@ void KonqViewManager::saveViewProfile( KConfig & cfg, bool saveURLs, bool saveWi
   cfg.sync();
 }
 
-void KonqViewManager::loadViewProfile( const QString & path, const QString & filename, const KURL & forcedURL )
+void KonqViewManager::loadViewProfile( const QString & path, const QString & filename,
+                                       const KURL & forcedURL, const KonqOpenURLRequest &req )
 {
   KConfig cfg( path, true );
   cfg.setDollarExpansion( true );
   cfg.setGroup( "Profile" );
-  loadViewProfile( cfg, filename, forcedURL );
+  loadViewProfile( cfg, filename, forcedURL, req );
 }
 
-void KonqViewManager::loadViewProfile( KConfig &cfg, const QString & filename, const KURL & forcedURL )
+void KonqViewManager::loadViewProfile( KConfig &cfg, const QString & filename,
+                                       const KURL & forcedURL, const KonqOpenURLRequest &req )
 {
   m_currentProfile = filename;
   m_currentProfileText = cfg.readEntry("Name",filename);
@@ -513,39 +579,61 @@ void KonqViewManager::loadViewProfile( KConfig &cfg, const QString & filename, c
       m_pMainContainer->setGeometry( 0, 0, m_pMainWindow->width(), m_pMainWindow->height() );
       m_pMainContainer->show();
 
+      // This flag is used by KonqView, to distinguish manual view creation
+      // from profile loading (e.g. in switchView)
+      m_bLoadingProfile = true;
+
       loadItem( cfg, m_pMainContainer, rootItem, defaultURL, forcedURL.isEmpty() );
+
+      m_bLoadingProfile = false;
+
       m_pMainWindow->enableAllActions(true);
+
+      // This flag disables calls to viewCountChanged while creating the views,
+      // so we do it once at the end :
+      m_pMainWindow->viewCountChanged();
   }
   else
   {
       m_pMainWindow->disableActionsNoView();
+      m_pMainWindow->action( "clear_location" )->activate();
   }
 
-  if ( /*m_pMainWindow->viewCount() == 0 &&*/ !forcedURL.isEmpty())
+  // Set an active part first so that we open the URL in the current view
+  // (to set the location bar correctly and asap)
+  KonqView *nextChildView = chooseNextView( 0L );
+  setActivePart( nextChildView ? nextChildView->part() : 0L, true /* immediate */ );
+
+  if ( !forcedURL.isEmpty())
   {
-      KonqView *firstChildView = chooseNextView( 0L );
-      KonqOpenURLRequest req( forcedURL.url() );
-      m_pMainWindow->openURL( firstChildView /* can be 0 for an empty profile */,
-                              forcedURL, QString::null, req );
+      KonqOpenURLRequest _req(req);
+      if (_req.typedURL.isEmpty())
+          _req.typedURL = forcedURL.url();
+      m_pMainWindow->openURL( nextChildView /* can be 0 for an empty profile */,
+                              forcedURL, _req.args.serviceType, _req, _req.args.trustedSource );
 
       // TODO choose a linked view if any (instead of just the first one),
       // then open the same URL in any non-linked one
   }
-  KonqView *nextChildView = chooseNextView( 0L );
-  setActivePart( nextChildView ? nextChildView->part() : 0L, true /* immediate */ );
+  else
+  {
+      if ( m_pMainWindow->locationBarURL().isEmpty() ) // No URL -> the user will want to type one
+          m_pMainWindow->focusLocationBar();
+  }
 
   // Window size
-
-  QSize size = readConfigSize( cfg );
-
-  if ( size.isValid() )
-    m_pMainWindow->resize( size );
+ if ( !m_pMainWindow->initialGeometrySet() )
+ {
+     QSize size = readConfigSize( cfg );
+     if ( size.isValid() )
+         m_pMainWindow->resize( size );
+ }
 
 #ifndef NDEBUG
   printFullHierarchy( m_pMainContainer );
 #endif
 
-  kdDebug(1202) << "KonqViewManager::loadViewProfile done" << endl;
+  //kdDebug(1202) << "KonqViewManager::loadViewProfile done" << endl;
 }
 
 void KonqViewManager::setActivePart( KParts::Part *part, bool immediate )
@@ -634,10 +722,6 @@ void KonqViewManager::loadItem( KConfig &cfg, KonqFrameContainer *parent,
 
     QString serviceName = cfg.readEntry( QString::fromLatin1( "ServiceName" ).prepend( prefix ) );
 
-    bool passiveMode = cfg.readBoolEntry( QString::fromLatin1( "PassiveMode" ).prepend( prefix ), false );
-    bool linkedView = cfg.readBoolEntry( QString::fromLatin1( "LinkedView" ).prepend( prefix ), false );
-    bool toggleView = cfg.readBoolEntry( QString::fromLatin1( "ToggleView" ).prepend( prefix ), false );
-
     KService::Ptr service;
     KTrader::OfferList partServiceOffers, appServiceOffers;
 
@@ -648,14 +732,13 @@ void KonqViewManager::loadItem( KConfig &cfg, KonqFrameContainer *parent,
       return; //ugh..
     }
 
-    kdDebug(1202) << "Creating View Stuff" << endl;
+    bool passiveMode = cfg.readBoolEntry( QString::fromLatin1( "PassiveMode" ).prepend( prefix ), false );
+
+    //kdDebug(1202) << "Creating View Stuff" << endl;
     KonqView *childView = setupView( parent, viewFactory, service, partServiceOffers, appServiceOffers, serviceType, passiveMode );
 
-    childView->setLinkedView( linkedView );
-    childView->setToggleView( toggleView );
-
-    //QCheckBox *checkBox = childView->frame()->statusbar()->passiveModeCheckBox();
-    //checkBox->setChecked( passiveMode );
+    childView->setLinkedView( cfg.readBoolEntry( QString::fromLatin1( "LinkedView" ).prepend( prefix ), false ) );
+    childView->setToggleView( cfg.readBoolEntry( QString::fromLatin1( "ToggleView" ).prepend( prefix ), false ) );
 
     QString key = QString::fromLatin1( "URL" ).prepend( prefix );
     if ( openURL )
@@ -666,10 +749,17 @@ void KonqViewManager::loadItem( KConfig &cfg, KonqFrameContainer *parent,
 
       if ( !url.isEmpty() )
       {
-        kdDebug(1202) << "loadItem: calling openURL " << url.prettyURL() << endl;
-        childView->openURL( url, url.prettyURL() );
+        //kdDebug(1202) << "loadItem: calling openURL " << url.prettyURL() << endl;
+        //childView->openURL( url, url.prettyURL() );
+        // We need view-follows-view (for the dirtree, for instance)
+        KonqOpenURLRequest req;
+        if (url.protocol() != "about")
+          req.typedURL = url.prettyURL();
+        m_pMainWindow->openView( serviceType, url, childView, req );
       }
     }
+    // Do this after opening the URL, so that it's actually possible to open it :)
+    childView->setLockedLocation( cfg.readBoolEntry( QString::fromLatin1( "LockedLocation" ).prepend( prefix ), false ) );
   }
   else if( name.find("Container") != -1 ) {
     kdDebug(1202) << "Item is Container" << endl;
@@ -759,12 +849,18 @@ void KonqViewManager::profileListDirty( bool broadcast )
 void KonqViewManager::slotProfileActivated( int id )
 {
 
-  QMap<QString, QString>::ConstIterator nameIt = m_mapProfileNames.find( m_pamProfiles->popupMenu()->text( id ) );
-  if ( nameIt == m_mapProfileNames.end() )
-    return;
+  QMap<QString, QString>::ConstIterator iter = m_mapProfileNames.begin();
+  QMap<QString, QString>::ConstIterator end = m_mapProfileNames.end();
+
+  for(int i=0; iter != end; ++iter, ++i) {
+    if( i == id ) {
+      KURL u;
+      u.setPath( *iter );
+      loadViewProfile( *iter, u.fileName() );
+      break;
+    }
+  }
 
-  KURL u; u.setPath( *nameIt );
-  loadViewProfile( *nameIt, u.fileName() );
 }
 
 void KonqViewManager::slotProfileListAboutToShow()
@@ -773,15 +869,22 @@ void KonqViewManager::slotProfileListAboutToShow()
     return;
 
   QPopupMenu *popup = m_pamProfiles->popupMenu();
-
   popup->clear();
 
+  // Fetch profiles
   m_mapProfileNames = KonqProfileDlg::readAllProfiles();
 
-  QMap<QString,QString>::ConstIterator eIt = m_mapProfileNames.begin();
-  QMap<QString,QString>::ConstIterator eEnd = m_mapProfileNames.end();
-  for (; eIt != eEnd; ++eIt )
-    popup->insertItem( eIt.key() );
+  // Generate accelerators
+  QStringList accel_strings;
+  KAccelGen::generateFromKeys(m_mapProfileNames, accel_strings);
+
+  // Store menu items
+  QValueListIterator<QString> iter = accel_strings.begin();
+  for( int id = 0;
+       iter != accel_strings.end();
+       ++iter, ++id ) {
+      popup->insertItem( *iter, id );
+  }
 
   m_bProfileListDirty = false;
 }
