@@ -25,6 +25,7 @@
 #include <konq_operations.h>
 #include <kparts/factory.h>
 #include <konq_dirpart.h>
+#include <konq_mimetyperesolver.h>
 
 #include <qvaluelist.h>
 #include <qlistview.h>
@@ -70,6 +71,8 @@ public:
   virtual bool openURL( const KURL &url );
   virtual bool closeURL();
   virtual bool openFile() { return true; }
+  virtual const KFileItem * currentItem();
+  virtual KFileItemList selectedFileItems() {return m_pListView->selectedFileItems();};
 
   KonqBaseListViewWidget *listViewWidget() const { return m_pListView; }
 
@@ -81,8 +84,17 @@ public:
   // "Cut" icons : disable those whose URL is in lst, enable the others
   virtual void disableIcons( const KURL::List & lst );
 
+  // See KonqMimeTypeResolver
+  void mimeTypeDeterminationFinished() {}
+  //int iconSize() { return m_pListView->iconSize(); }
+  void determineIcon( KonqBaseListViewItem * item );
+
+  QList<KonqBaseListViewItem> & lstPendingMimeIconItems() { return m_mimeTypeResolver->m_lstPendingMimeIconItems; }
+  void listingComplete();
+
+  virtual void newIconSize( int );
+
 protected:
-  virtual void guiActivateEvent( KParts::GUIActivateEvent *event );
   void setupActions();
 
 protected slots:
@@ -91,8 +103,7 @@ protected slots:
   void slotSelectAll();
   void slotUnselectAll();
   void slotInvertSelection();
-
-  void slotIconSizeToggled(bool b);
+  void slotCaseInsensitive();
 
   void slotShowDot();
   //this is called if a item in the submenu is toggled
@@ -104,15 +115,29 @@ protected slots:
   //columns by dragging them
   //at this moment the columns haven't changed their order yet, so
   //it starts a singleshottimer, after which the columns changed their order
-  //and then slotDaveAfterHeaderDrag is called
+  //and then slotSaveAfterHeaderDrag is called
   void headerDragged(int sec, int from, int to);
   //saves the new order of the columns
   void slotSaveAfterHeaderDrag();
   void slotHeaderClicked(int sec);
 
+  // This comes from KonqDirPart, it's for the "Find" feature
+  virtual void slotStarted() { m_pListView->slotStarted(); }
+  virtual void slotCanceled() { m_pListView->slotCanceled(); }
+  virtual void slotCompleted() { m_pListView->slotCompleted(); }
+  virtual void slotNewItems( const KFileItemList& lst ) { m_pListView->slotNewItems( lst ); }
+  virtual void slotDeleteItem( KFileItem * item ) { m_pListView->slotDeleteItem( item ); }
+  virtual void slotRefreshItems( const KFileItemList& lst ) { m_pListView->slotRefreshItems( lst ); }
+  virtual void slotClear() { m_pListView->slotClear(); }
+  virtual void slotRedirection( const KURL & u ) { m_pListView->slotRedirection( u ); }
+
+  void slotViewportAdjusted() { m_mimeTypeResolver->slotViewportAdjusted(); }
+  void slotProcessMimeIcons() { m_mimeTypeResolver->slotProcessMimeIcons(); }
+
 private:
 
   KonqBaseListViewWidget *m_pListView;
+  KonqMimeTypeResolver<KonqBaseListViewItem,KonqListView> *m_mimeTypeResolver;
 
   KAction *m_paSelect;
   KAction *m_paUnselect;
@@ -120,9 +145,7 @@ private:
   KAction *m_paUnselectAll;
   KAction *m_paInvertSelection;
 
-  KToggleAction *m_paLargeIcons;
-  KToggleAction *m_paMediumIcons;
-  KToggleAction *m_paSmallIcons;
+  KToggleAction *m_paCaseInsensitive;
 
   KToggleAction *m_paShowDot;
   KToggleAction *m_paShowTime;
@@ -136,7 +159,6 @@ private:
   KToggleAction *m_paShowGroup;
   KToggleAction *m_paShowPermissions;
   KToggleAction *m_paShowURL;
-
 };
 
 class ListViewBrowserExtension : public KParts::BrowserExtension
@@ -152,18 +174,18 @@ class ListViewBrowserExtension : public KParts::BrowserExtension
 
       virtual void saveState( QDataStream &stream )
         {
-          m_listView->saveState( stream );
+          m_listView->saveNameFilter( stream );
           KParts::BrowserExtension::saveState( stream );
+          m_listView->saveState( stream );
         }
 
       virtual void restoreState( QDataStream &stream )
         {
-          // Note: since restore state currently restores the name filter,
-          // which we need BEFORE opening the URL, we do that one first.
-          // If we add more stuff to restoreState, we may need to split it
-          // into two methods in fact.
-          m_listView->restoreState( stream );
+          // Note: since we need to restore the name filter,
+          // BEFORE opening the URL.
+          m_listView->restoreNameFilter( stream );
           KParts::BrowserExtension::restoreState( stream );
+          m_listView->restoreState( stream );
         }
 
    protected slots:
@@ -172,6 +194,7 @@ class ListViewBrowserExtension : public KParts::BrowserExtension
       void copy() { copySelection( false ); }
       void cut() { copySelection( true ); }
       void paste();
+      void rename();
       void trash() { KonqOperations::del(m_listView->listViewWidget(),
                                          KonqOperations::TRASH,
                                          m_listView->listViewWidget()->selectedUrls()); }
