@@ -39,11 +39,13 @@
 class KRootPixmap;
 
 class Konsole : public KMainWindow
-{ Q_OBJECT
+{
+    Q_OBJECT
 
+    friend class KonsoleSessionManaged;
 public:
 
-  Konsole(const char * name, const char* pgm, QStrList & _args, int histon);
+  Konsole(const char * name, const char* pgm, QStrList & _args, int histon, bool);
   ~Konsole();
   void setColLin(int columns, int lines);
   void setFullScreen(bool on);
@@ -57,10 +59,12 @@ private slots:
   void schema_menu_activated(int item);
   void pixmap_menu_activated(int item);
   void keytab_menu_activated(int item);
+  void schema_menu_check();
   void tecRef();
   void newSession();
   void newSessionSelect();
   void newSession(int kind);
+  void updateSchemaMenu();
 
   void changeColumns(int);
   void notifySize(int,int);
@@ -72,12 +76,14 @@ private slots:
 
 protected:
 
+ bool queryClose();
  void saveProperties(KConfig* config);
  void readProperties(KConfig* config);
  void saveGlobalProperties(KConfig* config);
  void readGlobalProperties(KConfig* config);
 
  void showFullScreen();
+ bool skip_exit_query;
 
 private slots:
 
@@ -120,6 +126,8 @@ private:
   TEWidget*      te;
   TESession*     se;
 
+  ColorSchemaList* colors;
+
   KRootPixmap*   rootxpm;
 
   KMenuBar*   menubar;
@@ -134,7 +142,6 @@ private:
   KPopupMenu* m_toolbarSessionsCommands;
 
   KToggleAction *showToolbar;
-  int         n_toolbarheight;
   KToggleAction *showMenubar;
   KToggleAction *showScrollbar;
   bool        b_scroll;
@@ -144,6 +151,8 @@ private:
   KSelectAction *selectFont;
   KSelectAction *selectScrollbar;
 
+  KToggleAction *warnQuit;                      // Warn when closing this session on quit
+
   int         n_keytab;
   int         n_font;
   int         n_scroll;
