@@ -30,17 +30,31 @@
 #include <qintdict.h>
 #include <kwin.h>
 
+class KPager;
 class QPopupMenu;
 
-class KPager : public KMainWindow
+class KPagerMainWindow : public KMainWindow
 {
-  Q_OBJECT
+    Q_OBJECT
+
+public:
+    KPagerMainWindow(QWidget *parent=0, const char *name=0);
+    ~KPagerMainWindow();
 
 protected:
     bool queryClose();
 
+    KPager *m_pPager;
+};
+
+class KPager : public QFrame
+{
+    Q_OBJECT
+
+    friend class KPagerMainWindow;
+
 public:
-    KPager(QWidget *parent=0, const char *name=0);
+    KPager(QWidget *parent=0, const char *name=0, WId parentWId = 0);
     ~KPager();
 
     class KWinModule *kwin() const { return m_winmodule; };
@@ -52,19 +66,23 @@ public:
 
     KWin::Info* info( WId win );
 
+    bool isEmbedded() { return m_bIsEmbedded; };
+
+    QSize sizeHint() const;
+
 public slots:
-  void configureDialog();
+    void configureDialog();
 
-  void slotActiveWindowChanged( WId win );
-  void slotWindowAdded( WId );
-  void slotWindowRemoved( WId );
-  void slotWindowChanged( WId, unsigned int ); 
-  void slotStackingOrderChanged();
-  void slotDesktopNamesChanged();  
-  void slotNumberOfDesktopsChanged(int ndesktops);
-  void slotCurrentDesktopChanged(int);
+    void slotActiveWindowChanged( WId win );
+    void slotWindowAdded( WId );
+    void slotWindowRemoved( WId );
+    void slotWindowChanged( WId, unsigned int );
+    void slotStackingOrderChanged();
+    void slotDesktopNamesChanged();
+    void slotNumberOfDesktopsChanged(int ndesktops);
+    void slotCurrentDesktopChanged(int);
 
-  void slotGrabWindows();
+    void slotGrabWindows();
 
 protected slots:
     void slotBackgroundChanged(int);
@@ -82,10 +100,10 @@ protected:
     };
 
 protected:
-    class KWinModule *m_winmodule;
-    class QValueList <class Desktop *> m_desktops;
+    KWinModule *m_winmodule;
+    QValueList<class Desktop *> m_desktops;
 
-    class QIntDict<struct KWin::Info> m_windows;
+    QIntDict<KWin::Info> m_windows;
     WId m_activeWin;
 
     const QString lWidth();
@@ -102,6 +120,8 @@ protected:
 
     QTimer *m_grabWinTimer;
     int     m_currentDesktop;
+
+    bool m_bIsEmbedded;
 public:
     static const LayoutTypes c_defLayout;
 };
