@@ -10,9 +10,10 @@
 
 #include <qdialog.h>
 #include <qcolor.h>
-#include <qpushbutton.h>
 #include "saver.h"
 
+class KColorButton;
+
 
 class KBlankSaver : public kScreenSaver
 {
@@ -41,13 +42,13 @@ protected:
 	void readSettings();
 
 private slots:
-	void slotColor();
+	void slotColor( const QColor & );
 	void slotOkPressed();
 
 private:
 	QWidget *preview;
 	KBlankSaver *saver;
-	QPushButton *colorPush;
+	KColorButton *colorPush;
 
 	QColor color;
 };
