@@ -278,28 +278,14 @@ void kHopSaver::setPoints( int p )
 
 void kHopSaver::readSettings()
 {
-    KConfig *config = KGlobal::config();
-	config->setGroup( "Settings" );
+    KConfig *config = klock_config();
+    config->setGroup( "Settings" );
 
-	QString str;
+    speed = MAXSPEED - config->readNumEntry( "Speed", MAXSPEED - (MAXSPEED-MINSPEED)/2);
+    maxLevels = config->readNumEntry( "MaxLevels", DEFBATCH );
+    numPoints = config->readNumEntry( "NumPoints", DEFCYCLES );
 
-	str = config->readEntry( "Speed" );
-	if ( !str.isNull() )
-		speed = MAXSPEED - atoi( str );
-	else
-		speed = (MAXSPEED-MINSPEED)/2;
-
-	str = config->readEntry( "MaxLevels" );
-	if ( !str.isNull() )
-		maxLevels = atoi( str );
-	else
-		maxLevels = DEFBATCH;
-
-	str = config->readEntry( "NumPoints" );
-	if ( !str.isNull() )
-		numPoints = atoi( str );
-	else
-		numPoints = DEFCYCLES;
+    delete config;
 }
 
 void kHopSaver::slotTimeout()
@@ -394,31 +380,19 @@ kHopSetup::kHopSetup( QWidget *parent, const char *name )
 
 void kHopSetup::readSettings()
 {
-	KConfig *config = KGlobal::config();
-	config->setGroup( "Settings" );
+    KConfig *config = klock_config();
+    config->setGroup( "Settings" );
 
-	QString str;
+    speed = config->readNumEntry( "Speed", speed );
+    if ( speed > MAXSPEED )
+	speed = MAXSPEED;
+    else if ( speed < MINSPEED )
+	speed = MINSPEED;
 
-	str = config->readEntry( "Speed" );
-	if ( !str.isNull() )
-		speed = atoi( str );
+    maxLevels = config->readNumEntry( "MaxLevels", DEFBATCH );
+    numPoints = config->readNumEntry( "NumPoints", DEFCYCLES );
 
-	if ( speed > MAXSPEED )
-		speed = MAXSPEED;
-	else if ( speed < MINSPEED )
-		speed = MINSPEED;
-
-	str = config->readEntry( "MaxLevels" );
-	if ( !str.isNull() )
-		maxLevels = atoi( str );
-	else
-		maxLevels = DEFBATCH;
-
-	str = config->readEntry( "NumPoints" );
-	if ( !str.isNull() )
-		numPoints = atoi( str );
-	else
-		numPoints = DEFCYCLES;
+    delete config;
 }
 
 void kHopSetup::slotSpeed( int num )
@@ -447,23 +421,24 @@ void kHopSetup::slotPoints( int num )
 
 void kHopSetup::slotOkPressed()
 {
-	KConfig *config = KGlobal::config();
-	config->setGroup( "Settings" );
+    KConfig *config = klock_config();
+    config->setGroup( "Settings" );
 
-	QString sspeed;
-	sspeed.setNum( speed );
-	config->writeEntry( "Speed", sspeed );
+    QString sspeed;
+    sspeed.setNum( speed );
+    config->writeEntry( "Speed", sspeed );
 
-	QString slevels;
-	slevels.setNum( maxLevels );
-	config->writeEntry( "MaxLevels", slevels );
+    QString slevels;
+    slevels.setNum( maxLevels );
+    config->writeEntry( "MaxLevels", slevels );
 
-	QString spoints;
-	spoints.setNum( numPoints );
-	config->writeEntry( "NumPoints", spoints );
+    QString spoints;
+    spoints.setNum( numPoints );
+    config->writeEntry( "NumPoints", spoints );
 
-	config->sync();
-	accept();
+    config->sync();
+    delete config;
+    accept();
 }
 
 void kHopSetup::slotAbout()
