@@ -3,16 +3,16 @@
  *
  * Based on xmatrix, xscreensaver by Jamie Zawinski <jwz@jwz.org> Copyright (c) 1999
  * ported to KDE 1.1.2 by Dmitry DELTA Malykhanov <d.malykhanov@iname.com> in August 1999
- * ported to KDE 2.0 and setup dialog fixup by Thorsten Westheider 
+ * ported to KDE 2.0 and setup dialog fixup by Thorsten Westheider
  * <thorsten.westheider@teleos-web.de> in March 2000
- * 
+ *
  * Additional contributors:
  *
  * kblankscrn - Basic screen saver for KDE Copyright (c)  Martin R. Jones 1996
  * layout management added 1998/04/19 by Mario Weilguni <mweilguni@kde.org>
  *
  */
- 
+
 #include <stdio.h>
 #include <stdlib.h>
 
@@ -22,16 +22,18 @@
 #include <qcolor.h>
 #include <qlabel.h>
 #include <qlayout.h>
-#include <qmessagebox.h>
 #include <qradiobutton.h>
 #include <qslider.h>
 
 #include <kapp.h>
+#include <kdebug.h>
 #include <kbuttonbox.h>
 #include <kcolordlg.h>
 #include <kconfig.h>
+#include <kglobal.h>
 #include <klocale.h>
 #include <krandomsequence.h>
+#include <kmessagebox.h>
 
 #include "helpers.h"
 
@@ -53,57 +55,32 @@ static const QString inserts[] = { "top", "bottom", "both" };
 void KMatrixSaverCfg::readSettings() {
   QString str;
 
-  KConfig *config = kapp->sessionConfig();
+  KConfig *config = klock_config();
   config->setGroup("Settings");
 
-  str = config->readEntry("BackgroundColor");
-  if ( !str.isNull() )
-    background.setNamedColor( str );
-  else
-    background = Qt::black;
-  str = config->readEntry("ForegroundColor");
-  if ( !str.isNull() )
-    foreground.setNamedColor( str );
-  else
-    foreground = Qt::green;
+  background = config->readColorEntry("BackgroundColor", &Qt::black);
+  foreground = config->readColorEntry("ForegroundColor", &Qt::green);
   //str = config->readEntry("Mono");
   mono = False;
-  str = config->readEntry("Density");
-  if( !str.isNull() )
-    density = str.toInt();
-  else
-    density = 25;
-  str = config->readEntry("Speed");
-  if( !str.isNull() )
-    speed = str.toInt();
-  else
-    speed = 100;
-  str = config->readEntry("Insert");
-  if( !str.isNull() )
-    insert = str;
-  else
-    insert = "bottom";
+  density = config->readNumEntry("Density", 25);
+  speed = config->readNumEntry("Speed", 100);
+  insert = config->readEntry("Insert", "bottom");
+
+  delete config;
 }
 
 void KMatrixSaverCfg::writeSettings() {
-  KConfig *config = kapp->sessionConfig();
+  KConfig *config = klock_config();
   config->setGroup( "Settings" );
 
-  QString str;
-
-  str.sprintf("#%02x%02x%02x",
-	      background.red(), background.green(), background.blue());
-  config->writeEntry("BackgroundColor", str);
-  str.sprintf("#%02x%02x%02x",
-	      foreground.red(), foreground.green(), foreground.blue());
-  config->writeEntry("ForegroundColor", str);
+  config->writeEntry("BackgroundColor", background);
+  config->writeEntry("ForegroundColor", foreground);
   //config->writeEntry("Mono", str);
-  str.sprintf("%d", density);
-  config->writeEntry("Density", str);
-  str.sprintf("%d", speed);
-  config->writeEntry("Speed", str);
+  config->writeEntry("Density", density);
+  config->writeEntry("Speed", speed);
   config->writeEntry("Insert", insert);
   config->sync();
+  delete config;
 }
 
 //--------------------------------------------------------------------
@@ -130,7 +107,7 @@ int setupScreenSaver() {
   return dlg.exec();
 }
 
-const char *getScreenSaverName() {
+QString getScreenSaverName() {
   return i18n("Kmatrix \"The Matrix\" movie style screen saver");
 }
 
@@ -138,7 +115,7 @@ void exposeScreenSaver( int x, int y, int width, int height ) {
   if ( saver ) {
   //  saver->expose( x, y, width, height );
   }
-} 
+}
 
 //--------------------------------------------------------------------
 // KMatrixSaver code
@@ -239,7 +216,7 @@ void KMatrixSaver::shutdown_matrix() {
  * the above copyright notice appear in all copies and that both that
  * copyright notice and this permission notice appear in supporting
  * documentation.  No representations are made about the suitability of this
- * software for any purpose.  It is provided "as is" without express or 
+ * software for any purpose.  It is provided "as is" without express or
  * implied warranty.
  *
  * Matrix -- simulate the text scrolls from the movie "The Matrix".
@@ -298,7 +275,6 @@ void KMatrixSaver::load_images () {
 /* initialize matrix */
 void KMatrixSaver::init_matrix () {
   XGCValues gcv;
-  char *insert;
   state = (m_state *) calloc (sizeof(*state), 1);
   state->dpy = qt_xdisplay();
   state->window = mDrawable;
@@ -328,35 +304,30 @@ void KMatrixSaver::init_matrix () {
 
   state->density = cfg.density;
 
-  insert = strdup(cfg.insert);
-  if (insert && !strcmp(insert, "top"))
+  QString insert = cfg.insert;
+  if (insert == "top")
     {
       state->insert_top_p = True;
       state->insert_bottom_p = False;
     }
-  else if (insert && !strcmp(insert, "bottom"))
+  else if (insert == "bottom")
     {
       state->insert_top_p = False;
       state->insert_bottom_p = True;
     }
-  else if (insert && !strcmp(insert, "both"))
+  else if (insert == "both")
     {
       state->insert_top_p = True;
       state->insert_bottom_p = True;
     }
   else
     {
-      if (insert && *insert)
-        fprintf (stderr,
-                 "%s: `insert' must be `top', `bottom', or `both', not `%s'\n",
-                 progname, insert);
+      if (!insert.isEmpty())
+        kdError() << "`insert' must be `top', `bottom', or `both', not " << insert << endl;
       state->insert_top_p = False;
       state->insert_bottom_p = True;
     }
 
-  if (insert)
-    free (insert);
-
   /* return state; */
 }
 
@@ -571,17 +542,17 @@ KMatrixSetup::KMatrixSetup( QWidget *parent, const char *name )
   /*
   densityEd = new QLineEdit(this);
   fixed_size(densityEd);
-  tmps.sprintf("%d", cfg.density);
+  tmps.setNum(cfg.density);
   densityEd->setText(tmps);
-  connect(densityEd, SIGNAL(textChanged(const char *)),
-	  SLOT(slotDensityEdit(const char *)));
+  connect(densityEd, SIGNAL(textChanged(const QString &)),
+	  SLOT(slotDensityEdit(const QString &)));
   dhb->addWidget(densityEd);
   */
 #undef Below
   densitySld = new QSlider(0, 100, 1, cfg.density, QSlider::Horizontal,
 			   this, "Density");
-  densitySld->setTickmarks(QSlider::Below);                   
-  densitySld->setTickInterval(10);                   
+  densitySld->setTickmarks(QSlider::Below);
+  densitySld->setTickInterval(10);
   densitySld->setFixedHeight(densitySld->sizeHint().height());
   connect( densitySld, SIGNAL(valueChanged(int)), SLOT(slotDensity(int)));
   tl11->addWidget(densitySld);
@@ -597,16 +568,16 @@ KMatrixSetup::KMatrixSetup( QWidget *parent, const char *name )
   /*
   speedEd = new QLineEdit(this);
   fixed_size(speedEd);
-  tmps.sprintf("%d", SPEED2SL(cfg.speed));
+  tmps.setNum(SPEED2SL(cfg.speed));
   speedEd->setText(tmps);
-  connect(speedEd, SIGNAL(textChanged(const char *)),
-	  SLOT(slotSpeedEdit(const char *)));
+  connect(speedEd, SIGNAL(textChanged(const QString &)),
+	  SLOT(slotSpeedEdit(const QString &)));
   shb->addWidget(speedEd);
   */
   speedSld = new QSlider(0, 100, 1, SPEED2SL(cfg.speed), QSlider::Horizontal,
 			 this, "Speed");
-  speedSld->setTickmarks(QSlider::Below);                    
-  speedSld->setTickInterval(10);                   
+  speedSld->setTickmarks(QSlider::Below);
+  speedSld->setTickInterval(10);
   speedSld->setFixedHeight(speedSld->sizeHint().height());
   connect( speedSld, SIGNAL(valueChanged(int)), SLOT(slotSpeed(int)));
   tl11->addWidget(speedSld);
@@ -628,13 +599,13 @@ KMatrixSetup::KMatrixSetup( QWidget *parent, const char *name )
   rb = new QRadioButton( insertRbGrp);
   rb->setText( i18n("Bottom"));
   min_size(rb);
-  if( !qstrcmp(cfg.insert, inserts[i++]) ) rb->setChecked(TRUE);
+  if( cfg.insert == inserts[i++] ) rb->setChecked(TRUE);
     else rb->setChecked(FALSE);
   grpvbox->addWidget(rb);
   rb = new QRadioButton( insertRbGrp);
   rb->setText( i18n("Both"));
   min_size(rb);
-  if( !qstrcmp(cfg.insert, inserts[i++]) ) rb->setChecked(TRUE);
+  if( cfg.insert == inserts[i++] ) rb->setChecked(TRUE);
     else rb->setChecked(FALSE);
   grpvbox->addWidget(rb);
   connect(insertRbGrp, SIGNAL(clicked(int)), SLOT(slotInsert(int)));
@@ -659,7 +630,7 @@ KMatrixSetup::KMatrixSetup( QWidget *parent, const char *name )
   connect(button, SIGNAL(clicked()), SLOT(slotAbout()));
   bbox->addStretch(1);
 
-  button = bbox->addButton( i18n("OK"));	
+  button = bbox->addButton( i18n("OK"));
   connect( button, SIGNAL( clicked() ), SLOT( slotOkPressed() ) );
 
   button = bbox->addButton(i18n("Cancel"));
@@ -701,10 +672,9 @@ void KMatrixSetup::slotForegrColor() {
 }
 
 void KMatrixSetup::slotDensity(int val) {
-  QString tmp;
   setDensity(val);
   // update edit control
-  // tmp.sprintf("%d", val);
+  // tmp.setNum(val);
   // densityEd->setText(tmp);
 }
 
@@ -715,10 +685,9 @@ void KMatrixSetup::setDensity(int val) {
 }
 
 void KMatrixSetup::slotSpeed(int val) {
-  QString tmp;
   setSpeed(val);
   // update edit control
-  // tmp.sprintf("%d", val);
+  // tmp.setNum(val);
   // speedEd->setText(tmp);
 }
 
@@ -734,15 +703,15 @@ void KMatrixSetup::slotInsert(int id) {
   saver->setInsert(cfg.insert);
 }
 
-void KMatrixSetup::slotDensityEdit(const char *s) {
-  int val = atoi(s);
+void KMatrixSetup::slotDensityEdit(const QString &s) {
+  int val = s.toInt();
   //fprintf(stderr, "slotDensityEdit: arg = %s\n", s);
   setDensity(val);
   densitySld->setValue(val);
 }
 
-void KMatrixSetup::slotSpeedEdit(const char *s) {
-  int val = atoi(s);
+void KMatrixSetup::slotSpeedEdit(const QString &s) {
+  int val = s.toInt();
   //fprintf(stderr, "slotSpeedEdit: arg = %s\n", s);
   setSpeed(val);
   speedSld->setValue(val);
@@ -755,7 +724,7 @@ void KMatrixSetup::slotOkPressed() {
 }
 
 void KMatrixSetup::slotAbout() {
-  QMessageBox::message(i18n("About KMatrix"),
+  KMessageBox::about(0,
 		       i18n("KMatrix\n\n"
 "based on xmatrix\n"
 "Copyright (C) 1999 by Jamie Zawinski <jwz@jwz.org>\n"
@@ -763,7 +732,7 @@ void KMatrixSetup::slotAbout() {
 "<d.malykhanov@iname.com>\n"
 "Ported to KDE 2.0 by Thorsten Westheider\n"
 "<thorsten.westheider@teleos-web.de>"),
-		       i18n("OK"));
+                       i18n("About KMatrix"));
 }
 
 #include "matrix.moc"
