@@ -118,12 +118,12 @@ FIXME: this could be clearer done by a calculation on the position.
 -- ------------------------------------------------------------------------ */
 #include "config.h"
 
-//#define QT_CLEAN_NAMESPACE
 #include <qslider.h>
 #include <qlayout.h>
 #include <kglobal.h>
 #include <kconfig.h>
 #include <krandomsequence.h>
+#include <kdebug.h>
 
 #include "xlock.h"
 #ifdef HAVE_CONFIG_H
@@ -177,10 +177,11 @@ void doneGL()
 
 static XVisualInfo *glVis[MAXSCREENS];
 
-int getVisual(XVisualInfo * wantVis){
+int getVisual(XVisualInfo * wantVis, int visual_count) {
 
         Display    *display = dsp;
         static int  first;
+	int i;
 
 
         if (first) {
@@ -205,13 +206,17 @@ int getVisual(XVisualInfo * wantVis){
                 }
         }
 
+        // Make sure we have a visual
+        if (!glVis[screen])
+	  return (0);
+
         /* check if GL can render into root window. */
+        for(i=0;i<visual_count;i++)
+	  if ( (glVis[screen]->visual == (wantVis+i)->visual) )
+	    return (1); // success
 
-        if ((!glVis[screen]) || (glVis[screen]->visual != wantVis->visual)) {
-                return (0);
-        }
-
-        return (1);             /* success */
+        // The visual we received did not match one we asked for
+        return (0);
 }
 
 void initGL(Window window)
@@ -251,10 +256,9 @@ void initGL(Window window)
   /* if User asked for mono.  Might fail on 16/24 bit displays,
      so fall back on color, but keep the mono "look & feel". */
 
-  if (!getVisual(wantVis)) {
-    if (!getVisual(wantVis)) {
-      (void) fprintf(stderr, i18n(
-           "GL can not render with root visual\n"));
+  if (!getVisual(wantVis, n)) {
+    if (!getVisual(wantVis, n)) {
+      kdError() << i18n("GL can not render with root visual\n");
       return;
     }
   }
@@ -269,6 +273,9 @@ void initGL(Window window)
 
   glXMakeCurrent(display, window, glx_context);
 
+  // Make sure we draw to the correct buffer.
+  glDrawBuffer(GL_FRONT);
+
   if (mono) {
     glIndexi(WhitePixel(display, screen));
     glClearIndex(BlackPixel(display, screen));
