@@ -56,7 +56,7 @@
 static KScienceSaver *saver = 0;
 
 struct {
-	char name[32];
+	QString name;
 	bool inverseEnable;
 	} modeInfo[MAX_MODES];
 
@@ -64,22 +64,22 @@ enum { MODE_WHIRL=0, MODE_CURVATURE, MODE_SPHERE, MODE_WAVE, MODE_EXPONENTIAL, M
 
 void initModeInfo()
 {
-	strncpy( modeInfo[MODE_WHIRL].name, i18n( "Whirl" ), 32 );
+	modeInfo[MODE_WHIRL].name = i18n( "Whirl" );
 	modeInfo[MODE_WHIRL].inverseEnable = true;
 
-	strncpy( modeInfo[MODE_SPHERE].name, i18n( "Sphere" ), 32 );
+	modeInfo[MODE_SPHERE].name = i18n( "Sphere" );
 	modeInfo[MODE_SPHERE].inverseEnable = true;
 
-	strncpy( modeInfo[MODE_EXPONENTIAL].name, i18n( "Exponential" ), 32 );
+	modeInfo[MODE_EXPONENTIAL].name = i18n( "Exponential" );
 	modeInfo[MODE_EXPONENTIAL].inverseEnable = false;
 
-	strncpy( modeInfo[MODE_CONTRACTION].name, i18n( "Contraction" ), 32 );
+	modeInfo[MODE_CONTRACTION].name = i18n( "Contraction" );
 	modeInfo[MODE_CONTRACTION].inverseEnable = false;
 
-	strncpy( modeInfo[MODE_WAVE].name, i18n( "Wave" ), 32 );
+	modeInfo[MODE_WAVE].name = i18n( "Wave" );
 	modeInfo[MODE_WAVE].inverseEnable = false;
 
-	strncpy( modeInfo[MODE_CURVATURE].name, i18n( "Curvature" ), 32 );
+	modeInfo[MODE_CURVATURE].name = i18n( "Curvature" );
 	modeInfo[MODE_CURVATURE].inverseEnable = true;
 }
 
@@ -175,9 +175,9 @@ void KPrepareDlg::hide()
 	frame->hide();
 }
 
-void KPrepareDlg::setText( const char *msg )
+void KPrepareDlg::setText( const QString & msg )
 {
-	if( msg != 0 )
+	if( !msg.isNull() ) // FIXME: why??
 	{
 		label->setText( msg );	
 		kapp->processEvents();
@@ -215,8 +215,9 @@ KScienceSaver::KScienceSaver( Drawable drawable, bool s, bool gP ) : kScreenSave
 	moveOn = true;
 	grabPixmap = gP;
 	setup = s;
-	showDialog = !setup && 	(RootWindow( qt_xdisplay(), qt_xscreen() ) != drawable) &&
-                     mWidth >= 320 && mHeight >= 200;
+//	showDialog = !setup && 	(RootWindow( qt_xdisplay(), qt_xscreen() ) != drawable) &&
+//                     mWidth >= 320 && mHeight >= 200;
+	showDialog = false;  // dialog is grabbed also
 
 	if( showDialog )
 	{
@@ -654,7 +655,7 @@ void KScienceSaver::setHideBG( bool b )
 
 void KScienceSaver::readSettings()
 {
-    KConfig *config = KApplication::kApplication()->config();
+    KConfig *config = klock_config();
         QString sMode;
   
 	config->setGroup( "Settings" );
@@ -676,6 +677,7 @@ void KScienceSaver::readSettings()
 
 	vx = copysign( moveX[mode], vx );
 	vy = copysign( moveY[mode], vy );
+	delete config;
 }              
 
 void KScienceSaver::do_refresh( const QRect & rect )
@@ -1161,7 +1163,7 @@ void KScienceSetup::updateSettings()
 // read settings from config file
 void KScienceSetup::readSettings()
 {
-    KConfig *config = KApplication::kApplication()->config();
+    KConfig *config = klock_config();
         QString sMode;
   
 	config->setGroup( "Settings" );
@@ -1180,6 +1182,7 @@ void KScienceSetup::readSettings()
 		gravity[i]   = config->readBoolEntry( "Gravity",   SCI_DEFAULT_GRAVITY);
 		hideBG[i]    = config->readBoolEntry( "HideBG",    SCI_DEFAULT_HIDE);
 	}
+	delete config;
 }  
 
 void KScienceSetup::slotMode( int m )
@@ -1272,7 +1275,7 @@ void KScienceSetup::slotSliderReleased()
 // Ok pressed - save settings and exit
 void KScienceSetup::slotOkPressed()
 {
-    KConfig *config = KApplication::kApplication()->config();
+    KConfig *config = klock_config();
 	QString sSize, sSpeed, sIntensity, sMode;
 
 	config->setGroup( "Settings" );
@@ -1293,6 +1296,7 @@ void KScienceSetup::slotOkPressed()
 	}
 
 	config->sync();
+	delete config;
 
 	accept();
 }
