@@ -10,8 +10,10 @@
 #include <qlist.h>
 #include <qdialog.h>
 #include <qlineedit.h>
+#include <krandomsequence.h>
 #include "saver.h"
 
+
 class kSwarmSaver : public kScreenSaver
 {
 	Q_OBJECT
@@ -29,6 +31,7 @@ protected slots:
 	void slotTimeout();
 
 protected:
+	KRandomSequence rnd;
 	QTimer      timer;
 	int         colorContext;
 
