@@ -1,7 +1,7 @@
 /*
     KTop, the KDE Task Manager and System Monitor
    
-	Copyright (c) 1999, 2000 Chris Schlaeger <cs@kde.org>
+	Copyright (c) 1999 - 2001 Chris Schlaeger <cs@kde.org>
     
     This program is free software; you can redistribute it and/or
     modify it under the terms version 2 of of the GNU General Public
@@ -19,7 +19,7 @@
 	KTop is currently maintained by Chris Schlaeger <cs@kde.org>. Please do
 	not commit any changes without consulting me first. Thanks!
 
-	$Id: ProcessController.cc,v 1.23 2000/10/18 16:11:49 coolo Exp $
+	$Id: ProcessController.cc,v 1.29 2001/01/27 20:59:49 cschlaeg Exp $
 */
 
 #include <assert.h>
@@ -31,6 +31,7 @@
 #include <kmessagebox.h>
 #include <kdebug.h>
 
+#include "SignalIDs.h"
 #include "ksysguard.h"
 #include "SensorManager.h"
 #include "ProcessController.moc"
@@ -38,6 +39,21 @@
 ProcessController::ProcessController(QWidget* parent, const char* name)
 	: SensorDisplay(parent, name)
 {
+	dict.setAutoDelete(true);
+	dict.insert("Name", new QString(i18n("Name")));
+	dict.insert("PID", new QString(i18n("PID")));
+	dict.insert("PPID", new QString(i18n("PPID")));
+	dict.insert("UID", new QString(i18n("UID")));
+	dict.insert("GID", new QString(i18n("GID")));
+	dict.insert("Status", new QString(i18n("Status")));
+	dict.insert("User%", new QString(i18n("User%")));
+	dict.insert("System%", new QString(i18n("System%")));
+	dict.insert("Nice", new QString(i18n("Nice")));
+	dict.insert("VmSize", new QString(i18n("VmSize")));
+	dict.insert("VmRss", new QString(i18n("VmRss")));
+	dict.insert("Login", new QString(i18n("Login")));
+	dict.insert("Command", new QString(i18n("Command")));
+
 	// Create the box that will contain the other widgets.
 	box = new QGroupBox(this, "pList_box"); 
 	CHECK_PTR(box);
@@ -49,13 +65,15 @@ ProcessController::ProcessController(QWidget* parent, const char* name)
 	// Create the table that lists the processes.
 	pList = new ProcessList(this, "pList");    
 	CHECK_PTR(pList);
+	connect(pList, SIGNAL(killProcess(int, int)),
+			this, SLOT(killProcess(int, int)));
 
 	/* All RMB clicks to the plist widget will be handled by 
 	 * SensorDisplay::eventFilter. */
 	pList->installEventFilter(this);
-
+	
 	// Create the check box to switch between tree view and list view.
-	xbTreeView = new QCheckBox(i18n("Tree"), this, "xbTreeView");
+	xbTreeView = new QCheckBox(i18n("&Tree"), this, "xbTreeView");
 	CHECK_PTR(xbTreeView);
 	xbTreeView->setMinimumSize(xbTreeView->sizeHint());
 	connect(xbTreeView, SIGNAL(toggled(bool)),
@@ -78,19 +96,20 @@ ProcessController::ProcessController(QWidget* parent, const char* name)
 			pList, SLOT(setFilterMode(int)));
 
 	// Create the check box to pause the automatic list update.
-	xbPause = new QCheckBox(i18n("Pause"), this, "xbPause");
+	xbPause = new QCheckBox(i18n("&Pause"), this, "xbPause");
 	CHECK_PTR(xbPause);
 	xbPause->setMinimumSize(xbPause->sizeHint());
 	connect(xbPause, SIGNAL(toggled(bool)), this, SLOT(togglePause(bool)));
 
 	// Create the 'Refresh' button.
-	bRefresh = new QPushButton(i18n("Refresh"), this, "bRefresh");
+	bRefresh = new QPushButton(i18n("&Refresh"), this, "bRefresh");
 	CHECK_PTR(bRefresh);
 	bRefresh->setMinimumSize(bRefresh->sizeHint());
 	connect(bRefresh, SIGNAL(clicked()), this, SLOT(updateList()));
 
 	// Create the 'Kill' button.
-	bKill = new QPushButton(i18n("Kill"), this, "bKill");
+	// TODO: we need to check first if the backend supports the 'kill' command.
+	bKill = new QPushButton(i18n("&Kill"), this, "bKill");
 	CHECK_PTR(bKill);
 	bKill->setMinimumSize(bKill->sizeHint());
 	connect(bKill, SIGNAL(clicked()), this, SLOT(killProcess()));
@@ -121,7 +140,7 @@ ProcessController::ProcessController(QWidget* parent, const char* name)
 
 	setMinimumSize(sizeHint());
 
-	modified = FALSE;
+	modified = false;
 }
 
 void
@@ -137,7 +156,7 @@ ProcessController::addSensor(const QString& hostName,
 							 const QString& sensorName,
 							 const QString& title)
 {
-	registerSensor(hostName, sensorName);
+	registerSensor(hostName, sensorName, title);
 	sendRequest(hostName, "ps?", 1);
 
 	if (title.isEmpty())
@@ -145,17 +164,25 @@ ProcessController::addSensor(const QString& hostName,
 	else
 		box->setTitle(title);
 
-	return (TRUE);
+	return (true);
 }
 
 void
 ProcessController::updateList()
 {
-	sendRequest(*hostNames.at(0), "ps", 2);
+	sendRequest(sensors.at(0)->hostName, "ps", 2);
 }
 
 void
-ProcessController::killProcess(void)
+ProcessController::killProcess(int pid, int sig)
+{
+	sendRequest(sensors.at(0)->hostName,
+				QString("kill %1 %2" ).arg(pid).arg(sig), 3);
+	updateList();
+}
+
+void
+ProcessController::killProcess()
 {
 	const QValueList<int>& selectedPIds = pList->getSelectedPIds();
 
@@ -179,12 +206,17 @@ ProcessController::killProcess(void)
 	// send kill signal to all seleted processes
 	QValueListConstIterator<int> it;
 	for (it = selectedPIds.begin(); it != selectedPIds.end(); ++it)
-		sendRequest(*hostNames.at(0), QString("kill %1 9" ).arg(*it), 3);
+		sendRequest(sensors.at(0)->hostName, QString("kill %1 %2" ).arg(*it)
+					.arg(MENU_ID_SIGKILL), 3);
+	updateList();
 }
 
 void
 ProcessController::answerReceived(int id, const QString& answer)
 {
+	/* We received something, so the sensor is probably ok. */
+	sensorError(id, false);
+
 	switch (id)
 	{
 	case 1:
@@ -196,6 +228,7 @@ ProcessController::answerReceived(int id, const QString& answer)
 		{
 			kdDebug () << "ProcessController::answerReceived(1)"
 				  "wrong number of lines [" <<  answer << "]" << endl;
+			sensorError(id, true);
 			return;
 		}
 		SensorTokenizer headers(lines[0], '\t');
@@ -203,7 +236,14 @@ ProcessController::answerReceived(int id, const QString& answer)
 		
 		pList->removeColumns();
 		for (unsigned int i = 0; i < headers.numberOfTokens(); i++)
-			pList->addColumn(headers[i], colTypes[i]);
+		{
+			QString header;
+			if (dict[headers[i]])
+				header = *dict[headers[i]];
+			else
+				header = headers[i];
+			pList->addColumn(header, colTypes[i]);
+		}
 
 		timerOn();
 
@@ -216,7 +256,10 @@ ProcessController::answerReceived(int id, const QString& answer)
 		 * information is corrupted. As a workaround we simply restart the
 		 * connection. The corruption seems to affect only the ps output. */
 		if (!pList->update(answer))
-			SensorMgr->resynchronize(*hostNames.at(0));
+		{
+			sensorError(id, true);
+			SensorMgr->resynchronize(sensors.at(0)->hostName);
+		}
 		break;
 	case 3:
 		// result of kill operation, we currently don't care about it.
@@ -225,14 +268,14 @@ ProcessController::answerReceived(int id, const QString& answer)
 }
 
 void
-ProcessController::sensorError(bool err)
+ProcessController::sensorError(int, bool err)
 {
-	if (err == sensorOk)
+	if (err == sensors.at(0)->ok)
 	{
-		// this happens only when the sensorOk status needs to be changed.
-		box->setEnabled(!err);
-		sensorOk = !err;
+		/* This happens only when the sensorOk status needs to be changed. */
+		sensors.at(0)->ok = !err;
 	}
+	pList->setSensorOk(sensors.at(0)->ok);
 }
 
 bool
@@ -247,25 +290,38 @@ ProcessController::load(QDomElement& el)
 	xbPause->setChecked(el.attribute("pause").toInt());
 	togglePause(el.attribute("pause").toInt());
 
-	int filter = el.attribute("filter").toUInt();
+	uint filter = el.attribute("filter").toUInt();
 	cbFilter->setCurrentItem(filter);
 	filterModeChanged(filter);
 
-	modified = FALSE;
+	uint col = el.attribute("sortColumn").toUInt();
+	bool inc = el.attribute("incrOrder").toUInt();
+
+	if (!pList->load(el))
+		return (false);
+
+	pList->setSortColumn(col, inc);
+
+	modified = false;
 
 	return (result);
 }
 
 bool
-ProcessController::save(QDomDocument&, QDomElement& display)
+ProcessController::save(QDomDocument& doc, QDomElement& display)
 {
-	display.setAttribute("hostName", *hostNames.at(0));
-	display.setAttribute("sensorName", *sensorNames.at(0));
+	display.setAttribute("hostName", sensors.at(0)->hostName);
+	display.setAttribute("sensorName", sensors.at(0)->name);
 	display.setAttribute("tree", (uint) xbTreeView->isChecked());
 	display.setAttribute("pause", (uint) xbPause->isChecked());
 	display.setAttribute("filter", cbFilter->currentItem());
+	display.setAttribute("sortColumn", pList->getSortColumn());
+	display.setAttribute("incrOrder", pList->getIncreasing());
 
-	modified = FALSE;
+	if (!pList->save(doc, display))
+		return (false);
 
-	return (TRUE);
+	modified = false;
+
+	return (true);
 }
