@@ -20,7 +20,7 @@
 	KTop is currently maintained by Chris Schlaeger <cs@kde.org>. Please do
 	not commit any changes without consulting me first. Thanks!
 
-	$Id: WorkSheet.cc,v 1.23 2000/10/09 21:30:11 zander Exp $
+	$Id: WorkSheet.cc,v 1.31 2001/02/06 17:31:33 cschlaeg Exp $
 */
 
 #include <qdragobject.h>
@@ -28,6 +28,8 @@
 #include <qfile.h>
 #include <qtextstream.h>
 #include <qpopupmenu.h>
+#include <qwhatsthis.h>
+
 #include <kmessagebox.h>
 #include <klocale.h>
 #include <kdebug.h>
@@ -36,6 +38,7 @@
 #include "SensorManager.h"
 #include "FancyPlotter.h"
 #include "MultiMeter.h"
+#include "DancingBars.h"
 #include "ProcessController.h"
 #include "WorkSheet.moc"
 
@@ -94,7 +97,7 @@ WorkSheet::load(const QString& fN)
 						   .arg(fileName));
 		return (FALSE);
 	}
-    
+
 	// Parse the XML file.
 	QDomDocument doc;
 	// Read in file and check for a valid XML header.
@@ -153,7 +156,8 @@ WorkSheet::load(const QString& fN)
 		int column = element.attribute("column").toUInt();
 		if (row >= rows || column >= columns)
 		{
-			kdDebug () << "Row or Column out of range (" << row << ", " << column << ")" << endl;
+			kdDebug () << "Row or Column out of range (" << row << ", "
+					   << column << ")" << endl;
 			return (FALSE);
 		}
 
@@ -163,6 +167,8 @@ WorkSheet::load(const QString& fN)
 			newDisplay = new FancyPlotter(this);
 		else if (classType == "MultiMeter")
 			newDisplay = new MultiMeter(this);
+		else if (classType == "DancingBars")
+			newDisplay = new DancingBars(this);
 		else if (classType == "ProcessController")
 			newDisplay = new ProcessController(this);
 		else
@@ -234,13 +240,12 @@ WorkSheet::save(const QString& fN)
 	QFile file(fileName = fN);
 	if (!file.open(IO_WriteOnly))
 	{
-		/* TODO: Change this to "Can't save file %1" after message freeze
-		 * is over. */
-		KMessageBox::sorry(this, i18n("Can't open the file %1")
+		KMessageBox::sorry(this, i18n("Can't save file %1")
 						   .arg(fileName));
 		return (FALSE);
 	}
 	QTextStream s(&file);
+	s.setEncoding(QTextStream::UnicodeUTF8);
 	s << doc;
 	file.close();
 
@@ -251,10 +256,12 @@ WorkSheet::save(const QString& fN)
 SensorDisplay*
 WorkSheet::addDisplay(const QString& hostName, const QString& sensorName,
 					  const QString& sensorType, const QString& sensorDescr,
-					  int r, int c, const QString& displayType)
+					  int r, int c)
 {
-	if (!SensorMgr->engage(hostName))
+	if (!SensorMgr->engageHost(hostName))
 	{
+		/* TODO: This error message is wrong. It needs to be changed
+		 * to "Impossible to connect to ..." after the message freeze. */
 		QString msg = i18n("Unknown hostname \'%1\'!").arg(hostName);
 		KMessageBox::error(this, msg);
 		return (0);
@@ -266,11 +273,34 @@ WorkSheet::addDisplay(const QString& hostName, const QString& sensorName,
 	if (displays[r][c]->isA("QGroupBox"))
 	{
 		SensorDisplay* newDisplay = 0;
-		/* Currently we support one specific sensor display for each
-		 * sensor type. This will change for sure and can then be
-		 * handled with a popup menu that lists all possible sensor
-		 * displays for the sensor type. */
+		/* If the sensor type is supported by more than one display type
+		 * we popup a menu so the user can select what display is wanted. */
 		if (sensorType == "integer")
+		{
+			QPopupMenu pm;
+			pm.insertItem(i18n("Select a display type"), 0);
+			pm.setItemEnabled(0, FALSE);
+			pm.insertSeparator();
+			pm.insertItem(i18n("&Signal Plotter"), 1);
+			pm.insertItem(i18n("&Multimeter"), 2);
+			pm.insertItem(i18n("&BarGraph"), 3);
+			switch (pm.exec(QCursor::pos()))
+			{
+			case 1:
+				newDisplay = new FancyPlotter(this, "FancyPlotter",
+											  sensorDescr);
+				break;
+			case 2:
+				newDisplay = new MultiMeter(this, "MultiMeter", sensorDescr);
+				break;
+			case 3:
+				newDisplay = new DancingBars(this, "DancingBars", sensorDescr);
+				break;
+			default:
+				return (0);
+			}
+		}
+		else if (sensorType == "float")
 		{
 			QPopupMenu pm;
 			pm.insertItem(i18n("Select a display type"), 0);
@@ -287,8 +317,6 @@ WorkSheet::addDisplay(const QString& hostName, const QString& sensorName,
 			case 2:
 				newDisplay = new MultiMeter(this, "MultiMeter", sensorDescr);
 				break;
-			default:
-				return (0);
 			}
 		}
 		else if (sensorType == "table")
@@ -302,7 +330,7 @@ WorkSheet::addDisplay(const QString& hostName, const QString& sensorName,
 	}
 
 	((SensorDisplay*) displays[r][c])->
-		addSensor(hostName, sensorName, displayType);
+		addSensor(hostName, sensorName, sensorDescr);
 
 	modified = TRUE;
 	return ((SensorDisplay*) displays[r][c]);
@@ -379,7 +407,6 @@ WorkSheet::customEvent(QCustomEvent* ev)
 	{
 		// SensorDisplays send out this event if they want to be removed.
 		removeDisplay((SensorDisplay*) ev->data());
-		delete ev;
 	}
 }
 
@@ -389,6 +416,11 @@ WorkSheet::insertDummyDisplay(int r, int c)
 	QGroupBox* dummy = new QGroupBox(this, "dummy frame");
 	dummy->setMinimumSize(40, 25);
 	dummy->setTitle(i18n("Drop sensor here"));
+	QWhatsThis::add(dummy, i18n(
+		"This is an empty space in a work sheet. Drag a sensor from "
+		"the Sensor Browser and drop it here. A sensor display will "
+		"appear that allows you to monitor the values of the sensor "
+		"over time."));
 	displays[r][c] = dummy;
 	lm->addWidget(dummy, r, c);
 	displays[r][c]->show();
