@@ -19,7 +19,7 @@
 	KTop is currently maintained by Chris Schlaeger <cs@kde.org>. Please do
 	not commit any changes without consulting me first. Thanks!
 
-	$Id: Workspace.h,v 1.14 2000/08/25 15:34:03 cschlaeg Exp $
+	$Id: Workspace.h,v 1.16 2000/12/23 22:42:28 cschlaeg Exp $
 */
 
 #ifndef _Workspace_h_
@@ -29,6 +29,8 @@
 #include <qstring.h>
 #include <qlist.h>
 
+#include <kurl.h>
+
 class KConfig;
 class WorkSheet;
 
@@ -52,6 +54,7 @@ public:
 public slots:
 	void newWorkSheet();
 	void loadWorkSheet();
+	void loadWorkSheet(const KURL&);
 	void saveWorkSheet()
 	{
 		saveWorkSheet((WorkSheet*) currentPage());
@@ -60,6 +63,9 @@ public slots:
 	void saveWorkSheetAs();
 	void deleteWorkSheet();
 
+signals:
+	void announceRecentURL(const KURL& url);
+
 private:
 	QList<WorkSheet> sheets;
 	/// Directory that was used for the last load/save.
