@@ -19,7 +19,7 @@
 	KTop is currently maintained by Chris Schlaeger <cs@kde.org>. Please do
 	not commit any changes without consulting me first. Thanks!
 
-	$Id: ksysguard.h,v 1.6 2000/09/01 07:21:24 waba Exp $
+	$Id: ksysguard.h,v 1.9 2001/02/06 17:31:33 cschlaeg Exp $
 */
 
 #ifndef _ktop_h_
@@ -36,6 +36,7 @@
 
 #include "SensorClient.h"
 
+class KRecentFilesAction;
 class KToggleAction;
 class SensorAgent;
 class SensorBrowser;
@@ -65,7 +66,11 @@ k_dcop:
 	QStringList listSensors();
 	QString readSensor(const QString& sensorLocator);
 
+public slots:
+	void registerRecentURL(const KURL& url);
+
 protected:
+
 	virtual void customEvent(QCustomEvent* e);
 	virtual void timerEvent(QTimerEvent*);
 	virtual bool queryClose();
@@ -83,6 +88,7 @@ private:
 	KStatusBar* statusbar;
 
 	QSplitter* splitter;
+	KRecentFilesAction* openRecent;
 	KToggleAction* toolbarTog;
 	KToggleAction* statusBarTog;
 	SensorBrowser* sb;
