@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-	$Id: Command.h,v 1.3 2000/07/11 23:42:58 cschlaeg Exp $
+	$Id: Command.h,v 1.5 2001/02/19 22:27:06 cschlaeg Exp $
 */
 
 #ifndef _Command_h_
@@ -27,17 +27,26 @@
 
 typedef void (*cmdExecutor)(const char*);
 
+extern int ReconfigureFlag;
+extern int CheckSetupFlag;
+
 void initCommand(void);
 
 void exitCommand(void);
 
 void registerCommand(const char* command, cmdExecutor ex);
 
+void removeCommand(const char* command);
+
 void registerMonitor(const char* command, const char* type, cmdExecutor ex,
 					 cmdExecutor iq);
 
+void removeMonitor(const char* command);
+
 void executeCommand(const char* command);
 
 void printMonitors(const char* cmd);
 
+void printTest(const char* cmd);
+
 #endif
