@@ -10,8 +10,11 @@ class QLabel;
 //class QHBoxLayout;
 class QGridLayout;
 
+namespace KWinInternal {
+
 class B2Button : public QButton
 {
+    Q_OBJECT
 public:
     B2Button(Client *_client=0, QWidget *parent=0, const char *name=0)
         : QButton(parent, name){useMiniIcon = false; client = _client;}
@@ -28,13 +31,21 @@ public:
 protected:
     virtual void drawButton(QPainter *p);
     void drawButtonLabel(QPainter *){;}
+    
     bool useMiniIcon;
     KPixmap *pNorm, *pDown, *iNorm, *iDown;
     QColor bg; //only use one color (the rest is pixmap) so forget QPalette ;)
     Client *client;
+    
+    void mousePressEvent( QMouseEvent* e );
+    void mouseReleaseEvent( QMouseEvent* e );
+
+public:
+    int last_button;    
 };
 
 class B2Client;
+
 class B2Titlebar : public QWidget
 {
     Q_OBJECT
@@ -62,7 +73,7 @@ protected:
     B2Client *client;
 };
 
-class B2Client : public Client
+class B2Client : public KWinInternal::Client
 {
     Q_OBJECT
     friend class B2Titlebar;
@@ -82,11 +93,13 @@ protected:
     void stickyChange(bool on);
     void activeChange(bool on);
     void maximizeChange(bool m);
+    void iconChange();
     void doShape();
     MousePosition mousePosition( const QPoint& p ) const;
 private slots:
     void menuButtonPressed();
     void slotReset();
+    void maxButtonClicked();
 private:
     void positionButtons();
     enum ButtonType{BtnMenu=0, BtnSticky, BtnIconify, BtnMax, BtnClose,
@@ -99,9 +112,9 @@ private:
     int bar_x_ofs;
     B2Titlebar *titlebar;
     int in_unobs;
+    
 };
 
-
-
+};
 
 #endif
