@@ -9,12 +9,16 @@
 #include <qlabel.h>
 #include <qdrawutil.h>
 #include <kpixmapeffect.h>
+#include <kstddirs.h>
+#include <kglobal.h>
 #include <klocale.h>
 #include <qbitmap.h>
 #include <qtooltip.h>
 #include "../../workspace.h"
 #include "../../options.h"
 
+using namespace KWinInternal;
+
 extern "C"
 {
     Client *allocate(Workspace *ws, WId w)
@@ -24,15 +28,14 @@ extern "C"
 }
 
 
-
 enum FramePixmap{FrameTop=0, FrameBottom, FrameLeft, FrameRight, FrameTopLeft,
    FrameTopRight, FrameBottomLeft, FrameBottomRight};
 
 static QPixmap *framePixmaps[8];
 static QPixmap *menuPix, *iconifyPix, *closePix, *maxPix, *minmaxPix,
     *pinupPix, *pindownPix;
-static KPixmap *aTitlePix = NULL;
-static KPixmap *iTitlePix = NULL;
+static KPixmap *aTitlePix = 0;
+static KPixmap *iTitlePix = 0;
 static KPixmapEffect::GradientType grType;
 static int maxExtent, titleAlign;
 static bool titleGradient = true;
@@ -53,19 +56,14 @@ static void init_theme()
     
     KConfig *config = KGlobal::config();
     config->setGroup("General");
+    QString tmpStr;
 
-    int i;
-
-    QString baseDir="/usr/local/kde2/share/apps/kwin/";
-    QString localBaseDir="/home/mosfet/.kde/share/apps/kwin/";
-    
-    for(i=0; i < 8; ++i){
-        framePixmaps[i] = new QPixmap(localBaseDir + "/kwmtheme/themepics/" +
-                                      config->readEntry(keys[i], " "));
+    for(int i=0; i < 8; ++i)
+    {
+        framePixmaps[i] = new QPixmap(locate("appdata",
+                                      "pics/"+config->readEntry(keys[i], " ")));
         if(framePixmaps[i]->isNull())
-            warning("Unable to load frame pixmap for %s", keys[i]);
-        else
-            warning("Loaded pixmap %d", i+1);
+            qWarning("Unable to load frame pixmap for %s", keys[i]);
     }
     maxExtent = framePixmaps[FrameTop]->height();
     if(framePixmaps[FrameBottom]->height() > maxExtent)
@@ -75,41 +73,36 @@ static void init_theme()
     if(framePixmaps[FrameRight]->width() > maxExtent)
         maxExtent = framePixmaps[FrameRight]->width();
 
-    menuPix = new QPixmap(localBaseDir + "/kwmtheme/themepics/" +
-                          config->readEntry("menu", " "));
-    iconifyPix = new QPixmap(localBaseDir + "/kwmtheme/themepics/" +
-                             config->readEntry("iconify", " "));
-    maxPix = new QPixmap(localBaseDir + "/kwmtheme/themepics/" +
-                         config->readEntry("maximize", " "));
-    minmaxPix = new QPixmap(localBaseDir + "/kwmtheme/themepics/" +
-                            config->readEntry("maximizedown", " "));
-    closePix = new QPixmap(localBaseDir + "/kwmtheme/themepics/" +
-                           config->readEntry("close", " "));
-    pinupPix = new QPixmap(localBaseDir + "/kwmtheme/themepics/" +
-                           config->readEntry("pinup", " "));
-    pindownPix = new QPixmap(localBaseDir + "/kwmtheme/themepics/" +
-                             config->readEntry("pindown", " "));
-    if(menuPix->isNull())
-        menuPix->load(baseDir + "/kwmtheme/defaultpics/menu.png");
+    menuPix = new QPixmap(locate("appdata",
+                                 "pics/"+config->readEntry("menu", " ")));
+    iconifyPix = new QPixmap(locate("appdata",
+                                    "pics/"+config->readEntry("iconify", " ")));
+    maxPix = new QPixmap(locate("appdata",
+                                "pics/"+config->readEntry("maximize", " ")));
+    minmaxPix = new QPixmap(locate("appdata",
+                                   "pics/"+config->readEntry("maximizedown", " ")));
+    closePix = new QPixmap(locate("appdata",
+                                  "pics/"+config->readEntry("close", " ")));
+    pinupPix = new QPixmap(locate("appdata",
+                                  "pics/"+config->readEntry("pinup", " ")));
+    pindownPix = new QPixmap(locate("appdata",
+                                    "pics/"+config->readEntry("pindown", " ")));
+    if(menuPix->isNull())                           
+        menuPix->load(locate("appdata", "pics/menu.png"));
     if(iconifyPix->isNull())
-        iconifyPix->
-            load(baseDir + "/kwmtheme/defaultpics/iconify.png");
+        iconifyPix->load(locate("appdata", "pics/iconify.png"));
     if(maxPix->isNull())
-        maxPix->
-            load(baseDir +"/kwmtheme/defaultpics/maximize.png");
+        maxPix->load(locate("appdata", "pics/maximize.png"));
     if(minmaxPix->isNull())
-        minmaxPix->
-            load(baseDir + "/kwmtheme/defaultpics/maximizedown.png");
+        minmaxPix->load(locate("appdata", "pics/maximizedown.png"));
     if(closePix->isNull())
-        closePix->load(baseDir + "/kwmtheme/defaultpics/close.png");
+        closePix->load(locate("appdata", "pics/close.png"));
     if(pinupPix->isNull())
-        pinupPix->load(baseDir + "/kwmtheme/defaultpics/pinup.png");
+        pinupPix->load(locate("appdata", "pics/pinup.png"));
     if(pindownPix->isNull())
-        pindownPix->
-            load(baseDir + "/kwmtheme/defaultpics/pindown.png");
+        pindownPix->load(locate("appdata", "pics/pindown.png"));
     
-    
-    QString tmpStr = config->readEntry("TitleAlignment");
+    tmpStr = config->readEntry("TitleAlignment");
     if(tmpStr == "right")
         titleAlign = Qt::AlignRight | Qt::AlignVCenter;
     else if(tmpStr == "middle")
@@ -156,20 +149,48 @@ static void init_theme()
         tmpStr = config->readEntry("TitlebarPixmapActive", "");
         if(!tmpStr.isEmpty()){
             aTitlePix = new KPixmap;
-            aTitlePix->load(localBaseDir + "/kwmtheme/themepics/" + tmpStr);
+            aTitlePix->load(locate("appdata", "pics/" + tmpStr));
         }
         else
             aTitlePix = NULL;
         tmpStr = config->readEntry("TitlebarPixmapInactive", "");
         if(!tmpStr.isEmpty()){
             iTitlePix = new KPixmap;
-            iTitlePix->load(localBaseDir + "/kwmtheme/themepics/" + tmpStr);
+            iTitlePix->load(locate("appdata", "pics/" + tmpStr));
         }
         else
             iTitlePix = NULL;
     }
 }
 
+void
+KWMThemeClient::slotReset()
+{
+   if (!pixmaps_created) return;
+   pixmaps_created = false;
+
+    for(int i=0; i < 8; ++i)
+        delete framePixmaps[i];
+
+   delete menuPix;
+   delete iconifyPix;
+   delete closePix;
+   delete maxPix;
+   delete minmaxPix;
+   delete pinupPix;
+   delete pindownPix;
+   delete aTitlePix;
+   aTitlePix = 0;
+   delete iTitlePix;
+   iTitlePix = 0;
+
+   titleGradient = true;
+   pixmaps_created = false;
+   titleSunken = false;
+
+   init_theme();   
+}
+
 void MyButton::drawButtonLabel(QPainter *p)
 {
     if(pixmap()){
@@ -180,10 +201,11 @@ void MyButton::drawButtonLabel(QPainter *p)
 
 KWMThemeClient::KWMThemeClient( Workspace *ws, WId w, QWidget *parent,
                             const char *name )
-    : Client( ws, w, parent, name, WResizeNoErase )
+    : Client( ws, w, parent, name, WResizeNoErase | WNorthWestGravity)
 {
+    stickyBtn = maxBtn = 0;
     init_theme();
-
+    connect(options, SIGNAL(resetClients()), this, SLOT(slotReset())); 
     QGridLayout *layout = new QGridLayout(this);
     layout->addColSpacing(0, maxExtent);
     layout->addColSpacing(2, maxExtent);
@@ -254,7 +276,7 @@ KWMThemeClient::KWMThemeClient( Workspace *ws, WId w, QWidget *parent,
         }
         else{
             if(val != "Off")
-                warning("KWin: Unrecognized button value: %s", val.latin1());
+                qWarning("KWin: Unrecognized button value: %s", val.latin1());
         }
     }
     if(titleGradient){
@@ -262,25 +284,31 @@ KWMThemeClient::KWMThemeClient( Workspace *ws, WId w, QWidget *parent,
         iGradient = new KPixmap;
     }
     else{
-        aGradient = NULL;
-        iGradient = NULL;
+        aGradient = 0;
+        iGradient = 0;
     }
         
     setBackgroundMode(NoBackground);
 }
 
-void KWMThemeClient::drawTitle(QPainter &p)
+void KWMThemeClient::drawTitle(QPainter &dest)
 {
-    QRect r = titlebar->geometry();
+    QRect titleRect = titlebar->geometry();
+    QRect r(0, 0, titleRect.width(), titleRect.height());
+    QPixmap buffer;
+
+    if(buffer.width() == r.width())
+        return;
+
+    buffer.resize(r.size());
+    QPainter p;
+    p.begin(&buffer);
 
     if(titleSunken){
-        warning("Title is sunken");
         qDrawShadeRect(&p, r, options->colorGroup(Options::Frame, isActive()),
                        true, 1, 0);
         r.setRect(r.x()+1, r.y()+1, r.width()-2, r.height()-2);
     }
-    else
-        warning("Title is not sunken");
     
     KPixmap *fill = isActive() ? aTitlePix : iTitlePix;
     if(fill)
@@ -302,9 +330,16 @@ void KWMThemeClient::drawTitle(QPainter &p)
     }
     p.setFont(options->font(isActive()));
     p.setPen(options->color(Options::Font, isActive()));
+    // Add left & right margin
+    r.setLeft(r.left()+5);
+    r.setRight(r.right()-5);
     p.drawText(r, titleAlign, caption());
+    p.end();
+
+    dest.drawPixmap(titleRect.x(), titleRect.y(), buffer);
 }
 
+
 void KWMThemeClient::resizeEvent( QResizeEvent* e)
 {
     Client::resizeEvent( e );
@@ -325,12 +360,10 @@ void KWMThemeClient::captionChange( const QString& )
     repaint( titlebar->geometry(), false );
 }
 
-void KWMThemeClient::paintEvent( QPaintEvent* )
+void KWMThemeClient::paintEvent( QPaintEvent*e )
 {
     QPainter p;
     p.begin(this);
-    p.fillRect(rect(), options->colorGroup(Options::Frame, isActive()).
-               brush(QColorGroup::Background));
 
     // first the corners
     int w1 = framePixmaps[FrameTopLeft]->width();
@@ -364,18 +397,18 @@ void KWMThemeClient::paintEvent( QPaintEvent* )
            w4, h4);
 
     QPixmap *curPix = framePixmaps[FrameTop];
-    tileHoriz(this, curPix, w1, maxExtent-curPix->height()-1, width()-w2-w1);
-
-    
+    p.drawTiledPixmap(w1, maxExtent-curPix->height(), width()-w2-w1,
+                      curPix->height(), *curPix);
     curPix = framePixmaps[FrameBottom];
-    tileHoriz(this, curPix, w3, height()-maxExtent+1, width()-w3-w4);
-
+    p.drawTiledPixmap(w3, height()-maxExtent, width()-w3-w4,
+                      curPix->height(), *curPix);
     curPix = framePixmaps[FrameLeft];
-    tileVert(this, curPix, maxExtent-curPix->width()-1, h1, height()-h1-h3);
-    
-    curPix = framePixmaps[FrameRight];
-    tileVert(this, curPix, width()-maxExtent+1, h2, height()-h2-h4);
+    p.drawTiledPixmap(maxExtent-curPix->width(), h1, curPix->width(),
+                      height()-h1-h3, *curPix);
 
+    curPix = framePixmaps[FrameRight];
+    p.drawTiledPixmap(width()-maxExtent, h2, curPix->width(),
+                      height()-h2-h4, *curPix);
     drawTitle(p);
     p.end();
 }
@@ -416,23 +449,27 @@ void KWMThemeClient::doShape()
            framePixmaps[FrameBottomRight]->height()-h4,
            w4, h4);
 
-    const QBitmap *curPix = framePixmaps[FrameTop]->mask();
-    tileHoriz(&mask, curPix, w1, maxExtent-curPix->height()-1, width()-w2-w1);
-    
-    curPix = framePixmaps[FrameBottom]->mask();
-    tileHoriz(&mask, curPix, w3, height()-maxExtent+1, width()-w3-w4);
-
-    curPix = framePixmaps[FrameLeft]->mask();
-    tileVert(&mask, curPix, maxExtent-curPix->width()-1, h1, height()-h1-h3);
-    
-    curPix = framePixmaps[FrameRight]->mask();
-    tileVert(&mask, curPix, width()-maxExtent+1, h2, height()-h2-h4);
-
     p.begin(&mask);
+    const QBitmap *curPix = framePixmaps[FrameTop]->mask();
+    if (curPix)
+       p.drawTiledPixmap(w1, maxExtent-curPix->height(), width()-w2-w1,
+                         curPix->height(), *curPix);
+    curPix = framePixmaps[FrameBottom]->mask();
+    if (curPix)
+       p.drawTiledPixmap(w3, height()-maxExtent, width()-w3-w4,
+                      curPix->height(), *curPix);
+    curPix = framePixmaps[FrameLeft]->mask();
+    if (curPix)
+       p.drawTiledPixmap(maxExtent-curPix->width(), h1, curPix->width(),
+                      height()-h1-h3, *curPix);
+    curPix = framePixmaps[FrameRight]->mask();
+    if (curPix)
+       p.drawTiledPixmap(width()-maxExtent, h2, curPix->width(),
+                      height()-h2-h4, *curPix);
     p.setBrush(color1);
     p.setPen(color1);
-    p.fillRect(maxExtent-1, maxExtent-1, width()-2*maxExtent+2,
-               height()-2*maxExtent+2, color1);
+    p.fillRect(maxExtent, maxExtent, width()-2*maxExtent,
+               height()-2*maxExtent, color1);
     p.end();
     setMask(mask);
 }
@@ -459,12 +496,45 @@ void KWMThemeClient::mouseDoubleClickEvent( QMouseEvent * e )
 
 void KWMThemeClient::stickyChange(bool on)
 {
-    stickyBtn->setPixmap(on ? *pinupPix : *pindownPix);
+    if (stickyBtn)
+       stickyBtn->setPixmap(on ? *pinupPix : *pindownPix);
 }
 
 void KWMThemeClient::maximizeChange(bool m)
 {
-    maxBtn->setPixmap(m ? *minmaxPix : *maxPix);
+    if (maxBtn)
+       maxBtn->setPixmap(m ? *minmaxPix : *maxPix);
+}
+
+Client::MousePosition KWMThemeClient::mousePosition(const QPoint &p) const
+{
+    MousePosition m = Client::mousePosition(p);
+    // corners
+    if(p.y() < framePixmaps[FrameTop]->height() &&
+       p.x() < framePixmaps[FrameLeft]->width()){
+        m = TopLeft;
+    }
+    else if(p.y() < framePixmaps[FrameTop]->height() &&
+            p.x() > width()-framePixmaps[FrameRight]->width()){
+        m = TopRight;
+    }
+    else if(p.y() > height()-framePixmaps[FrameBottom]->height() &&
+            p.x() < framePixmaps[FrameLeft]->width()){
+        m = BottomLeft;
+    }
+    else if(p.y() > height()-framePixmaps[FrameBottom]->height() &&
+            p.x() > width()-framePixmaps[FrameRight]->width()){
+        m = BottomRight;
+    } // edges
+    else if(p.y() < framePixmaps[FrameTop]->height())
+        m = Top;
+    else if(p.y() > height()-framePixmaps[FrameBottom]->height())
+        m = Bottom;
+    else if(p.x()  < framePixmaps[FrameLeft]->width())
+        m = Left;
+    else if(p.x() > width()-framePixmaps[FrameRight]->width())
+        m = Right;
+    return(m);
 }
 
 void KWMThemeClient::init()
