@@ -8,6 +8,8 @@
 class QLabel;
 class QSpacerItem;
 
+namespace KWinInternal {
+
 // QToolButton uses a 1 pixel border :P
 class MyButton : public QToolButton
 {
@@ -18,7 +20,7 @@ protected:
     void drawButtonLabel(QPainter *p);
 };
 
-class KWMThemeClient : public Client
+class KWMThemeClient : public KWinInternal::Client
 {
     Q_OBJECT
 public:
@@ -36,39 +38,17 @@ protected:
     void captionChange( const QString& name );
     void stickyChange(bool on);
     void maximizeChange(bool m);
+    MousePosition mousePosition(const QPoint &) const;
+protected slots:
+    void slotReset();
 private:
-    inline void tileHoriz(QPaintDevice *dest, const QPixmap *src,
-                          int x, int y, int w);
-    inline void tileVert(QPaintDevice *dest, const QPixmap *src,
-                          int x, int y, int h);
+    QPixmap buffer;
     KPixmap *aGradient, *iGradient;
     MyButton *maxBtn, *stickyBtn;
     QSpacerItem *titlebar;
 };
 
-inline void KWMThemeClient::tileHoriz(QPaintDevice *dest, const QPixmap *src,
-                                      int x, int y, int w)
-{
-    int cx;
-    for(cx = x; cx < x+w; cx+=src->width()){
-        bitBlt(dest, cx, y, src, 0, 0, cx+src->width() <= x+w ? src->width() :
-               (x+w)-cx);
-    }
-}
-
-inline void KWMThemeClient::tileVert(QPaintDevice *dest, const QPixmap *src,
-                                     int x, int y, int h)
-{
-    int cy;
-    for(cy = y; cy < y+h; cy+=src->height()){
-        bitBlt(dest, x, cy, src, 0, 0, src->width(),
-               cy+src->height() <= y+h ? src->height() :
-               (y+h)-cy);
-    }
-}
-
-
-
-
+};
 
 #endif
+
