@@ -25,9 +25,30 @@
 namespace RiscOS
 {
 
+/* XPM */
+static const char * const close_xpm[] = {
+"12 12 3 1",
+" 	c None",
+".	c #000000",
+"+	c #FFFFFF",
+"  .      .  ",
+" .+.    .+. ",
+".+++.  .+++.",
+" .+++..+++. ",
+"  .++++++.  ",
+"   .++++.   ",
+"   .++++.   ",
+"  .++++++.  ",
+" .+++..+++. ",
+".+++.  .+++.",
+" .+.    .+. ",
+"  .      .  "};
+
 CloseButton::CloseButton(QWidget * parent)
-  : Button(parent, Close)
+  : Button(parent)
 {
+  setPixmap(QPixmap((const char **)close_xpm));
+  connect(this, SIGNAL(close()), parent, SLOT(closeWindow()));
 }
 
   void
@@ -40,17 +61,8 @@ CloseButton::mouseReleaseEvent(QMouseEvent * e)
 
   switch (e->button())
   {
-    case RightButton:
-      emit(closeClient());
-      break;
-
-    case MidButton:
-      emit(closeClient());
-      break;
-
-    case LeftButton:
     default:
-      emit(closeClient());
+      emit(close());
       break;
   }
 }
@@ -58,3 +70,4 @@ CloseButton::mouseReleaseEvent(QMouseEvent * e)
 } // End namespace;
 
 // vim:ts=2:sw=2:tw=78
+#include "CloseButton.moc"
