@@ -25,9 +25,30 @@
 namespace RiscOS
 {
 
+/* XPM */
+static const char * const iconify_xpm[] = {
+"12 12 3 1",
+" 	c None",
+".	c #000000",
+"+	c #FFFFFF",
+"            ",
+"            ",
+"            ",
+"            ",
+" .......... ",
+".++++++++++.",
+".++++++++++.",
+" .......... ",
+"            ",
+"            ",
+"            ",
+"            "};
+
 IconifyButton::IconifyButton(QWidget * parent)
-  : Button(parent, Iconify)
+  : Button(parent)
 {
+  setPixmap(QPixmap((const char **)iconify_xpm));
+  connect(this, SIGNAL(iconify()), parent, SLOT(iconify()));
 }
 
   void
@@ -40,23 +61,13 @@ IconifyButton::mouseReleaseEvent(QMouseEvent * e)
 
   switch (e->button())
   {
-    case RightButton:
-      emit(iconifyClient());
-      break;
-
-    case MidButton:
-      emit(iconifyClient());
-      break;
-
-    case LeftButton:
     default:
-      emit(iconifyClient());
+      emit(iconify());
       break;
   }
-
-
 }
 
 } // End namespace;
 
 // vim:ts=2:sw=2:tw=78
+#include "IconifyButton.moc"
