@@ -25,9 +25,30 @@
 namespace RiscOS
 {
 
+/* XPM */
+static const char * const lower_xpm[] = {
+"12 12 3 1",
+" 	c None",
+".	c #000000",
+"+	c #FFFFFF",
+"            ",
+" .....      ",
+".+++++.     ",
+".+++++.     ",
+".+++++..... ",
+".++++.+++++.",
+".++++.+++++.",
+" .....+++++.",
+"     .+++++.",
+"     .+++++.",
+"      ..... ",
+"            "};
+
 LowerButton::LowerButton(QWidget * parent)
-  : Button(parent, Lower)
+  : Button(parent)
 {
+  setPixmap(QPixmap((const char **)lower_xpm));
+  connect(this, SIGNAL(lower()), parent, SLOT(lower()));
 }
 
   void
@@ -41,12 +62,12 @@ LowerButton::mouseReleaseEvent(QMouseEvent * e)
   switch (e->button())
   {
     default:
-      emit(lowerClient());
+      emit(lower());
       break;
   }
 
 }
-
 } // End namespace;
 
 // vim:ts=2:sw=2:tw=78
+#include "LowerButton.moc"
