@@ -40,13 +40,13 @@ class StickyButton;
 class HelpButton;
 class Button;
 
-class Manager : public Client
+class Manager : public KWinInternal::Client
 {
   Q_OBJECT
 
   public:
 
-    Manager(Workspace *, WId, QWidget * parent = 0, const char * name = 0);
+    Manager(KWinInternal::Workspace *, WId, QWidget * parent = 0, const char * name = 0);
     ~Manager();
 
   signals:
@@ -65,7 +65,7 @@ class Manager : public Client
 
   protected:
 
-    Client::MousePosition mousePosition(const QPoint &) const;
+    KWinInternal::Client::MousePosition mousePosition(const QPoint &) const;
     void paletteChange(const QPalette &);
     void activeChange(bool);
     void maximizeChange(bool);
@@ -74,6 +74,9 @@ class Manager : public Client
     void resizeEvent(QResizeEvent *);
     void mouseDoubleClickEvent(QMouseEvent *);
     void animateIconifyOrDeiconify(bool);
+    void animate(bool, int);
+    void updateButtonVisibility();
+    void updateTitleBuffer();
 
   protected slots:
 
@@ -92,8 +95,21 @@ class Manager : public Client
     QSpacerItem     * titleSpacer_;
 
     QDict<Button>   buttonDict_;
+
+    QPixmap         titleBuf_;
 };
 
+class ToolManager : public Manager
+{
+  Q_OBJECT
+
+  public:
+
+    ToolManager(KWinInternal::Workspace *, WId, QWidget * parent = 0, const char * name = 0);
+    ~ToolManager();
+};
+
+
 } // End namespace
 
 #endif
