@@ -2,30 +2,47 @@
 #define __SYSTEMCLIENT_H
 
 #include <qbutton.h>
+#include <qtoolbutton.h>
+
 #include <qbitmap.h>
 #include <kpixmap.h>
 #include "../../client.h"
+
+
 class QLabel;
 class QSpacerItem;
 
+namespace KWinInternal {
 
-// get rid of autohide :P
-class SystemButton : public QButton
+class SystemButton : public QToolButton
 {
+    Q_OBJECT
 public:
     SystemButton(Client *parent=0, const char *name=0,
                  const unsigned char *bitmap=NULL);
     void setBitmap(const unsigned char *bitmap);
     void reset();
     QSize sizeHint() const;
+signals:
+    void clicked( int );
 protected:
     virtual void drawButton(QPainter *p);
     void drawButtonLabel(QPainter *){;}
     QBitmap deco;
     Client *client;
+
+    void mousePressEvent( QMouseEvent* e );
+    void mouseReleaseEvent( QMouseEvent* e );
+
+private slots:
+    void handleClicked();
+
+private:
+    int last_button;
+    
 };
 
-class SystemClient : public Client
+class SystemClient : public KWinInternal::Client
 {
     Q_OBJECT
 public:
@@ -47,6 +64,9 @@ protected:
     void activeChange(bool);
 protected slots:
     void slotReset();
+private slots:
+    void maxButtonClicked( int );
+
 private:
     SystemButton* button[5];
     QSpacerItem* titlebar;
@@ -54,8 +74,6 @@ private:
     QString oldTitle;
 };
 
-
-
-
+};
 
 #endif
