@@ -9,6 +9,7 @@ Copyright (C) 1999, 2000    Daniel M. Duley <mosfet@kde.org>
 #include <kdesktopfile.h>
 #include <ksimpleconfig.h>
 #include <klocale.h>
+#include <klibloader.h>
 
 // X11/Qt conflict
 #undef Unsorted
@@ -19,6 +20,8 @@ Copyright (C) 1999, 2000    Daniel M. Duley <mosfet@kde.org>
 #include "plugins.h"
 #include "kdedefault.h"
 
+using namespace KWinInternal;
+
 PluginMenu::PluginMenu(PluginMgr *manager, QWidget *parent, const char *name)
     : QPopupMenu(parent, name)
 {
@@ -93,10 +96,17 @@ void PluginMenu::parseDesktop(QFileInfo *fi)
 
 void PluginMenu::slotActivated(int id)
 {
-    if(id == 0)
-        mgr->loadPlugin(QString::null);
-    else
-        mgr->loadPlugin(fileList[id-1]);
+    QString newPlugin;
+    if (id > 0)
+        newPlugin = fileList[id-1];
+
+    KConfig *config = KGlobal::config();
+    config->setGroup("Style");
+    config->writeEntry("PluginLib", newPlugin);
+    config->sync();
+    // We can't do this directly because we might destruct a client
+    // underneath our own feet while doing so.
+    QTimer::singleShot(0, mgr, SLOT(updatePlugin()));
 }
 
 PluginMgr::PluginMgr()
@@ -104,14 +114,9 @@ PluginMgr::PluginMgr()
 {
     alloc_ptr = NULL;
     handle = 0;
+    pluginStr = "standard";
 
-    KConfig *config = KGlobal::config();
-    config->setGroup("Style");
-    pluginStr = config->readEntry("PluginLib", "default");
-    if(pluginStr.isEmpty() || pluginStr == "standard")
-        pluginStr = "standard";
-    else
-        loadPlugin(pluginStr);
+    updatePlugin();
 }
 
 PluginMgr::~PluginMgr()
@@ -120,6 +125,20 @@ PluginMgr::~PluginMgr()
         lt_dlclose(handle);
 }
 
+bool
+PluginMgr::updatePlugin()
+{
+    KConfig *config = KGlobal::config();
+    config->reparseConfiguration();
+    config->setGroup("Style");
+    QString newPlugin = config->readEntry("PluginLib", "standard" );
+    if (newPlugin != pluginStr) {
+       loadPlugin(newPlugin);
+       return true;
+    }
+    return false;
+}
+
 Client* PluginMgr::allocateClient(Workspace *ws, WId w, bool tool)
 {
     if(alloc_ptr)
@@ -131,55 +150,36 @@ Client* PluginMgr::allocateClient(Workspace *ws, WId w, bool tool)
 void PluginMgr::loadPlugin(QString nameStr)
 {
     static bool dlregistered = false;
-    static lt_dlhandle oldHandle = 0;
+    lt_dlhandle oldHandle = handle;
+    pluginStr = "standard";
+    handle = 0;
+    alloc_ptr = 0;
 
-    pluginStr = nameStr;
+    if ( !nameStr.isEmpty() && nameStr != "standard" ) {
+	if(!dlregistered){
+	    dlregistered = true;
+	    lt_dlinit();
+	}
+	QString path = KLibLoader::findLibrary(nameStr.latin1());
 
-    oldHandle = handle;
-
-    // Rikkus: temporary change in semantics.
-
-    if (!nameStr)
-      nameStr = "default";
-
-    if(!dlregistered){
-        dlregistered = true;
-        lt_dlinit();
+	if( !path.isEmpty() ) {
+	    if ( (handle = lt_dlopen(path.latin1() ) ) ) {
+		lt_ptr_t alloc_func = lt_dlsym(handle, "allocate");
+		if(alloc_func) {
+		    alloc_ptr = (Client* (*)(Workspace *ws, WId w, int tool))alloc_func;
+		} else{
+		    qWarning("KWin: %s is not a KWin plugin.", path.latin1());
+		    lt_dlclose(handle);
+		    handle = 0;
+		}
+	    } else {
+		qWarning("KWin: cannot load client plugin %s.", path.latin1());
+	    }
+	}
     }
-    nameStr += ".la";
-    nameStr = KGlobal::dirs()->findResource("lib", nameStr);
+    if ( alloc_ptr )
+	pluginStr = nameStr;
 
-    if(!nameStr){
-        qWarning("KWin: cannot find client plugin.");
-        handle = 0;
-        alloc_ptr = NULL;
-        pluginStr = "standard";
-    }
-    else{
-        handle = lt_dlopen(nameStr.latin1());
-        if(!handle){
-            qWarning("KWin: cannot load client plugin %s.", nameStr.latin1());
-            handle = 0;
-            alloc_ptr = NULL;
-            pluginStr = "standard";
-        }
-        else{
-            lt_ptr_t alloc_func = lt_dlsym(handle, "allocate");
-            if(alloc_func)
-                alloc_ptr = (Client* (*)(Workspace *ws, WId w, int tool))alloc_func;
-            else{
-                qWarning("KWin: %s is not a KWin plugin.", nameStr.latin1());
-                lt_dlclose(handle);
-                handle = 0;
-                alloc_ptr = NULL;
-                pluginStr = "standard";
-            }
-        }
-    }
-    KConfig *config = KGlobal::config();
-    config->setGroup("Style");
-    config->writeEntry("PluginLib", pluginStr);
-    config->sync();
     emit resetAllClients();
     if(oldHandle)
         lt_dlclose(oldHandle);
