@@ -1,5 +1,5 @@
 /*
-  $Id: highlight.h,v 1.42 2000/07/23 18:15:39 gebauer Exp $
+  $Id: highlight.h,v 1.51 2001/01/13 00:32:42 sdmanson Exp $
 
    Copyright (C) 1998, 1999 Jochen Wilhelmy
                             digisnap@cs.tu-berlin.de
@@ -27,6 +27,11 @@
 #include <qdialog.h>
 
 #include <kcolorbtn.h>
+#include <qstrvec.h>
+#include <qdict.h>
+
+
+class SyntaxDocument;
 
 class QCheckBox;
 class QComboBox;
@@ -35,6 +40,7 @@ class QLineEdit;
 class TextLine;
 class Attribute;
 
+
 bool isInWord(QChar); //true for '_','0'-'9','A'-'Z','a'-'z'
 
 class HlItem {
@@ -66,6 +72,8 @@ class HlCharDetect : public HlItem {
 class Hl2CharDetect : public HlItem {
   public:
     Hl2CharDetect(int attribute, int context,  QChar ch1, QChar ch2);
+   	Hl2CharDetect(int attribute, int context, const QChar *ch);
+
     virtual const QChar *checkHgl(const QChar *);
   protected:
     QChar sChar1;
@@ -103,13 +111,33 @@ class HlKeyword : public HlItemWw {
   public:
     HlKeyword(int attribute, int context);
     virtual ~HlKeyword();
-    void addWord(const QString &);
-    void addList(const char **);
+    virtual void addWord(const QString &);
+		virtual void addList(const QStringList &);
+// needed for kdevelop (if they decide to use this code)
+    virtual void addList(const char **);
     virtual const QChar *checkHgl(const QChar *);
+		QStringList getList() { return words;};
+		QDict<char> getDict() { return Dict;};
+		
   protected:
     QStringList words;
+		QDict<char> Dict;
+};
+class HlCaseInsensitiveKeyword : public HlKeyword {
+  public:
+    HlCaseInsensitiveKeyword(int attribute, int context);
+    virtual ~HlCaseInsensitiveKeyword();
+    virtual const char *checkHgl(const char *);
+		virtual const QChar *checkHgl(const QChar *);
+    void addList(const QStringList &);
+    void addList(const char **);
 };
 
+class HlPHex : public HlItemWw {
+  public:
+    HlPHex(int attribute,int context);
+    virtual const QChar *checkHgl(const QChar *);
+};
 class HlInt : public HlItemWw {
   public:
     HlInt(int attribute, int context);
@@ -354,7 +382,7 @@ class HlManager;
 class KConfig;
 
 class Highlight {
-    friend HlManager;
+    friend class HlManager;
   public:
     Highlight(const char * name);
     virtual ~Highlight();
@@ -379,7 +407,6 @@ class Highlight {
     virtual void createItemData(ItemDataList &);
     virtual void init();
     virtual void done();
-
     const char * iName;
     QString iWildcards;
     QString iMimetypes;
@@ -411,7 +438,6 @@ class GenHighlight : public Highlight {
 };
 
 
-
 class CHighlight : public GenHighlight {
   public:
     CHighlight(const char * name);
@@ -424,6 +450,7 @@ class CHighlight : public GenHighlight {
     virtual void setKeywords(HlKeyword *keyword, HlKeyword *dataType);
 };
 
+
 class CppHighlight : public CHighlight {
   public:
     CppHighlight(const char * name);
@@ -433,6 +460,18 @@ class CppHighlight : public CHighlight {
   protected:
     virtual void setKeywords(HlKeyword *keyword, HlKeyword *dataType);
 };
+class PascalHighlight : public CHighlight {
+  public:
+    PascalHighlight(const char *name);
+    virtual ~PascalHighlight();
+    virtual QString getCommentStart() { return QString("//"); };
+    virtual QString getCommentEnd() { return QString(""); };
+  protected:
+    virtual void createItemData(ItemDataList &);
+    virtual void makeContextList();
+    virtual void setKeywords(HlKeyword *keyword, HlKeyword *dataType);
+};
+
 
 class ObjcHighlight : public CHighlight {
   public:
@@ -521,7 +560,7 @@ class PerlHighlight : public Highlight {
   public:
     PerlHighlight(const char * name);
 
-    virtual int doHighlight(int ctxNum, TextLine *);
+    virtual int doHighlight(int ctxNum, TextLine*);
     virtual QString getCommentStart() { return QString("#"); };
   protected:
     virtual void createItemData(ItemDataList &);
@@ -579,11 +618,13 @@ class HlManager : public QObject {
     const char * hlName(int n);
     void getHlDataList(HlDataList &);
     void setHlDataList(HlDataList &);
+
+    SyntaxDocument *syntax;
+
   signals:
     void changed();
   protected:
     QList<Highlight> hlList;
-
     static HlManager *s_pSelf;
 };
 
