@@ -64,7 +64,7 @@ XKBExtension::~XKBExtension()
     if( data )
 	delete data;
 }    
-void XKBExtension::setLayout(QString rule, QString model, QString layout, const QString &encoding)
+void XKBExtension::setLayout(QString rule, QString model, QString layout, const QString &encoding, unsigned int group)
 {
   if (rule.isEmpty() || model.isEmpty() || layout.isEmpty())
     return;
@@ -79,7 +79,12 @@ void XKBExtension::setLayout(QString rule, QString model, QString layout, const
   *p << "-model" << model;
   *p << "-layout" << layout;
   
-  p->start(KProcess::DontCare);
+  p->start(KProcess::Block);
+
+  XkbLockGroup( dpy, XkbUseCoreKbd, group );
+//   XkbStateRec rec;
+//   XkbGetState( dpy, XkbUseCoreKbd, &rec );
+//   qDebug( "keyboard state is: group: %d, lock %d", (int)rec.group, (int)rec.locked_group);
   
   const char * enc = encoding.latin1();
   XChangeProperty( dpy, qt_xrootwin(), qt_input_encoding, XA_STRING, 8, 
