@@ -7,11 +7,12 @@
 
 
 class XKBExtension;
-
+class KeyRules;
 
 #include <kuniqueapp.h>
 #include <ksystemtray.h>
 
+class KGlobalAccel;
 
 class TrayWindow : public KSystemTray
 {
@@ -35,7 +36,7 @@ signals:
 protected:
 
   void mouseReleaseEvent(QMouseEvent *);
-  
+
 };
 
 
@@ -55,7 +56,7 @@ protected slots:
 
   void menuActivated(int id);
   void toggled();
- 
+
 
 protected:
 
@@ -65,11 +66,14 @@ protected:
 private:
 
   QString _rule, _model, _layout, _encoding;
-  QStringList _list;
+    unsigned int _group;
+    QStringList _list;
   QStringList _encList;
   XKBExtension *extension;
-
+    KeyRules *rules;
+    
   TrayWindow *tray;
+  KGlobalAccel *keys;
 
 };
 
