@@ -1,23 +1,12 @@
-/*
-   This file is part of the KDE libraries
-   Copyright (c) 1999 Kurt Granroth <granroth@kde.org>
-
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
-*/
-#include <kapp.h>
+/* This file is part of the KDE kdebase package
+ *
+ * Copyright (C) 1999-2000 Kurt Granroth <granroth@kde.org>
+ *
+ * This file is distributed under the BSD license. See the file "BSD"
+ * in the subdirectory "licenses" of the package for the full license
+ * text which has to be applied for this file.
+ */
+#include <kuniqueapp.h>
 #include <qstring.h>
 #include <qcstring.h>
 #include <dcopclient.h>
@@ -25,6 +14,7 @@
 #include <qmap.h>
 #include <qdatetime.h>
 
+#include <kdebug.h>
 /**
 g++ -o testxmlrpc testxmlrpc.cpp -I$KDEDIR/include -I$QTDIR/include -L$KDEDIR/lib -L$QTDIR/lib -lkdecore -lqt
 **/
@@ -186,17 +176,13 @@ public:
 
 int main(int argc, char **argv)
 {
-    KApplication app(argc, argv, "testapp", false);
-
-    // standard DCOP stuff
-    DCOPClient *client = app.dcopClient();
-    client->registerAs("xmlrpcDCOP");
+    KUniqueApplication app(argc, argv, "testxmlrpc", false);
 
     // start up my servers
     DCOPObject *address_server = new AddressServer;
     DCOPObject *type_server    = new TypeServer;
 
     int ret = app.exec();
-    client->detach();
+    kapp->dcopClient()->detach();
     return ret;
 }
