@@ -1,8 +1,6 @@
 /*  This file is part of the KDE project
     Copyright (C) 2000  David Faure <faure@kde.org>
 
-#include "konq_operations.h"
-
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation; either version 2 of the License, or
@@ -42,11 +40,14 @@
 #include <kdesktopfile.h>
 #include <kurldrag.h>
 #include <kglobalsettings.h>
+#include <kimageio.h>
 #include <kio/job.h>
 #include <kio/paste.h>
 #include <klocale.h>
 #include <konq_drag.h>
 #include <konq_fileitem.h>
+#include <konq_iconviewwidget.h>
+#include <kprotocolinfo.h>
 #include <kprocess.h>
 #include <kstringhandler.h>
 #include <kstddirs.h>
@@ -56,10 +57,15 @@
 #include <X11/Xlib.h>
 
 KonqOperations::KonqOperations( QWidget *parent )
-: QObject( parent, "KonqOperations" )
+    : QObject( parent, "KonqOperations" ), m_info(0L)
 {
 }
 
+KonqOperations::~KonqOperations()
+{
+    delete m_info;
+}
+
 void KonqOperations::editMimeType( const QString & mimeType )
 {
   QString keditfiletype = QString::fromLatin1("keditfiletype");
@@ -147,12 +153,43 @@ void KonqOperations::doPaste( QWidget * parent, const KURL & destURL )
     }
 }
 
+void KonqOperations::copy( QWidget * parent, int method, const KURL::List & selectedURLs, const KURL& destUrl )
+{
+  kdDebug(1203) << "KonqOperations::copy() " << parent->className() << endl;
+  if ((method!=COPY) && (method!=MOVE) && (method!=LINK))
+  {
+    kdWarning(1203) << "Illegal copy method !" << endl;
+    return;
+  }
+  if ( selectedURLs.isEmpty() )
+  {
+    kdWarning(1203) << "Empty URL list !" << endl;
+    return;
+  }
+
+  KonqOperations * op = new KonqOperations( parent );
+  KIO::Job* job(0);
+  if (method==LINK)
+     job= KIO::link( selectedURLs, destUrl);
+  else if (method==MOVE)
+     job= KIO::move( selectedURLs, destUrl);
+  else
+     job= KIO::copy( selectedURLs, destUrl);
+
+  op->setOperation( job, method,selectedURLs ,destUrl );
+
+  if (method==COPY)
+     (void) new KonqCommandRecorder( KonqCommand::COPY, selectedURLs, destUrl, job );
+  else
+     (void) new KonqCommandRecorder( method==MOVE?KonqCommand::MOVE:KonqCommand::LINK, selectedURLs, destUrl, job );
+};
+
 void KonqOperations::_del( int method, const KURL::List & selectedURLs, int confirmation )
 {
   m_method = method;
   if ( confirmation == SKIP_CONFIRMATION || askDeleteConfirmation( selectedURLs, confirmation ) )
   {
-    m_srcURLs = selectedURLs;
+    //m_srcURLs = selectedURLs;
     KIO::Job *job;
     switch( method )
     {
@@ -199,30 +236,28 @@ bool KonqOperations::askDeleteConfirmation( const KURL::List & selectedURLs, int
 
       if ( prettyList.count() == 1 )
       {
-        //TODO "Do you really want to delete <filename> from <directory>"
-        // so that it's possible to use KIO::decodeName on the filename
-        QString url = KStringHandler::csqueeze(prettyList.first());
-        QString msg = (m_method == DEL ? i18n( "Do you really want to delete '%1'?" ).arg( url ) :
-                       m_method == SHRED ? i18n( "Do you really want to shred '%1'?" ).arg( url ) :
-                       i18n( "Do you really want to move '%1' to the trash?" ).arg( url ));
+        QString filename = KStringHandler::csqueeze(KIO::decodeFileName(selectedURLs.first().fileName()));
+        QString directory = KStringHandler::csqueeze(selectedURLs.first().directory());
+        QString msg = (m_method == DEL ? i18n( "Do you really want to delete <b>%1</b> from '%2'?" ).arg( filename ).arg( directory ) :
+                       m_method == SHRED ? i18n( "Do you really want to shred <b>%1</b>?" ).arg( filename ) :
+                       i18n( "Do you really want to move <b>%1</b> to the trash?" ).arg( filename ));
         return ( KMessageBox::questionYesNo( 0, msg ) == KMessageBox::Yes );
       }
       else
       {
-        QString msg = (m_method == DEL ? i18n( "Do you really want to delete the files?" ) :
-                       m_method == SHRED ? i18n( "Do you really want to shred the files?" ) :
-                       i18n( "Do you really want to move the files to the trashcan?" ));
+        QString msg = (m_method == DEL ? i18n( "Do you really want to delete those %1 items?" ) :
+                       m_method == SHRED ? i18n( "Do you really want to shred those %1 items?" ) :
+                       i18n( "Do you really want to move those %1 items to the trashcan?" ));
 
-        return ( KMessageBox::questionYesNoList( 0, msg, prettyList ) == KMessageBox::Yes );
+        return ( KMessageBox::questionYesNoList( 0, msg.arg(prettyList.count()), prettyList ) == KMessageBox::Yes );
       }
     }
     return true;
 }
 
 //static
-void KonqOperations::doDrop( const KonqFileItem * destItem, QDropEvent * ev, QWidget * parent )
+void KonqOperations::doDrop( const KonqFileItem * destItem, const KURL & dest, QDropEvent * ev, QWidget * parent )
 {
-    KURL dest = destItem->url();
     kdDebug(1203) << "dest : " << dest.url() << endl;
     KURL::List lst;
     if ( KURLDrag::decode( ev, lst ) ) // Are they urls ?
@@ -230,6 +265,7 @@ void KonqOperations::doDrop( const KonqFileItem * destItem, QDropEvent * ev, QWi
         if( lst.count() == 0 )
         {
             kdWarning(1203) << "Oooops, no data ...." << endl;
+            ev->accept(false);
             return;
         }
         // Check if we dropped something on itself
@@ -243,101 +279,45 @@ void KonqOperations::doDrop( const KonqFileItem * destItem, QDropEvent * ev, QWi
                 // Note: ev->source() can be 0L! (in case of kdesktop) (Simon)
                 if ( !ev->source() || ev->source() != parent && ev->source()->parent() != parent )
                     KMessageBox::sorry( parent, i18n("You can't drop a directory on itself") );
+                kdDebug(1203) << "Dropped on itself" << endl;
+                ev->accept(false);
                 return; // do nothing instead of displaying kfm's annoying error box
             }
         }
 
-        // Check what the destination is
-        if ( S_ISDIR(destItem->mode()) )
+        // Check the state of the modifiers key at the time of the drop
+        Window root;
+        Window child;
+        int root_x, root_y, win_x, win_y;
+        uint keybstate;
+        XQueryPointer( qt_xdisplay(), qt_xrootwin(), &root, &child,
+                       &root_x, &root_y, &win_x, &win_y, &keybstate );
+
+        QDropEvent::Action action = ev->action();
+        // Check for the drop of a bookmark -> we want a Link action
+        if ( ev->provides("application/x-xbel") )
         {
-            // Check the state of the modifiers key at the time of the drop
-            Window root;
-            Window child;
-            int root_x, root_y, win_x, win_y;
-            uint keybstate;
-            XQueryPointer( qt_xdisplay(), qt_xrootwin(), &root, &child,
-                           &root_x, &root_y, &win_x, &win_y, &keybstate );
-
-            if ( dest.path( 1 ) == KGlobalSettings::trashPath() )
-                ev->setAction( QDropEvent::Move );
-            else if ( ((keybstate & ControlMask) == 0) && ((keybstate & ShiftMask) == 0) )
-            {
-                // Nor control nor shift are pressed => show popup menu
-                QPopupMenu popup;
-                popup.insertItem( i18n( "&Copy Here" ), 1 );
-                popup.insertItem( i18n( "&Move Here" ), 2 );
-                popup.insertItem( i18n( "&Link Here" ), 3 );
-
-                int result = popup.exec( QPoint( win_x, win_y ) );
-                switch (result) {
-                    case 1 : ev->setAction( QDropEvent::Copy ); break;
-                    case 2 : ev->setAction( QDropEvent::Move ); break;
-                    case 3 : ev->setAction( QDropEvent::Link ); break;
-                    default : return;
-                }
-            }
-
-            KonqOperations * op = new KonqOperations( parent );
-            KIO::Job * job = 0;
-            switch ( ev->action() ) {
-                case QDropEvent::Move :
-                  job = KIO::move( lst, dest );
-                  op->setOperation( job, MOVE, lst, dest );
-                  (void) new KonqCommandRecorder( KonqCommand::MOVE, lst, dest, job );
-                  break;
-                case QDropEvent::Copy :
-                  job = KIO::copy( lst, dest );
-                  op->setOperation( job, COPY, lst, dest );
-                  (void) new KonqCommandRecorder( KonqCommand::COPY, lst, dest, job );
-                  break;
-                case QDropEvent::Link :
-                  job = KIO::link( lst, dest );
-                  op->setOperation( 0L, LINK, lst, dest );
-                  (void) new KonqCommandRecorder( KonqCommand::LINK, lst, dest, job );
-                  break;
-                default : kdError(1203) << "Unknown action " << (int)ev->action() << endl; delete op; return;
-            }
-        } else
-        {
-            // (If this fails, there is a bug in KonqFileItem::acceptsDrops)
-            assert( dest.isLocalFile() );
-            if ( destItem->mimetype() == "application/x-desktop")
-            {
-                // Local .desktop file. What type ?
-                KDesktopFile desktopFile( dest.path() );
-                if ( desktopFile.hasApplicationType() )
-                {
-                    QString error;
-                    QStringList stringList;
-                    KURL::List::Iterator it = lst.begin();
-                    for ( ; it != lst.end() ; it++ )
-                    {
-                        stringList.append((*it).url());
-                    }
-                    if ( KApplication::startServiceByDesktopPath( dest.path(), stringList, &error ) > 0 )
-                        KMessageBox::error( 0L, error );
-                }
-                // else, well: mimetype, link, .directory, device. Can't really drop anything on those.
-            } else
-            {
-                // Should be a local executable
-                // (If this fails, there is a bug in KonqFileItem::acceptsDrops)
-                kdDebug() << "KonqOperations::doDrop " << dest.path() << "should be an executable" << endl;
-                ASSERT ( access( QFile::encodeName(dest.path()), X_OK ) == 0 );
-                // Launch executable for each of the files
-                KURL::List::Iterator it = lst.begin();
-                for ( ; it != lst.end() ; it++ )
-                {
-                    KProcess proc;
-                    proc << dest.path() << (*it).path(); // assume local files
-                    kdDebug(1203) << "starting " << dest.path() << " " << (*it).path() << endl;
-                    proc.start( KProcess::DontCare );
-                }
-            }
+            keybstate |= ControlMask | ShiftMask;
+            action = QDropEvent::Link;
+            kdDebug(1203) << "KonqOperations::doDrop Bookmark -> emulating Link" << endl;
         }
 
-        ev->acceptAction(TRUE);
-        ev->accept();
+        KonqOperations * op = new KonqOperations(parent);
+        op->setDropInfo( new DropInfo( keybstate, lst, win_x, win_y, action ) );
+
+        // Ok, now we need destItem.
+        if ( destItem )
+        {
+            op->asyncDrop( destItem ); // we have it already
+        }
+        else
+        {
+            // we need to stat to get it.
+            op->_statURL( dest, op, SLOT( asyncDrop( const KFileItem * ) ) );
+        }
+        // In both cases asyncDrop will delete op when done
+
+        ev->acceptAction();
     }
     else
     {
@@ -348,7 +328,7 @@ void KonqOperations::doDrop( const KonqFileItem * destItem, QDropEvent * ev, QWi
                 formats.append( ev->format( i ) );
         if ( formats.count() >= 1 )
         {
-            kdDebug(1203) << "Pasting to " << dest.url() << endl;
+            //kdDebug(1203) << "Pasting to " << dest.url() << endl;
 
             QByteArray data;
 
@@ -363,13 +343,162 @@ void KonqOperations::doDrop( const KonqFileItem * destItem, QDropEvent * ev, QWi
 
             KIO::pasteData( dest, data );
         }
+        ev->acceptAction();
     }
 }
 
-void KonqOperations::setOperation( KIO::Job * job, int method, const KURL::List & src, const KURL & dest )
+void KonqOperations::asyncDrop( const KFileItem * destItem )
+{
+    assert(m_info); // setDropInfo should have been called before asyncDrop
+    KURL dest = destItem->url();
+    KURL::List lst = m_info->lst;
+    kdDebug(1203) << "KonqOperations::asyncDrop destItem->mode=" << destItem->mode() << endl;
+    // Check what the destination is
+    if ( S_ISDIR(destItem->mode()) )
+    {
+        QDropEvent::Action action = m_info->action;
+        if ( dest.path( 1 ) == KGlobalSettings::trashPath() )
+        {
+            if ( askDeleteConfirmation( lst, DEFAULT_CONFIRMATION ) )
+                action = QDropEvent::Move;
+            else
+            {
+                delete this;
+                return;
+            }
+        }
+        else if ( ((m_info->keybstate & ControlMask) == 0) && ((m_info->keybstate & ShiftMask) == 0) )
+        {
+            KonqIconViewWidget *iconView = dynamic_cast<KonqIconViewWidget*>(parent());
+            bool bSetWallpaper = false;
+            if (iconView && iconView->isDesktop() &&
+                (lst.count() == 1) &&
+                (!KImageIO::type(lst.first().path()).isEmpty()))
+            {
+                bSetWallpaper = true;
+            }
+
+            // Check what the source can do
+            QString protocol = lst.first().protocol(); // we'll assume it's the same for all URLs (hack)
+            bool sReading = KProtocolInfo::supportsReading( protocol );
+            bool sDeleting = KProtocolInfo::supportsDeleting( protocol );
+            bool sMoving = KProtocolInfo::supportsMoving( protocol );
+            // Check what the destination can do
+            protocol = dest.protocol();
+            bool dWriting = KProtocolInfo::supportsWriting( protocol );
+            if ( !dWriting )
+            {
+                delete this;
+                return;
+            }
+
+            // Nor control nor shift are pressed => show popup menu
+            QPopupMenu popup;
+            if ( sReading )
+              popup.insertItem( i18n( "&Copy Here" ), 1 );
+            if ( (sMoving || (sReading && sDeleting)) )
+              popup.insertItem( i18n( "&Move Here" ), 2 );
+            popup.insertItem( i18n( "&Link Here" ), 3 );
+            if (bSetWallpaper)
+                popup.insertItem( i18n( "Set as &Wallpaper"), 4 );
+
+            int result = popup.exec( m_info->mousePos );
+            switch (result) {
+                case 1 : action = QDropEvent::Copy; break;
+                case 2 : action = QDropEvent::Move; break;
+                case 3 : action = QDropEvent::Link; break;
+                case 4 :
+                {
+                    kdDebug(1203) << "setWallpaper iconView=" << iconView << " url=" << lst.first().url() << endl;
+                    if (iconView) iconView->setWallpaper(lst.first());
+                    delete this;
+                    return;
+                }
+                default : delete this; return;
+            }
+        }
+
+        KIO::Job * job = 0;
+        switch ( action ) {
+            case QDropEvent::Move :
+                job = KIO::move( lst, dest );
+                setOperation( job, MOVE, lst, dest );
+                (void) new KonqCommandRecorder( KonqCommand::MOVE, lst, dest, job );
+                return; // we still have stuff to do -> don't delete ourselves
+            case QDropEvent::Copy :
+                job = KIO::copy( lst, dest );
+                setOperation( job, COPY, lst, dest );
+                (void) new KonqCommandRecorder( KonqCommand::COPY, lst, dest, job );
+                return;
+            case QDropEvent::Link :
+                kdDebug(1203) << "KonqOperations::asyncDrop lst.count=" << lst.count() << endl;
+                job = KIO::link( lst, dest );
+                setOperation( job, LINK, lst, dest );
+                (void) new KonqCommandRecorder( KonqCommand::LINK, lst, dest, job );
+                return;
+            default : kdError(1203) << "Unknown action " << (int)action << endl;
+        }
+    } else
+    {
+        // (If this fails, there is a bug in KonqFileItem::acceptsDrops)
+        assert( dest.isLocalFile() );
+        if ( destItem->mimetype() == "application/x-desktop")
+        {
+            // Local .desktop file. What type ?
+            KDesktopFile desktopFile( dest.path() );
+            if ( desktopFile.hasApplicationType() )
+            {
+                QString error;
+                QStringList stringList;
+                KURL::List::Iterator it = lst.begin();
+                for ( ; it != lst.end() ; it++ )
+                {
+                    stringList.append((*it).url());
+                }
+                if ( KApplication::startServiceByDesktopPath( dest.path(), stringList, &error ) > 0 )
+                    KMessageBox::error( 0L, error );
+            }
+            // else, well: mimetype, link, .directory, device. Can't really drop anything on those.
+        } else
+        {
+            // Should be a local executable
+            // (If this fails, there is a bug in KonqFileItem::acceptsDrops)
+            kdDebug(1203) << "KonqOperations::doDrop " << dest.path() << "should be an executable" << endl;
+            ASSERT ( access( QFile::encodeName(dest.path()), X_OK ) == 0 );
+            KProcess proc;
+            proc << dest.path() ;
+            // Launch executable for each of the files
+            KURL::List::Iterator it = lst.begin();
+            for ( ; it != lst.end() ; it++ )
+                proc << (*it).path(); // assume local files
+            kdDebug(1203) << "starting " << dest.path() << " with " << lst.count() << " arguments" << endl;
+            proc.start( KProcess::DontCare );
+        }
+    }
+    delete this;
+}
+
+void KonqOperations::rename( QWidget * parent, const KURL & oldurl, const QString & name )
+{
+    QString newPath = oldurl.directory(false,true) + name;
+    kdDebug(1203) << "KonqOperations::rename newPath=" << newPath << endl;
+    KURL newurl(oldurl);
+    newurl.setPath(newPath);
+    if ( oldurl != newurl )
+    {
+        KURL::List lst;
+        lst.append(oldurl);
+        KIO::Job * job = KIO::moveAs( oldurl, newurl );
+        KonqOperations * op = new KonqOperations( parent );
+        op->setOperation( job, MOVE, lst, newurl );
+        (void) new KonqCommandRecorder( KonqCommand::MOVE, lst, newurl, job );
+    }
+}
+
+void KonqOperations::setOperation( KIO::Job * job, int method, const KURL::List & /*src*/, const KURL & dest )
 {
   m_method = method;
-  m_srcURLs = src;
+  //m_srcURLs = src;
   m_destURL = dest;
   if ( job )
     connect( job, SIGNAL( result( KIO::Job * ) ),
@@ -378,6 +507,37 @@ void KonqOperations::setOperation( KIO::Job * job, int method, const KURL::List
     slotResult( 0L );
 }
 
+void KonqOperations::statURL( const KURL & url, const QObject *receiver, const char *member )
+{
+    KonqOperations * op = new KonqOperations( 0L );
+    op->_statURL( url, receiver, member );
+    op->m_method = STAT;
+}
+
+void KonqOperations::_statURL( const KURL & url, const QObject *receiver, const char *member )
+{
+    connect( this, SIGNAL( statFinished( const KFileItem * ) ), receiver, member );
+    KIO::StatJob * job = KIO::stat( url /*, false?*/ );
+    connect( job, SIGNAL( result( KIO::Job * ) ),
+             SLOT( slotStatResult( KIO::Job * ) ) );
+}
+
+void KonqOperations::slotStatResult( KIO::Job * job )
+{
+    if ( job->error())
+        job->showErrorDialog( (QWidget*)parent() );
+    else
+    {
+        KIO::StatJob * statJob = static_cast<KIO::StatJob*>(job);
+        KFileItem * item = new KFileItem( statJob->statResult(), statJob->url() );
+        emit statFinished( item );
+        delete item;
+    }
+    // If we're only here for a stat, we're done. But not if we used _statURL internally
+    if ( m_method == STAT )
+        delete this;
+}
+
 void KonqOperations::slotResult( KIO::Job * job )
 {
     if (job && job->error())
