@@ -31,6 +31,7 @@
 #include <kdebug.h>
 #include <kglobal.h>
 #include <kstddirs.h>
+#include <kconfig.h>
 #include <dcopclient.h>
 #include <dcopstub.h>
 #include <qobject.h>
@@ -38,7 +39,6 @@
 #include <qtextstream.h>
 #include <qregexp.h>
 
-
 #include "nspluginloader.h"
 #include "nspluginloader.moc"
 
@@ -50,10 +50,11 @@ int NSPluginLoader::s_refCount = 0;
 
 
 NSPluginInstance::NSPluginInstance(QWidget *parent, const QCString& app, const QCString& id)
-  : QXEmbed(parent), DCOPStub(app, id), NSPluginInstanceIface_stub(app, id)
+  : EMBEDCLASS(parent), DCOPStub(app, id), NSPluginInstanceIface_stub(app, id)
 {
-  setBackgroundMode(QWidget::NoBackground);
-  embed( NSPluginInstanceIface_stub::winId() );
+    _loader = NSPluginLoader::instance();
+    setBackgroundMode(QWidget::NoBackground);
+    embed( NSPluginInstanceIface_stub::winId() );
 }
 
 
@@ -61,14 +62,15 @@ NSPluginInstance::~NSPluginInstance()
 {
    kdDebug() << "-> NSPluginInstance::~NSPluginInstance" << endl;
    shutdown();
-   emit destroyed( this );
+   kdDebug() << "release" << endl;
+   _loader->release();
    kdDebug() << "<- NSPluginInstance::~NSPluginInstance" << endl;
 }
 
 
 void NSPluginInstance::resizeEvent(QResizeEvent *event)
 {
-  QXEmbed::resizeEvent(event);
+  EMBEDCLASS::resizeEvent(event);
   resizePlugin(width(), height());
   kdDebug() << "NSPluginInstance(client)::resizeEvent" << endl;
 }
@@ -81,13 +83,18 @@ NSPluginLoader::NSPluginLoader()
    : QObject(), _mapping(7, false), _viewer(0)
 {
   scanPlugins();
-  _plugins.setAutoDelete( true );
   _mapping.setAutoDelete( true );
 
   // trap dcop register events
   kapp->dcopClient()->setNotifications(true);
-  QObject::connect(kapp->dcopClient(), SIGNAL(applicationRegistered(const QCString&)),
+  QObject::connect(kapp->dcopClient(),
+                   SIGNAL(applicationRegistered(const QCString&)),
                    this, SLOT(applicationRegistered(const QCString&)));
+
+  // load configuration
+  KConfig cfg("kcmnspluginrc", false);
+  cfg.setGroup("Misc");
+  _useArtsdsp = cfg.readBoolEntry( "useArtsdsp", true );
 }
 
 
@@ -119,7 +126,6 @@ void NSPluginLoader::release()
 NSPluginLoader::~NSPluginLoader()
 {
    kdDebug() << "-> NSPluginLoader::~NSPluginLoader" << endl;
-   _plugins.clear();
    unloadViewer();
    kdDebug() << "<- NSPluginLoader::~NSPluginLoader" << endl;
 }
@@ -131,18 +137,16 @@ void NSPluginLoader::scanPlugins()
 
   // open the cache file
   QFile cachef(locate("data", "nsplugins/cache"));
-  if (!cachef.open(IO_ReadOnly))
-    {
+  if (!cachef.open(IO_ReadOnly)) {
       kdDebug() << "Could not load plugin cache file!" << endl;
       return;
-    }
+  }
 
   QTextStream cache(&cachef);
 
   // read in cache
   QString line, plugin;
-  while (!cache.atEnd())
-    {
+  while (!cache.atEnd()) {
       line = cache.readLine();
       if (line.isEmpty() || (line.left(1) == "#"))
         continue;
@@ -163,9 +167,19 @@ void NSPluginLoader::scanPlugins()
 
           // insert the suffix -> mimetype mapping
           QStringList::Iterator suffix;
-          for (suffix = suffixes.begin(); suffix != suffixes.end(); ++suffix)
-            if (!_filetype.find((*suffix).stripWhiteSpace()))
-              _filetype.insert((*suffix).stripWhiteSpace(), new QString(mime));
+          for (suffix = suffixes.begin(); suffix != suffixes.end(); ++suffix) {
+
+              // strip whitspaces and any preceeding '.'
+              QString stripped = (*suffix).stripWhiteSpace();
+
+              unsigned p=0;
+              for ( ; p<stripped.length() && stripped[p]=='.'; p++ );
+              stripped = stripped.right( stripped.length()-p );
+
+              // add filetype to list
+              if ( !stripped.isEmpty() && !_filetype.find(stripped) )
+                  _filetype.insert( stripped, new QString(mime));
+          }
         }
     }
 }
@@ -206,7 +220,8 @@ bool NSPluginLoader::loadViewer()
    int pid = (int)getpid();
    _dcopid.sprintf("nspluginviewer-%d", pid);
 
-   connect( _process, SIGNAL(processExited(KProcess*)), this, SLOT(processTerminated(KProcess*)) );
+   connect( _process, SIGNAL(processExited(KProcess*)),
+            this, SLOT(processTerminated(KProcess*)) );
 
    // find the external viewer process
    QString viewer = KGlobal::dirs()->findExe("nspluginviewer");
@@ -218,17 +233,19 @@ bool NSPluginLoader::loadViewer()
    }
 
    // find the external artsdsp process
-#if 0
-   QString artsdsp = KGlobal::dirs()->findExe("artsdsp");
-   if (!artsdsp)
-   {
-      kdDebug() << "can't find artsdsp" << endl;
+   if( _useArtsdsp ) {
+       kdDebug() << "trying to use artsdsp" << endl;
+       QString artsdsp = KGlobal::dirs()->findExe("artsdsp");
+       if (!artsdsp)
+       {
+           kdDebug() << "can't find artsdsp" << endl;
+       } else
+       {
+           kdDebug() << artsdsp << endl;
+           *_process << artsdsp;
+       }
    } else
-   {
-      kdDebug() << artsdsp << endl;
-      *_process << artsdsp;
-   }
-#endif
+       kdDebug() << "don't using artsdsp" << endl;
 
    *_process << viewer;
 
@@ -304,7 +321,6 @@ void NSPluginLoader::processTerminated(KProcess *proc)
    if ( _process == proc)
    {
       kdDebug() << "Viewer process  terminated" << endl;
-      _plugins.clear();
       delete _viewer;
       delete _process;
       _viewer = 0;
@@ -315,7 +331,8 @@ void NSPluginLoader::processTerminated(KProcess *proc)
 
 NSPluginInstance *NSPluginLoader::newInstance(QWidget *parent, QString url,
                                               QString mimeType, bool embed,
-                                              QStringList argn, QStringList argv)
+                                              QStringList argn, QStringList argv,
+                                              QString appId, QString callbackId )
 {
    kdDebug() << "-> NSPluginLoader::NewInstance( parent=" << (void*)parent << ", url=" << url << ", mime=" << mimeType << ", ...)" << endl;
 
@@ -378,26 +395,17 @@ NSPluginInstance *NSPluginLoader::newInstance(QWidget *parent, QString url,
 
 
    // get plugin instance
-   DCOPRef inst_ref = cls->newInstance( url, mime, embed, argn, argv );
+   DCOPRef inst_ref = cls->newInstance( url, mime, embed, argn, argv, appId, callbackId );
    if ( inst_ref.isNull() )
    {
       kdDebug() << "Couldn't create plugin instance" << endl;
       return 0;
    }
-   NSPluginInstance *plugin = new NSPluginInstance( parent, inst_ref.app(), inst_ref.object() );
-   _plugins.append( plugin );
-   connect( plugin, SIGNAL(destroyed(NSPluginInstance *)),
-            this, SLOT(pluginDestroyed(NSPluginInstance *)) );
+
+   NSPluginInstance *plugin = new NSPluginInstance( parent, inst_ref.app(),
+                                                    inst_ref.object() );
 
    kdDebug() << "<- NSPluginLoader::NewInstance = " << (void*)plugin << endl;
    return plugin;
 }
 
-
-void NSPluginLoader::pluginDestroyed( NSPluginInstance *inst )
-{
-   kdDebug() << "NSPluginLoader::pluginDestroyed" << endl;
-   _plugins.setAutoDelete( false ); // avoid delete recursion
-   _plugins.remove( inst );
-   _plugins.setAutoDelete( true );
-}
